@@ -8,7 +8,11 @@
 # Licensed under the MIT/Expat License.
 
 import sys
-from make_pysol_freecell_board import find_index_main, LCRandom31
+
+from make_pysol_freecell_board import find_index_main
+
+from pysol_cards.random import LCRandom31
+
 from six.moves import range
 
 
