@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // check_and_add_state.c - the various possible implementations of the function
 // fc_solve_check_and_add_state().
 
@@ -20,9 +18,9 @@
   */
 static inline void fc_solve_hash_rehash(hash_table *const hash)
 {
-    const int old_size = hash->size;
+    const_AUTO(old_size, hash->size);
 
-    const int new_size = old_size << 1;
+    const_AUTO(new_size, old_size << 1);
 
     /* Check for overflow. */
     if (new_size < old_size)
@@ -31,21 +29,21 @@ static inline void fc_solve_hash_rehash(hash_table *const hash)
         return;
     }
 
-    const int new_size_bitmask = new_size - 1;
+    const size_t new_size_bitmask = new_size - 1;
 
     const_SLOT(entries, hash);
     hash_table_entry *const new_entries =
         calloc(new_size, sizeof(new_entries[0]));
 
     /* Copy the items to the new hash while not allocating them again */
-    for (int i = 0; i < old_size; i++)
+    for (size_t i = 0; i < old_size; i++)
     {
         hash_item *item = entries[i].first_item;
         /* traverse the chain item by item */
         while (item != NULL)
         {
             /* The place in the new hash table */
-            const int place = item->hash_value & new_size_bitmask;
+            const size_t place = item->hash_value & new_size_bitmask;
 
             /* Store the next item in the linked list in a safe place,
                so we can retrieve it after the assignment */
@@ -246,10 +244,10 @@ static inline void fc_solve_cache_stacks(
         }
 
         var_AUTO(column, fcs_state_get_col(*(new_state_key), i));
-        const int col_len = (fcs_col_len(column) + 1);
+        const size_t col_len = (fcs_col_len(column) + 1);
 
-        char *const new_ptr =
-            (char *)fcs_compact_alloc_ptr(stacks_allocator, col_len);
+        fcs_cards_column new_ptr =
+            (fcs_cards_column)fcs_compact_alloc_ptr(stacks_allocator, col_len);
         memcpy(new_ptr, column, col_len);
         *(current_stack) = new_ptr;
         column = fcs_state_get_col(*new_state_key, i);
@@ -262,8 +260,8 @@ static inline void fc_solve_cache_stacks(
          * (It is not derived work however). */
         fcs_hash_value hash_value_int = 0;
         {
-            const char *s_ptr = (char *)(*(current_stack));
-            const char *s_end = s_ptr + fcs_col_len(s_ptr) + 1;
+            const int8_t *s_ptr = (int8_t *)(*(current_stack));
+            const int8_t *s_end = s_ptr + fcs_col_len(s_ptr) + 1;
             while (s_ptr < s_end)
             {
                 hash_value_int += (hash_value_int << 5) + *(s_ptr++);
@@ -344,8 +342,8 @@ static inline void fc_solve_cache_stacks(
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_HASH)
 guint fc_solve_hash_function(gconstpointer key)
 {
-    const char *s_ptr = (const char *)key;
-    const char *const s_end = s_ptr + sizeof(fcs_state);
+    const int8_t *s_ptr = (const int8_t *)key;
+    const int8_t *const s_end = s_ptr + sizeof(fcs_state);
     guint hash_value = 0;
     while (s_ptr < s_end)
     {
@@ -370,11 +368,11 @@ guint fc_solve_hash_function(gconstpointer key)
  *    that were already checked.
  *    If it is:
  *
- *        5a. Return FALSE.
+ *        5a. Return false.
  *
  *    If it isn't:
  *
- *        5b. Add the new state and return TRUE.
+ *        5b. Add the new state and return true.
  * */
 
 static inline void upon_new_state(fcs_instance *const instance GCC_UNUSED,
@@ -397,7 +395,7 @@ static inline void upon_new_state(fcs_instance *const instance GCC_UNUSED,
 #ifndef FCS_WITHOUT_TRIM_MAX_STORED_STATES
     ++instance->active_num_states_in_collection;
 #endif
-    ++instance->num_states_in_collection;
+    ++instance->i__stats.num_states_in_collection;
 #endif
 }
 
@@ -408,7 +406,7 @@ static inline bool handle_existing_void(fcs_instance *const instance,
     if (existing_void)
     {
         FCS_STATE_collectible_to_kv(existing_state_raw, existing_void);
-        return FALSE;
+        return false;
     }
     else
     {
@@ -419,12 +417,12 @@ static inline bool handle_existing_void(fcs_instance *const instance,
             printf("%s", "\n\nAdded state: ");
             for (size_t i = 0; i < sizeof(new_state->key[0]); ++i)
             {
-                printf("\\x%02x", (int)((unsigned char *)(new_state->key))[i]);
+                printf("\\x%02x", (int)((uint8_t *)(new_state->key))[i]);
             }
             printf("\n\n");
         }
 #endif
-        return TRUE;
+        return true;
     }
 }
 #define HANDLE_existing_void(existing_void)                                    \
@@ -462,8 +460,8 @@ bool fc_solve_check_and_add_state(fcs_hard_thread *const hard_thread,
 #ifdef FCS_ENABLE_SECONDARY_HASH_VALUE
     fcs_hash_value hash_value_int = 0;
     {
-        const char *s_ptr = (char *)new_state_key;
-        const char *s_end = s_ptr + sizeof(*new_state_key);
+        const int8_t *s_ptr = (int8_t *)new_state_key;
+        const int8_t *s_end = s_ptr + sizeof(*new_state_key);
         while (s_ptr < s_end)
         {
             hash_value_int += (hash_value_int << 5) + *(s_ptr++);
