@@ -1,15 +1,13 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // cmd_line.c - the Freecell Solver command line arguments-like parsing
 // routines. Useful for more easily configuring a Freecell Solver instance.
-#include "fcs_conf.h"
+#include "freecell-solver/fcs_conf.h"
 
 #ifndef HAVE_VASPRINTF
 #include "asprintf.h"
@@ -87,7 +85,7 @@ static inline bool read_preset(const char *const preset_name,
         (const char *)global_presetrc,
         user_preset_dir,
     };
-    bool read_next_preset = FALSE;
+    bool read_next_preset = false;
     for (size_t path_idx = 0; path_idx < COUNT(presetrc_pathes); ++path_idx)
     {
         const char *const path = presetrc_pathes[path_idx];
@@ -135,7 +133,7 @@ static inline bool read_preset(const char *const preset_name,
                 nullify_newline(line);
                 if (!strcmp(s, preset_name))
                 {
-                    read_next_preset = TRUE;
+                    read_next_preset = true;
                 }
             }
             else if ((s = try_str_prefix(line, "command=")))
@@ -144,13 +142,13 @@ static inline bool read_preset(const char *const preset_name,
                 {
                     *args_man = fc_solve_args_man_chop(s);
                     fclose(f);
-                    return FALSE;
+                    return false;
                 }
             }
         }
         fclose(f);
     }
-    return TRUE;
+    return true;
 }
 
 #ifdef FCS_WITH_ERROR_STRS
@@ -158,16 +156,12 @@ static inline __attribute__((format(printf, 1, 2))) char *calc_errstr_s(
     const char *const format, ...)
 {
     va_list my_va_list;
-
     va_start(my_va_list, format);
-
     char *errstr;
-
-    vasprintf(&errstr, format, my_va_list);
-
+    const_AUTO(ret, vasprintf(&errstr, format, my_va_list));
     va_end(my_va_list);
 
-    return errstr;
+    return ((ret < 0) ? NULL : errstr);
 }
 
 #define ASSIGN_ERR_STR(error_string, format, ...)                              \
@@ -182,11 +176,11 @@ static inline __attribute__((format(printf, 1, 2))) char *calc_errstr_s(
 #define PROCESS_OPT_ARG()                                                      \
     if ((++arg) == arg_argc)                                                   \
     {                                                                          \
-        *last_arg = arg - 1 - &(argv[0]);                                      \
+        *last_arg = (int)(arg - 1 - &(argv[0]));                               \
         return FCS_CMD_LINE_PARAM_WITH_NO_ARG;                                 \
     }
 #define RET_ERROR_IN_ARG()                                                     \
-    *last_arg = arg - &(argv[0]);                                              \
+    *last_arg = (int)(arg - &(argv[0]));                                       \
     return FCS_CMD_LINE_ERROR_IN_ARG
 #define RET_ERR_STR(...)                                                       \
     ASSIGN_ERR_STR(__VA_ARGS__);                                               \
@@ -211,24 +205,21 @@ DLLEXPORT int freecell_solver_user_cmd_line_read_cmd_line_preset(
         ASSIGN_ERR_STR(error_string, "%s", "Could not read preset.");
         return FCS_CMD_LINE_ERROR_IN_ARG;
     }
-    else
-    {
-        int last_arg = 0;
+    int last_arg = 0;
 
-        const int ret =
-            freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
-                instance, preset_args.argc,
-                (freecell_solver_str_t *)(void *)(preset_args.argv), 0,
-                known_parameters, NULL, NULL FCS__PASS_ERR_STR(error_string),
-                &(last_arg),
-                ((file_nesting_count < 0) ? file_nesting_count
-                                          : (file_nesting_count - 1)),
-                dir[0] ? dir : opened_files_dir);
+    const int ret =
+        freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
+            instance, preset_args.argc,
+            (freecell_solver_str_t *)(void *)(preset_args.argv), 0,
+            known_parameters, NULL, NULL FCS__PASS_ERR_STR(error_string),
+            &(last_arg),
+            ((file_nesting_count < 0) ? file_nesting_count
+                                      : (file_nesting_count - 1)),
+            dir[0] ? dir : opened_files_dir);
 
-        fc_solve_args_man_free(&preset_args);
+    fc_solve_args_man_free(&preset_args);
 
-        return ret;
-    }
+    return ret;
 }
 
 DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
@@ -258,7 +249,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
             if (*known_param)
             {
                 int ret, num_to_skip;
-                switch (callback(instance, argc, argv, arg - &(argv[0]),
+                switch (callback(instance, argc, argv, (int)(arg - &(argv[0])),
                     &num_to_skip, &ret, callback_context))
                 {
                 case FCS_CMD_LINE_SKIP:
@@ -266,7 +257,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
                     goto end_of_arg_loop;
 
                 case FCS_CMD_LINE_STOP:
-                    *last_arg = arg - &(argv[0]);
+                    *last_arg = (int)(arg - &(argv[0]));
                     return ret;
                 }
             }
@@ -282,7 +273,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
         switch (opt)
         {
         case FCS_OPT_UNRECOGNIZED:
-            *last_arg = arg - &(argv[0]);
+            *last_arg = (int)(arg - &(argv[0]));
             return FCS_CMD_LINE_UNRECOGNIZED_OPTION;
 
         case FCS_OPT_MAX_DEPTH: /* STRINGS=-md|--max-depth; */
@@ -660,9 +651,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
                 }
                 else
                 {
-                    /*
-                     * Initialize f to NULL so it will be initialized
-                     * */
+                    // Initialize f to NULL so it will be initialized
                     f = NULL;
                 }
 
@@ -680,7 +669,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
                 }
                 fseek(f, 0, SEEK_END);
                 const long file_len = ftell(f);
-                char *buffer = SMALLOC(buffer, file_len + 1);
+                char *buffer = SMALLOC(buffer, (size_t)(file_len + 1));
                 if (buffer == NULL)
                 {
                     fclose(f);
@@ -689,7 +678,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
                         "to parse the file. Quitting.\n");
                 }
                 fseek(f, 0, SEEK_SET);
-                buffer[fread(buffer, 1, file_len, f)] = '\0';
+                buffer[fread(buffer, 1, (size_t)(file_len), f)] = '\0';
                 fclose(f);
 
                 fcs_args_man args_man = fc_solve_args_man_chop(buffer);
@@ -714,7 +703,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
                             (ret == FCS_CMD_LINE_OK)))
                     {
                         /* So we don't give a last_arg to the read file.*/
-                        *last_arg = arg - &(argv[0]);
+                        *last_arg = (int)(arg - &(argv[0]));
                         fc_solve_args_man_free(&args_man);
                         return ret;
                     }
@@ -866,7 +855,7 @@ DLLEXPORT int freecell_solver_user_cmd_line_parse_args_with_file_nesting_count(
     end_of_arg_loop:;
     }
 
-    *last_arg = arg - &(argv[0]);
+    *last_arg = (int)(arg - &(argv[0]));
     return FCS_CMD_LINE_OK;
 }
 
