@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2012 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2012 Shlomi Fish
 /*
  * dbm_cache.h - contains the implementation of the DBM solver cache routines.
  */
@@ -25,8 +23,8 @@ extern "C" {
 #include "dbm_calc_derived_iface.h"
 #include "dbm_lru_cache.h"
 
-static int fc_solve_compare_lru_cache_keys(const void *const void_a,
-    const void *const void_b, void *context GCC_UNUSED)
+static inline int fc_solve_compare_lru_cache_keys__noctx(
+    const void *const void_a, const void *const void_b)
 {
 #define GET_PARAM(p) ((((const fcs_cache_key_info *)(p))->key))
     return memcmp(
@@ -34,6 +32,14 @@ static int fc_solve_compare_lru_cache_keys(const void *const void_a,
 #undef GET_PARAM
 }
 
+#ifdef AVL_with_rb_param
+static int fc_solve_compare_lru_cache_keys(const void *const void_a,
+    const void *const void_b, void *context GCC_UNUSED)
+{
+    return fc_solve_compare_lru_cache_keys__noctx(void_a, void_b);
+}
+#endif
+
 static inline void cache_destroy_key(fcs_cache_key_info *cache_key)
 {
     for (; cache_key; cache_key = RECYCLE_BIN_NEXT(cache_key))
@@ -53,14 +59,16 @@ static inline void cache_destroy(fcs_lru_cache *cache)
 }
 
 static inline void cache_init(fcs_lru_cache *const cache,
-    const long max_num_elements_in_cache, meta_allocator *const meta_alloc)
+    const unsigned long max_num_elements_in_cache,
+    meta_allocator *const meta_alloc)
 {
 #if (FCS_RCS_CACHE_STORAGE == FCS_RCS_CACHE_STORAGE_JUDY)
     cache->states_values_to_keys_map = ((Pvoid_t)NULL);
 #elif (FCS_RCS_CACHE_STORAGE == FCS_RCS_CACHE_STORAGE_KAZ_TREE)
     cache->tree_recycle_bin = NULL;
-    cache->kaz_tree = fc_solve_kaz_tree_create(fc_solve_compare_lru_cache_keys,
-        NULL, meta_alloc, &(cache->tree_recycle_bin));
+    cache->kaz_tree =
+        fc_solve_kaz_tree_create(fc_solve_compare_lru_cache_keys__noctx, NULL,
+            meta_alloc, &(cache->tree_recycle_bin));
 #else
 #error Unknown FCS_RCS_CACHE_STORAGE
 #endif
@@ -82,7 +90,7 @@ static inline bool cache_does_key_exist(
         fc_solve_kaz_tree_lookup_value(cache->kaz_tree, &to_check);
     if (!existing_key)
     {
-        return FALSE;
+        return false;
     }
     else
     {
@@ -108,7 +116,7 @@ static inline bool cache_does_key_exist(
             existing->higher_pri = NULL;
         }
 
-        return TRUE;
+        return true;
     }
 }
 
