@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2012 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2012 Shlomi Fish
 /*
  * dbm_calc_derived.h - contains functions to calculate the derived states
  * from a certain position.
@@ -32,10 +30,10 @@ typedef struct fcs_derived_state_struct
     fcs_encoded_state_buffer key;
     fcs_dbm_record *parent;
     struct fcs_derived_state_struct *next;
-    int core_irreversible_moves_count;
+    size_t core_irreversible_moves_count;
     fcs_which_moves_bitmask which_irreversible_moves_bitmask;
     fcs_fcc_move move;
-    int num_non_reversible_moves_including_prune;
+    size_t num_non_reversible_moves_including_prune;
     DECLARE_IND_BUF_T(indirect_stacks_buffer)
 } fcs_derived_state;
 
@@ -55,7 +53,7 @@ static inline void fcs_derived_state_list__recycle(
     *p_list = NULL;
 }
 
-#define MAKE_MOVE(src, dest) ((fcs_fcc_move)((src) | ((dest) << 4)))
+#define MAKE_MOVE(src, dest) ((fcs_fcc_move)((src) | ((dest) << 4U)))
 #define COL2MOVE(idx) (idx)
 #define FREECELL2MOVE(idx) (idx + 8)
 #define FOUND2MOVE(idx) ((idx) + (8 + 4))
@@ -73,10 +71,10 @@ static inline void fcs_derived_state_list__recycle(
     {                                                                          \
         const_AUTO(copy_stack_col,                                             \
             fcs_state_get_col((ptr_new_state->state.s), copy_col_idx));        \
-        memcpy(&(ptr_new_state->indirect_stacks_buffer[copy_col_idx << 7]),    \
+        memcpy(&(ptr_new_state->indirect_stacks_buffer[copy_col_idx << 6]),    \
             copy_stack_col, (size_t)(fcs_col_len(copy_stack_col)) + 1);        \
         fcs_state_get_col((ptr_new_state->state.s), copy_col_idx) =            \
-            &(ptr_new_state->indirect_stacks_buffer[copy_col_idx << 7]);       \
+            &(ptr_new_state->indirect_stacks_buffer[copy_col_idx << 6]);       \
     }
 
 #else
@@ -104,13 +102,13 @@ static inline void fcs_derived_state_list__recycle(
 
 static inline void fc_solve_add_to_irrev_moves_bitmask(
     fcs_which_moves_bitmask *const which_irreversible_moves_bitmask,
-    const fcs_card moved_card, const int count)
+    const fcs_card moved_card, const uint_fast32_t count)
 {
     unsigned char *const by_rank_ptr =
         which_irreversible_moves_bitmask->s + fcs_card_rank(moved_card) - 1;
-    const int suit_times_two = (fcs_card_suit(moved_card) << 1);
-    const int new_count =
-        ((((*by_rank_ptr) >> (suit_times_two)) & ((1 << 2) - 1)) + count);
+    const size_t suit_times_two = (fcs_card_suit(moved_card) << 1);
+    const size_t new_count =
+        ((((*by_rank_ptr) >> (suit_times_two)) & ((1U << 2U) - 1U)) + count);
     *by_rank_ptr &= (~((((unsigned char)0x3) << (suit_times_two))));
     *by_rank_ptr |= (new_count << (suit_times_two));
 }
@@ -143,8 +141,8 @@ static inline __attribute__((pure)) int calc_foundation_to_put_card_on(
 {
     FCS_ON_NOT_FC_ONLY(
         const int sequences_are_built_by = CALC_SEQUENCES_ARE_BUILT_BY());
-    const int_fast32_t rank = fcs_card_rank(card);
-    const int_fast32_t suit = fcs_card_suit(card);
+    const fcs_card rank = fcs_card_rank(card);
+    const fcs_card suit = fcs_card_suit(card);
     for (uint_fast32_t deck = 0; deck < INSTANCE_DECKS_NUM; ++deck)
     {
         if (fcs_foundation_value(*ptr_state, (deck << 2) + suit) == rank - 1)
@@ -165,7 +163,7 @@ static inline __attribute__((pure)) int calc_foundation_to_put_card_on(
             }
             if (other_deck_idx == (INSTANCE_DECKS_NUM << 2))
             {
-                return (deck << 2) + suit;
+                return (int)((deck << 2) + suit);
             }
         }
     }
@@ -197,20 +195,20 @@ static inline fcs_fcc_moves_list_item *fc_solve_fcc_alloc_moves_list_item(
 
 #define FROM_COL_IS_REVERSIBLE_MOVE()                                          \
     ((cards_num <= 1)                                                          \
-            ? TRUE                                                             \
+            ? true                                                             \
             : fcs_is_parent_card(card, fcs_col_get_card(col, cards_num - 2)))
 #define COUNT_NON_REV(is_reversible) ((is_reversible) ? 1 : 2)
 
 /* Returns the number of amortized irreversible moves performed. */
-static inline int horne_prune(const fcs_dbm_variant_type local_variant,
+static inline size_t horne_prune(const fcs_dbm_variant_type local_variant,
     fcs_state_keyval_pair *const init_state_kv_ptr,
     fcs_which_moves_bitmask *const which_irreversible_moves_bitmask,
     fcs_fcc_moves_seq *const moves_seq,
     fcs_fcc_moves_seq_allocator *const allocator)
 {
     fcs_fcc_move additional_moves[RANK_KING * 4 * DECKS_NUM];
-    int count_moves_so_far = 0;
-    int count_additional_irrev_moves = 0;
+    size_t count_moves_so_far = 0;
+    size_t count_additional_irrev_moves = 0;
     FCS_ON_NOT_FC_ONLY(
         const int sequences_are_built_by = CALC_SEQUENCES_ARE_BUILT_BY());
 
@@ -219,7 +217,7 @@ static inline int horne_prune(const fcs_dbm_variant_type local_variant,
     do
     {
         num_cards_moved = 0;
-        for (int stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
+        for (stack_i stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
         {
             var_AUTO(col, fcs_state_get_col(the_state, stack_idx));
             const int cards_num = fcs_col_len(col);
@@ -248,14 +246,14 @@ static inline int horne_prune(const fcs_dbm_variant_type local_variant,
 
                 fcs_increment_foundation(the_state, dest_foundation);
 
-                additional_moves[count_moves_so_far++] =
-                    MAKE_MOVE(COL2MOVE(stack_idx), FOUND2MOVE(dest_foundation));
+                additional_moves[count_moves_so_far++] = MAKE_MOVE(
+                    COL2MOVE(stack_idx), FOUND2MOVE((stack_i)dest_foundation));
             }
         }
 
 #if MAX_NUM_FREECELLS > 0
         // Now check the same for the free cells
-        for (int fc = 0; fc < LOCAL_FREECELLS_NUM; fc++)
+        for (stack_i fc = 0; fc < LOCAL_FREECELLS_NUM; fc++)
         {
             const fcs_card card = fcs_freecell_card(the_state, fc);
             if (fcs_card_is_valid(card))
@@ -272,8 +270,8 @@ static inline int horne_prune(const fcs_dbm_variant_type local_variant,
 
                     fcs_empty_freecell(the_state, fc);
                     fcs_increment_foundation(the_state, dest_foundation);
-                    additional_moves[count_moves_so_far++] =
-                        MAKE_MOVE(COL2MOVE(fc), FOUND2MOVE(dest_foundation));
+                    additional_moves[count_moves_so_far++] = MAKE_MOVE(
+                        COL2MOVE(fc), FOUND2MOVE((stack_i)dest_foundation));
                 }
             }
         }
@@ -301,16 +299,16 @@ static inline int horne_prune(const fcs_dbm_variant_type local_variant,
          * to sum up we need to move count / FCS_FCC_NUM_MOVES_IN_ITEM .
          *
          * */
-        const int count = moves_seq->count;
-        for (int pos = 0; pos <= count - FCS_FCC_NUM_MOVES_IN_ITEM;
+        const size_t count = moves_seq->count;
+        for (size_t pos = 0; pos <= count - FCS_FCC_NUM_MOVES_IN_ITEM;
              pos += FCS_FCC_NUM_MOVES_IN_ITEM)
         {
             iter = &((*iter)->next);
         }
 
-        int pos = count;
+        size_t pos = count;
 
-        for (int pos_moves_so_far = 0; pos_moves_so_far < count_moves_so_far;
+        for (size_t pos_moves_so_far = 0; pos_moves_so_far < count_moves_so_far;
              pos_moves_so_far++)
         {
             if (pos % FCS_FCC_NUM_MOVES_IN_ITEM == 0)
@@ -330,7 +328,8 @@ static inline int horne_prune(const fcs_dbm_variant_type local_variant,
     return count_moves_so_far + count_additional_irrev_moves;
 }
 
-static inline int horne_prune__simple(const fcs_dbm_variant_type local_variant,
+static inline size_t horne_prune__simple(
+    const fcs_dbm_variant_type local_variant,
     fcs_state_keyval_pair *const init_state_kv_ptr)
 {
     fcs_which_moves_bitmask no_use = {{'\0'}};
@@ -338,7 +337,7 @@ static inline int horne_prune__simple(const fcs_dbm_variant_type local_variant,
 }
 
 static inline bool card_cannot_be_placed(const fcs_state *const s,
-    const uint16_t ds, const fcs_card card,
+    const stack_i ds, const fcs_card card,
     const int sequences_are_built_by GCC_UNUSED)
 {
     const_AUTO(col, fcs_state_get_col(*s, ds));
@@ -351,14 +350,14 @@ static inline bool card_cannot_be_placed(const fcs_state *const s,
 static inline bool is_state_solved(
     fcs_state_keyval_pair *const init_state_kv_ptr)
 {
-    for (int suit = 0; suit < DECKS_NUM * 4; suit++)
+    for (stack_i suit = 0; suit < DECKS_NUM * 4; suit++)
     {
         if (fcs_foundation_value(the_state, suit) < RANK_KING)
         {
-            return FALSE;
+            return false;
         }
     }
-    return TRUE;
+    return true;
 }
 
 static inline bool instance_solver_thread_calc_derived_states(
@@ -370,28 +369,30 @@ static inline bool instance_solver_thread_calc_derived_states(
     const bool perform_horne_prune)
 {
     fcs_derived_state *ptr_new_state;
-    int empty_stack_idx = -1;
+    bool has_empty_stack = false;
+    stack_i empty_stack_idx = 0;
     const int sequences_are_built_by = CALC_SEQUENCES_ARE_BUILT_BY();
 #define new_state (ptr_new_state->state.s)
     if (is_state_solved(init_state_kv_ptr))
     {
-        return TRUE;
+        return true;
     }
 
     /* Move top stack cards to foundations. */
-    for (int stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
+    for (stack_i stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
     {
         const_AUTO(col, fcs_state_get_col(the_state, stack_idx));
         const_AUTO(cards_num, fcs_col_len(col));
         if (cards_num == 0)
         {
             empty_stack_idx = stack_idx;
+            has_empty_stack = true;
             continue;
         }
         /* Get the top card in the stack */
         const_AUTO(card, fcs_col_get_card(col, cards_num - 1));
         const_AUTO(suit, fcs_card_suit(card));
-        for (int deck = 0; deck < INSTANCE_DECKS_NUM; deck++)
+        for (stack_i deck = 0; deck < INSTANCE_DECKS_NUM; deck++)
         {
             if (fcs_foundation_value(the_state, deck * 4 + suit) !=
                 fcs_card_rank(card) - 1)
@@ -413,16 +414,16 @@ static inline bool instance_solver_thread_calc_derived_states(
 #if MAX_NUM_FREECELLS > 0
     int empty_fc_idx = -1;
     // Move freecell cards to foundations.
-    for (int fc_idx = 0; fc_idx < LOCAL_FREECELLS_NUM; fc_idx++)
+    for (stack_i fc_idx = 0; fc_idx < LOCAL_FREECELLS_NUM; ++fc_idx)
     {
         const_AUTO(card, fcs_freecell_card(the_state, fc_idx));
         if (fcs_card_is_empty(card))
         {
-            empty_fc_idx = fc_idx;
+            empty_fc_idx = (int)fc_idx;
             continue;
         }
         const_AUTO(suit, fcs_card_suit(card));
-        for (int deck = 0; deck < INSTANCE_DECKS_NUM; deck++)
+        for (stack_i deck = 0; deck < INSTANCE_DECKS_NUM; ++deck)
         {
             if (fcs_foundation_value(the_state, deck * 4 + suit) !=
                 fcs_card_rank(card) - 1)
@@ -436,7 +437,7 @@ static inline bool instance_solver_thread_calc_derived_states(
             fcs_increment_foundation(new_state, deck * 4 + suit);
 
             COMMIT_NEW_STATE(
-                FREECELL2MOVE(fc_idx), FOUND2MOVE(suit), FALSE, card)
+                FREECELL2MOVE(fc_idx), FOUND2MOVE(suit), false, card)
             break;
         }
     }
@@ -446,7 +447,7 @@ static inline bool instance_solver_thread_calc_derived_states(
         ((local_variant == FCS_DBM_VARIANT_BAKERS_DOZEN) ? 1 : 0);
 
     /* Move stack card on top of a parent */
-    for (int stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
+    for (stack_i stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
     {
         const_AUTO(col, fcs_state_get_col(the_state, stack_idx));
         const_AUTO(cards_num, fcs_col_len(col));
@@ -456,7 +457,7 @@ static inline bool instance_solver_thread_calc_derived_states(
         }
         const_AUTO(card, fcs_col_get_card(col, cards_num - 1));
 
-        for (int ds = 0; ds < LOCAL_STACKS_NUM; ++ds)
+        for (stack_i ds = 0; ds < LOCAL_STACKS_NUM; ++ds)
         {
             if (ds == stack_idx || card_cannot_be_placed(&the_state, ds, card,
                                        sequences_are_built_by))
@@ -476,14 +477,14 @@ static inline bool instance_solver_thread_calc_derived_states(
 
 #if MAX_NUM_FREECELLS > 0
     // Move freecell card on top of a parent
-    for (int fc_idx = 0; fc_idx < LOCAL_FREECELLS_NUM; fc_idx++)
+    for (stack_i fc_idx = 0; fc_idx < LOCAL_FREECELLS_NUM; fc_idx++)
     {
         const_AUTO(card, fcs_freecell_card(the_state, fc_idx));
         if (!fcs_card_is_valid(card))
         {
             continue;
         }
-        for (int ds = 0; ds < LOCAL_STACKS_NUM; ++ds)
+        for (stack_i ds = 0; ds < LOCAL_STACKS_NUM; ++ds)
         {
             if (card_cannot_be_placed(
                     &the_state, ds, card, sequences_are_built_by))
@@ -496,16 +497,15 @@ static inline bool instance_solver_thread_calc_derived_states(
             fcs_state_push(&new_state, ds, card);
             fcs_empty_freecell(new_state, fc_idx);
 
-            COMMIT_NEW_STATE(FREECELL2MOVE(fc_idx), COL2MOVE(ds), TRUE, card)
+            COMMIT_NEW_STATE(FREECELL2MOVE(fc_idx), COL2MOVE(ds), true, card)
         }
     }
 #endif
 
-    if ((local_variant != FCS_DBM_VARIANT_BAKERS_DOZEN) &&
-        (empty_stack_idx >= 0))
+    if ((local_variant != FCS_DBM_VARIANT_BAKERS_DOZEN) && has_empty_stack)
     {
         /* Stack Card to Empty Stack */
-        for (int stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
+        for (stack_i stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
         {
             const_AUTO(col, fcs_state_get_col(the_state, stack_idx));
             const_AUTO(cards_num, fcs_col_len(col));
@@ -530,7 +530,7 @@ static inline bool instance_solver_thread_calc_derived_states(
 
 #if MAX_NUM_FREECELLS > 0
         /* Freecell card -> Empty Stack. */
-        for (int fc_idx = 0; fc_idx < LOCAL_FREECELLS_NUM; fc_idx++)
+        for (stack_i fc_idx = 0; fc_idx < LOCAL_FREECELLS_NUM; fc_idx++)
         {
             const_AUTO(card, fcs_freecell_card(the_state, fc_idx));
             if (fcs_card_is_empty(card))
@@ -544,7 +544,7 @@ static inline bool instance_solver_thread_calc_derived_states(
             fcs_empty_freecell(new_state, fc_idx);
 
             COMMIT_NEW_STATE(
-                FREECELL2MOVE(fc_idx), COL2MOVE(empty_stack_idx), TRUE, card);
+                FREECELL2MOVE(fc_idx), COL2MOVE(empty_stack_idx), true, card);
         }
 #endif
     }
@@ -553,7 +553,7 @@ static inline bool instance_solver_thread_calc_derived_states(
     if (empty_fc_idx >= 0)
     {
         /* Stack Card to Empty Freecell */
-        for (int stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
+        for (stack_i stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
         {
             const_AUTO(col, fcs_state_get_col(the_state, stack_idx));
             const_AUTO(cards_num, fcs_col_len(col));
@@ -568,7 +568,8 @@ static inline bool instance_solver_thread_calc_derived_states(
             fcs_state_pop_col_top(&new_state, stack_idx);
             fcs_put_card_in_freecell(new_state, empty_fc_idx, card);
 
-            COMMIT_NEW_STATE(COL2MOVE(stack_idx), FREECELL2MOVE(empty_fc_idx),
+            COMMIT_NEW_STATE(COL2MOVE(stack_idx),
+                FREECELL2MOVE((stack_i)empty_fc_idx),
                 FROM_COL_IS_REVERSIBLE_MOVE(), card)
         }
     }
@@ -588,7 +589,7 @@ static inline bool instance_solver_thread_calc_derived_states(
                         : 0));
     }
 
-    return FALSE;
+    return false;
 }
 
 #undef FROM_COL_IS_REVERSIBLE_MOVE
