@@ -1,17 +1,15 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2011 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2011 Shlomi Fish
 // dbm_calc_derived_test.c - testing interface for dbm_calc_derived.h .
 // This is compiled into a shared library and then loaded by Inline::C,
 // ctypes, etc.
 #include <assert.h>
-#include "fcs_conf.h"
+#include "freecell-solver/fcs_conf.h"
 #undef FCS_RCS_STATES
 #include "delta_states_any.h"
 #include "dbm_calc_derived.h"
@@ -61,7 +59,7 @@ DLLEXPORT int fc_solve_user_INTERNAL_calc_derived_states_wrapper(
         iter = iter->next;
     }
 
-    *(num_out_derived_states) = states_count;
+    *(num_out_derived_states) = (int)states_count;
 
     fcs_derived_state_debug *const debug_ret = SMALLOC(debug_ret, states_count);
     *(out_derived_states) = debug_ret;
@@ -127,7 +125,7 @@ DLLEXPORT int fc_solve_user_INTERNAL_perform_horne_prune(
     *ret_state_s = SMALLOC(*ret_state_s, 1000);
     FCS__RENDER_STATE(*ret_state_s, &(init_state.s), &locs);
 
-    return prune_ret;
+    return (int)prune_ret;
 }
 
 DLLEXPORT void fc_solve_user_INTERNAL_perform_horne_prune__free_ret_state_s(
