@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 #include "dbm_solver.h"
 #include "generic_tree.h"
 #include "dbm_kaztree_compare.h"
@@ -28,7 +26,7 @@ void fc_solve_dbm_store_init(fcs_dbm_store *const store,
     fc_solve_meta_compact_allocator_init(&(db->meta_alloc));
 
     db->kaz_tree = fc_solve_kaz_tree_create(
-        compare_records, NULL, &(db->meta_alloc), recycle_bin_ptr);
+        compare_records__noctx, NULL, &(db->meta_alloc), recycle_bin_ptr);
 
 #ifndef FCS_LIBAVL_STORE_WHOLE_KEYS
     fc_solve_compact_allocator_init(&(db->allocator), &(db->meta_alloc));
@@ -43,7 +41,7 @@ dict_t *__attribute__((pure)) fc_solve_dbm_store_get_dict(fcs_dbm_store store)
 }
 
 /*
- * Returns TRUE if the key was added (it didn't already exist.)
+ * Returns true if the key was added (it didn't already exist.)
  * */
 fcs_dbm_record *fc_solve_dbm_store_insert_key_value(fcs_dbm_store store,
     const fcs_encoded_state_buffer *key, fcs_dbm_record *const parent,
@@ -77,28 +75,23 @@ fcs_dbm_record *fc_solve_dbm_store_insert_key_value(fcs_dbm_store store,
     to_check->key = *key;
     to_check->parent = parent->parent;
 #endif
-    bool ret = (fc_solve_kaz_tree_alloc_insert(db->kaz_tree, to_check) == NULL);
+    const bool ret =
+        (fc_solve_kaz_tree_alloc_insert(db->kaz_tree, to_check) == NULL);
 
-#ifndef FCS_LIBAVL_STORE_WHOLE_KEYS
     if (!ret)
     {
+#ifndef FCS_LIBAVL_STORE_WHOLE_KEYS
         fcs_compact_alloc_release(&(db->allocator));
-    }
 #endif
-    if (ret)
-    {
-        if (should_modify_parent && parent)
-        {
-            fcs_dbm_record_increment_refcount(parent);
-        }
-
-        return ((fcs_dbm_record *)(fc_solve_kaz_tree_lookup_value(
-            db->kaz_tree, to_check)));
-    }
-    else
-    {
         return NULL;
     }
+    if (should_modify_parent && parent)
+    {
+        fcs_dbm_record_increment_refcount(parent);
+    }
+
+    return ((fcs_dbm_record *)(fc_solve_kaz_tree_lookup_value(
+        db->kaz_tree, to_check)));
 }
 
 bool fc_solve_dbm_store_lookup_parent(
@@ -110,28 +103,24 @@ bool fc_solve_dbm_store_lookup_parent(
         fc_solve_kaz_tree_lookup_value(((fcs_dbm *)store)->kaz_tree, &to_check);
     if (!existing)
     {
-        return FALSE;
+        return false;
+    }
+#ifdef FCS_DBM_RECORD_POINTER_REPR
+    fcs_dbm_record *const p =
+        fcs_dbm_record_get_parent_ptr((fcs_dbm_record *)existing);
+
+    if (p)
+    {
+        *(fcs_encoded_state_buffer *)parent = p->key;
     }
     else
     {
-#ifdef FCS_DBM_RECORD_POINTER_REPR
-        fcs_dbm_record *const p =
-            fcs_dbm_record_get_parent_ptr((fcs_dbm_record *)existing);
-
-        if (p)
-        {
-            *(fcs_encoded_state_buffer *)parent = p->key;
-        }
-        else
-        {
-            fcs_init_encoded_state((fcs_encoded_state_buffer *)parent);
-        }
-#else
-        *(fcs_encoded_state_buffer *)parent =
-            ((fcs_dbm_record *)existing)->parent;
-#endif
-        return TRUE;
+        fcs_init_encoded_state((fcs_encoded_state_buffer *)parent);
     }
+#else
+    *(fcs_encoded_state_buffer *)parent = ((fcs_dbm_record *)existing)->parent;
+#endif
+    return true;
 }
 
 extern void fc_solve_dbm_store_destroy(fcs_dbm_store store)
