@@ -1,25 +1,20 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2012 Shlomi Fish
- */
-/*
- * dbm_solver.c - a specialised solver that offloads the states' collection
- * to an on-disk DBM database such as Berkeley DB or Google's LevelDB. Has
- * been adapted to be completely in-memory. It makes use of delta_states.c
- * for a very compact storage.
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2012 Shlomi Fish
+// dbm_solver.c - a specialised solver that offloads the states' collection
+// to an on-disk DBM database such as Berkeley DB or Google's LevelDB. Has
+// been adapted to be completely in-memory. It makes use of delta_states.c
+// for a very compact storage.
 
 #include "dbm_solver_head.h"
 
 typedef struct
 {
     fcs_dbm__cache_store__common cache_store;
-    /* The queue */
     meta_allocator meta_alloc;
     fcs_offloading_queue queue;
 #ifdef FCS_DBM_USE_OFFLOADING_QUEUE
@@ -32,8 +27,9 @@ typedef struct
 
 #include "dbm_procs.h"
 static inline void instance_init(dbm_solver_instance *const instance,
-    const fcs_dbm_common_input *const inp, const long iters_delta_limit,
-    FILE *const out_fh)
+    const fcs_dbm_common_input *const inp,
+    const unsigned long iters_delta_limit,
+    const unsigned long max_num_states_in_collection, FILE *const out_fh)
 {
     fc_solve_meta_compact_allocator_init(&(instance->meta_alloc));
 #ifdef FCS_DBM_USE_OFFLOADING_QUEUE
@@ -42,8 +38,8 @@ static inline void instance_init(dbm_solver_instance *const instance,
 #else
     fcs_offloading_queue__init(&(instance->queue), &(instance->meta_alloc));
 #endif
-    fcs_dbm__common_init(
-        &(instance->common), iters_delta_limit, inp->local_variant, out_fh);
+    fcs_dbm__common_init(&(instance->common), iters_delta_limit,
+        max_num_states_in_collection, inp->local_variant, out_fh);
     fcs_dbm__cache_store__init(&(instance->cache_store), &(instance->common),
         &(instance->meta_alloc), inp->dbm_store_path, inp->pre_cache_max_count,
         inp->caches_delta);
@@ -76,9 +72,9 @@ static inline void instance_destroy(dbm_solver_instance *const instance)
 
 static inline void instance_check_key(
     dbm_solver_thread *const thread GCC_UNUSED,
-    dbm_solver_instance *const instance, const int key_depth GCC_UNUSED,
+    dbm_solver_instance *const instance, const size_t key_depth GCC_UNUSED,
     fcs_encoded_state_buffer *const key, fcs_dbm_record *const parent,
-    const unsigned char move GCC_UNUSED,
+    const uint8_t move GCC_UNUSED,
     const fcs_which_moves_bitmask *const which_irreversible_moves_bitmask
         GCC_UNUSED
 #ifdef FCS_DBM_CACHE_ONLY
@@ -94,8 +90,6 @@ static inline void instance_check_key(
         fcs_cache_key_info *cache_key = cache_store__insert_key(
             &(instance->cache_store), key, parent, moves_to_parent, move);
 #endif
-        /* Now insert it into the queue. */
-
         ++instance->common.count_of_items_in_queue;
         ++instance->common.num_states_in_collection;
 
@@ -103,7 +97,6 @@ static inline void instance_check_key(
 
         fcs_offloading_queue__insert(
             &(instance->queue), ((offloading_queue_item *)(&token)));
-        ++instance->common.count_of_items_in_queue;
     }
 }
 
@@ -125,7 +118,7 @@ static void *instance_run_solver_thread(void *const void_arg)
     fcs_delta_stater *const delta_stater = &(thread->delta_stater);
 
     fcs_dbm_queue_item *item = NULL, *prev_item = NULL;
-    long queue_num_extracted_and_processed = 0;
+    unsigned long queue_num_extracted_and_processed = 0;
 
     compact_allocator derived_list_allocator;
     fc_solve_compact_allocator_init(
@@ -140,9 +133,9 @@ static void *instance_run_solver_thread(void *const void_arg)
     fcs_state_locs_struct locs;
     fc_solve_init_locs(&locs);
 #endif
-    while (1)
+    while (true)
     {
-        /* First of all extract an item. */
+        // First of all extract an item.
         fcs_lock_lock(&instance->common.storage_lock);
 
         if (prev_item)
@@ -177,23 +170,21 @@ static void *instance_run_solver_thread(void *const void_arg)
 
         if (!item)
         {
-            /* Sleep until more items become available in the
-             * queue. */
+            // Sleep until more items become available in the queue.
             const struct timespec ts = {.tv_sec = 0, .tv_nsec = 5000000};
             struct timespec no_use;
             nanosleep(&ts, &no_use);
         }
         else
         {
-            /* Handle item. */
+            // Handle item.
             fc_solve_delta_stater_decode_into_state(
                 delta_stater, item->key.s, &state, indirect_stacks_buffer);
-            /* A section for debugging. */
             FCS__OUTPUT_STATE(out_fh, "", &(state.s), &locs);
 
             if (instance_solver_thread_calc_derived_states(local_variant,
                     &state, token, &derived_list, &derived_list_recycle_bin,
-                    &derived_list_allocator, TRUE))
+                    &derived_list_allocator, true))
             {
                 fcs_lock_lock(&instance->common.storage_lock);
                 fcs_dbm__found_solution(&(instance->common), token, item);
@@ -201,7 +192,7 @@ static void *instance_run_solver_thread(void *const void_arg)
                 break;
             }
 
-            /* Encode all the states. */
+            // Encode all the states.
             for (var_AUTO(derived_iter, derived_list); derived_iter;
                  derived_iter = derived_iter->next)
             {
@@ -220,9 +211,8 @@ static void *instance_run_solver_thread(void *const void_arg)
 
             fcs_derived_state_list__recycle(
                 &derived_list_recycle_bin, &derived_list);
-            /* End handle item. */
         }
-        /* End of main thread loop */
+        // End of main thread loop
         prev_item = item;
     }
 
@@ -234,7 +224,8 @@ static void *instance_run_solver_thread(void *const void_arg)
 static bool populate_instance_with_intermediate_input_line(
     dbm_solver_instance *const instance, fcs_delta_stater *const delta,
     fcs_state_keyval_pair *const init_state_ptr, char *const line,
-    const long line_num, fcs_encoded_state_buffer *const parent_state_enc)
+    const unsigned long line_num,
+    fcs_encoded_state_buffer *const parent_state_enc)
 {
     fcs_encoded_state_buffer final_stack_encoded_state;
     fcs_encoded_state_buffer running_key;
@@ -259,27 +250,25 @@ static bool populate_instance_with_intermediate_input_line(
         unsigned int hex_digits;
         if (sscanf(s_ptr, "%2X", &hex_digits) != 1)
         {
-            fc_solve_err("Error in reading state in line %ld of the "
-                         "--intermediate-input",
+            exit_error("Error in reading state in line %lu of the "
+                       "--intermediate-input",
                 line_num);
         }
 #ifdef FCS_DEBONDT_DELTA_STATES
-        final_stack_encoded_state.s[(s_ptr - line) >> 1] =
-            (unsigned char)hex_digits;
+        final_stack_encoded_state.s[(s_ptr - line) >> 1] = (uint8_t)hex_digits;
 #else
         final_stack_encoded_state.s[++final_stack_encoded_state.s[0]] =
-            (unsigned char)hex_digits;
+            (uint8_t)hex_digits;
 #endif
         s_ptr += 2;
     }
 
-    /* Skip the '|'. */
+    // Skip the '|' character
     ++s_ptr;
 
     FCS_STATE__DUP_keyval_pair(running_state, *init_state_ptr);
 
-    /* The NULL parent and move for indicating this is the initial
-     * state. */
+    // The NULL parent and move for indicating this is the initial state.
     fcs_init_and_encode_state(
         delta, local_variant, &(running_state), &running_key);
     fcs_dbm_record *running_parent = NULL;
@@ -290,7 +279,7 @@ static bool populate_instance_with_intermediate_input_line(
         &running_parent, running_moves, '\0');
 #else
     running_parent = fc_solve_dbm_store_insert_key_value(
-        instance->cache_store.store, &(running_key), running_parent, TRUE);
+        instance->cache_store.store, &(running_key), running_parent, true);
 #endif
     ++instance->common.num_states_in_collection;
 
@@ -305,11 +294,11 @@ static bool populate_instance_with_intermediate_input_line(
 
         const_AUTO(move, (fcs_fcc_move)hex_digits);
         /* Apply the move. */
-        int src = (move & 0xF);
-        int dest = ((move >> 4) & 0xF);
+        stack_i src = (move & 0xF);
+        stack_i dest = ((move >> 4) & 0xF);
 
 #define the_state (running_state.s)
-        /* Extract the card from the source. */
+        // Extract the card from the source.
         if (src < 8)
         {
             var_AUTO(src_col, fcs_state_get_col(the_state, src));
@@ -320,9 +309,9 @@ static bool populate_instance_with_intermediate_input_line(
             src -= 8;
             if (src >= 4)
             {
-                fc_solve_err("Error in reading state in line %ld of the "
-                             "--intermediate-input - source cannot be a "
-                             "foundation.",
+                exit_error("Error in reading state in line %lu of the "
+                           "--intermediate-input - source cannot be a "
+                           "foundation.",
                     line_num);
             }
 #if MAX_NUM_FREECELLS > 0
@@ -332,7 +321,7 @@ static bool populate_instance_with_intermediate_input_line(
             abort();
 #endif
         }
-        /* Apply src_card to dest. */
+        // Apply src_card to dest.
         if (dest < 8)
         {
             fcs_state_push(&the_state, dest, src_card);
@@ -368,10 +357,10 @@ static bool populate_instance_with_intermediate_input_line(
         }
 #else
         token = fc_solve_dbm_store_insert_key_value(
-            instance->cache_store.store, &(running_key), running_parent, TRUE);
+            instance->cache_store.store, &(running_key), running_parent, true);
         if (!token)
         {
-            return FALSE;
+            return false;
         }
 #endif
         ++instance->common.num_states_in_collection;
@@ -389,16 +378,16 @@ static bool populate_instance_with_intermediate_input_line(
     if (memcmp(&running_key, &final_stack_encoded_state, sizeof(running_key)) !=
         0)
     {
-        fc_solve_err("Error in reading state in line %ld of the "
-                     "--intermediate-input - final state does not match "
-                     "that with all states applied.\n",
+        exit_error("Error in reading state in line %lu of the "
+                   "--intermediate-input - final state does not match "
+                   "that with all states applied.\n",
             line_num);
     }
     fcs_offloading_queue__insert(
         &(instance->queue), (const offloading_queue_item *)(&token));
     ++instance->common.count_of_items_in_queue;
 
-    return TRUE;
+    return true;
 }
 
 #include "dbm_procs_inner.h"
@@ -416,7 +405,8 @@ static void instance_run_all_threads(dbm_solver_instance *const instance,
         if (pthread_create(&(threads[i].id), NULL, instance_run_solver_thread,
                 &(threads[i].arg)))
         {
-            fc_solve_err("Worker Thread No. %zu Initialization failed!\n", i);
+            exit_error("Worker Thread No. %lu Initialization failed!\n",
+                (unsigned long)i);
         }
     }
 
@@ -433,7 +423,7 @@ static bool handle_and_destroy_instance_solution(
     dbm_solver_instance *const instance, fcs_delta_stater *const delta)
 {
     FILE *const out_fh = instance->common.out_fh;
-    bool ret = FALSE;
+    bool ret = false;
     fcs_dbm_record *token;
 #ifdef DEBUG_OUT
     fcs_dbm_variant_type local_variant = instance->common.variant;
@@ -445,7 +435,7 @@ static bool handle_and_destroy_instance_solution(
     if (instance->common.queue_solution_was_found)
     {
         trace_solution(instance, out_fh, delta);
-        ret = TRUE;
+        ret = true;
     }
     else if (instance->common.should_terminate != DONT_TERMINATE)
     {
@@ -486,16 +476,14 @@ static bool handle_and_destroy_instance_solution(
                     }
                 }
 #else
-                int trace_num;
+                size_t trace_num;
                 fcs_encoded_state_buffer *trace;
                 calc_trace(token, &trace, &trace_num);
 
-/*
- * We stop at 1 because the deepest state does not contain
- * a move (as it is the ultimate state).
- * */
+// We stop at 1 because the deepest state does not contain a move (as it is the
+// ultimate state).
 #define PENULTIMATE_DEPTH 1
-                for (int i = trace_num - 1; i >= PENULTIMATE_DEPTH; i--)
+                for (int i = (int)trace_num - 1; i >= PENULTIMATE_DEPTH; i--)
                 {
                     fprintf(out_fh, "%.2X,",
                         get_move_from_parent_to_child(
@@ -521,7 +509,7 @@ static bool handle_and_destroy_instance_solution(
         }
         else if (instance->common.should_terminate == MAX_ITERS_TERMINATE)
         {
-            fprintf(out_fh, "Reached Max-or-more iterations of %ld.\n",
+            fprintf(out_fh, "Reached Max-or-more iterations of %lu.\n",
                 instance->common.max_count_num_processed);
         }
     }
@@ -538,10 +526,11 @@ static bool handle_and_destroy_instance_solution(
 
 int main(int argc, char *argv[])
 {
-    long start_line = 1;
+    apr_initialize();
+    unsigned long start_line = 1;
     const char *out_filename = NULL, *intermediate_input_filename = NULL;
     FILE *intermediate_in_fh = NULL;
-    bool skip_queue_output = FALSE;
+    bool skip_queue_output = false;
     DECLARE_IND_BUF_T(init_indirect_stacks_buffer)
     const char *param;
     fcs_dbm_common_input inp = fcs_dbm_common_input_init;
@@ -554,7 +543,7 @@ int main(int argc, char *argv[])
         }
         else if ((param = TRY_P("--start-line")))
         {
-            start_line = atol(param);
+            start_line = (unsigned long)atol(param);
         }
         else if ((param = TRY_P("-o")))
         {
@@ -572,14 +561,15 @@ int main(int argc, char *argv[])
 
     if (arg < argc - 1)
     {
-        fc_solve_err("%s\n", "Junk arguments!");
+        exit_error("%s\n", "Junk arguments!");
     }
     if (arg == argc)
     {
-        fc_solve_err("%s\n", "No board specified.");
+        exit_error("%s\n", "No board specified.");
     }
+#ifndef FCS_DBM_SINGLE_THREAD
     const_AUTO(num_threads, inp.num_threads);
-
+#endif
     FILE *const out_fh = calc_out_fh(out_filename);
     fcs_state_keyval_pair init_state;
     read_state_from_file(inp.local_variant, argv[arg],
@@ -596,7 +586,7 @@ int main(int argc, char *argv[])
         intermediate_in_fh = fopen(intermediate_input_filename, "rt");
         if (!intermediate_in_fh)
         {
-            fc_solve_err(
+            exit_error(
                 "Could not open file '%s' as --intermediate-input-filename.\n",
                 intermediate_input_filename);
         }
@@ -611,28 +601,29 @@ int main(int argc, char *argv[])
         size_t line_size = 16000;
         char *line = SMALLOC(line, line_size);
 #endif
-        long line_num = 0;
-        bool queue_solution_was_found = FALSE;
+        unsigned long line_num = 0;
+        bool queue_solution_was_found = false;
         dbm_solver_instance queue_instance;
         dbm_solver_instance limit_instance;
 
-        instance_init(&queue_instance, &inp, -1, out_fh);
-        instance_init(&limit_instance, &inp, inp.iters_delta_limit, out_fh);
+        instance_init(&queue_instance, &inp, ULONG_MAX, ULONG_MAX, out_fh);
+        instance_init(
+            &limit_instance, &inp, inp.iters_delta_limit, ULONG_MAX, out_fh);
 
         bool found_line;
         do
         {
             ++line_num;
-            found_line = FALSE;
+            found_line = false;
 #ifdef HAVE_GETLINE
             while (getline(&line, &line_size, intermediate_in_fh) >= 0)
 #else
-            while (fgets(line, line_size - 1, intermediate_in_fh))
+            while (fgets(line, (int)line_size - 1, intermediate_in_fh))
 #endif
             {
                 if (strchr(line, '|') != NULL)
                 {
-                    found_line = TRUE;
+                    found_line = true;
                     break;
                 }
                 ++line_num;
@@ -644,7 +635,7 @@ int main(int argc, char *argv[])
                 {
                     continue;
                 }
-                skip_queue_output = FALSE;
+                skip_queue_output = false;
                 {
                     fcs_encoded_state_buffer parent_state_enc;
                     if (!populate_instance_with_intermediate_input_line(
@@ -660,15 +651,15 @@ int main(int argc, char *argv[])
                     if (limit_instance.common.queue_solution_was_found)
                     {
                         trace_solution(&limit_instance, out_fh, &delta);
-                        skip_queue_output = TRUE;
-                        queue_solution_was_found = TRUE;
+                        skip_queue_output = true;
+                        queue_solution_was_found = true;
                     }
                     else if (limit_instance.common.should_terminate ==
                              MAX_ITERS_TERMINATE)
                     {
                         fprintf(out_fh,
-                            "Reached Max-or-more iterations of %ld "
-                            "in intermediate-input line No. %ld.\n",
+                            "Reached Max-or-more iterations of %lu "
+                            "in intermediate-input line No. %lu.\n",
                             limit_instance.common.max_count_num_processed,
                             line_num);
                     }
@@ -677,9 +668,9 @@ int main(int argc, char *argv[])
                     {
                         fprintf(out_fh,
                             "Pruning due to unsolvability in "
-                            "intermediate-input line No. %ld\n",
+                            "intermediate-input line No. %lu\n",
                             line_num);
-                        skip_queue_output = TRUE;
+                        skip_queue_output = true;
                     }
                 }
 
@@ -699,17 +690,15 @@ int main(int argc, char *argv[])
                     if (handle_and_destroy_instance_solution(
                             &queue_instance, &delta))
                     {
-                        queue_solution_was_found = TRUE;
+                        queue_solution_was_found = true;
                     }
                 }
             }
 
             if (!queue_solution_was_found)
             {
-                /*
-                 * This recycles the instances by keeping the cache,
-                 * but making sure that the statistics and the queue are reset.
-                 * */
+                // This recycles the instances by keeping the cache,
+                // but making sure that the statistics and the queue are reset.
                 instance_recycle(&limit_instance);
                 instance_recycle(&queue_instance);
             }
@@ -723,11 +712,13 @@ int main(int argc, char *argv[])
 
         free(line);
         line = NULL;
+        fclose(intermediate_in_fh);
     }
     else
     {
         dbm_solver_instance instance;
-        instance_init(&instance, &inp, inp.iters_delta_limit, out_fh);
+        instance_init(
+            &instance, &inp, inp.iters_delta_limit, ULONG_MAX, out_fh);
         fcs_encoded_state_buffer *key_ptr;
 #define KEY_PTR() (key_ptr)
         fcs_encoded_state_buffer parent_state_enc;
@@ -735,8 +726,8 @@ int main(int argc, char *argv[])
         key_ptr = &(instance.common.first_key);
         fcs_init_and_encode_state(
             &delta, local_variant, &(init_state), KEY_PTR());
-        /* The NULL parent_state_enc and move for indicating this is the
-         * initial state. */
+        // The NULL parent_state_enc and move for indicating this is the
+        // initial state.
         fcs_init_encoded_state(&(parent_state_enc));
 
         fcs_dbm_record *token;
@@ -745,7 +736,7 @@ int main(int argc, char *argv[])
             &(instance.cache_store), KEY_PTR(), &parent_state_enc, NULL, '\0');
 #else
         token = fc_solve_dbm_store_insert_key_value(
-            instance.cache_store.store, KEY_PTR(), NULL, TRUE);
+            instance.cache_store.store, KEY_PTR(), NULL, true);
 #endif
 
         fcs_offloading_queue__insert(
@@ -762,10 +753,7 @@ int main(int argc, char *argv[])
     {
         fclose(out_fh);
     }
-    if (intermediate_in_fh)
-    {
-        fclose(intermediate_in_fh);
-    }
 
+    apr_terminate();
     return 0;
 }
