@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 /*
  * delta_states.h - header file for common functions to the delta_states
  * functionality.
@@ -17,7 +15,7 @@
 extern "C" {
 #endif
 
-#include "bit_rw.h"
+#include "rinutils/bit_rw.h"
 #include "dbm_common.h"
 
 #ifdef FCS_DEBONDT_DELTA_STATES
@@ -28,11 +26,11 @@ extern "C" {
 
 typedef struct
 {
-    FCS_ON_NOT_FC_ONLY(int sequences_are_built_by);
+    FCS_ON_NOT_FC_ONLY(int sequences_are_built_by;)
     int num_freecells;
     size_t num_columns;
     fcs_state *init_state, *derived_state;
-    int bits_per_orig_cards_in_column;
+    size_t bits_per_orig_cards_in_column;
     int card_states[CARD_ARRAY_LEN];
     int8_t bakers_dozen_topmost_cards_lookup[((1 << 6) / 8) + 1];
     fcs_var_base_reader r;
@@ -43,11 +41,11 @@ typedef struct
 #define FCS_ENCODED_STATE_COUNT_CHARS 24
 typedef struct
 {
-    FCS_ON_NOT_FC_ONLY(int sequences_are_built_by);
+    FCS_ON_NOT_FC_ONLY(int sequences_are_built_by;)
     size_t num_freecells;
     size_t num_columns;
     fcs_state *init_state, *derived_state;
-    int bits_per_orig_cards_in_column;
+    size_t bits_per_orig_cards_in_column;
 } fcs_delta_stater;
 #endif
 
@@ -59,7 +57,7 @@ static inline void fc_solve_delta_stater_set_derived(
 
 typedef struct
 {
-    unsigned char s[FCS_ENCODED_STATE_COUNT_CHARS];
+    uint8_t s[FCS_ENCODED_STATE_COUNT_CHARS];
 } fcs_encoded_state_buffer;
 
 #if SIZEOF_VOID_P == 4
@@ -73,7 +71,7 @@ typedef struct
     fcs_encoded_state_buffer key;
     uintptr_t parent_and_refcount;
 #ifdef FCS_EXPLICIT_REFCOUNT
-    unsigned char refcount;
+    uint8_t refcount;
 #endif
 } fcs_dbm_record;
 
@@ -104,28 +102,28 @@ static inline void fcs_dbm_record_set_parent_ptr(
 }
 
 #ifdef FCS_EXPLICIT_REFCOUNT
-static inline unsigned char fcs_dbm_record_get_refcount(
+static inline uint8_t fcs_dbm_record_get_refcount(
     const fcs_dbm_record *const rec)
 {
     return rec->refcount;
 }
 #else
-static inline unsigned char fcs_dbm_record_get_refcount(
+static inline uint8_t fcs_dbm_record_get_refcount(
     const fcs_dbm_record *const rec)
 {
-    return (unsigned char)(rec->parent_and_refcount >> FCS_DBM_RECORD_SHIFT);
+    return (uint8_t)(rec->parent_and_refcount >> FCS_DBM_RECORD_SHIFT);
 }
 #endif
 
 #ifdef FCS_EXPLICIT_REFCOUNT
 static inline void fcs_dbm_record_set_refcount(
-    fcs_dbm_record *const rec, const unsigned char new_val)
+    fcs_dbm_record *const rec, const uint8_t new_val)
 {
     rec->refcount = new_val;
 }
 #else
 static inline void fcs_dbm_record_set_refcount(
-    fcs_dbm_record *const rec, const unsigned char new_val)
+    fcs_dbm_record *const rec, const uint8_t new_val)
 {
     rec->parent_and_refcount &=
         (~(((const uintptr_t)0xFF) << FCS_DBM_RECORD_SHIFT));
@@ -140,10 +138,10 @@ static inline void fcs_dbm_record_increment_refcount(fcs_dbm_record *const rec)
 }
 
 /* Returns the new value so we can tell if it is zero. */
-static inline unsigned char fcs_dbm_record_decrement_refcount(
+static inline uint8_t fcs_dbm_record_decrement_refcount(
     fcs_dbm_record *const rec)
 {
-    const unsigned char new_val = fcs_dbm_record_get_refcount(rec) - 1;
+    const uint8_t new_val = fcs_dbm_record_get_refcount(rec) - 1;
 
     fcs_dbm_record_set_refcount(rec, new_val);
 
