@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2011 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2011 Shlomi Fish
 // delta_states_debondt_impl.h - "delta states" are an encoding of states,
 // where the states are encoded and decoded based on a compact delta from the
 // initial state.
@@ -147,7 +145,7 @@ static void fc_solve_delta_stater_encode_composite(fcs_delta_stater *const self,
 
     fc_solve_delta_stater__init_card_states(self);
 
-    for (int suit_idx = 0; suit_idx < FCS_NUM_SUITS; ++suit_idx)
+    for (size_t suit_idx = 0; suit_idx < FCS_NUM_SUITS; ++suit_idx)
     {
         const unsigned long rank = fcs_foundation_value(*derived, suit_idx);
 
@@ -161,7 +159,7 @@ static void fc_solve_delta_stater_encode_composite(fcs_delta_stater *const self,
 #define CARD_STATE(card) self->card_states[CARD_POS(card)]
 #define SET_CARD_STATE(card, opt) CARD_STATE(card) = (opt)
 #define RS_STATE(rank, suit_idx) CARD_STATE(fcs_make_card(rank, suit_idx))
-            RS_STATE(r, suit_idx) = OPT_DONT_CARE;
+            RS_STATE(((fcs_card)r), ((fcs_card)suit_idx)) = OPT_DONT_CARE;
         }
     }
 
@@ -261,12 +259,14 @@ static void fc_solve_delta_stater_encode_composite(fcs_delta_stater *const self,
     {
         for (int suit_idx = 0; suit_idx < FCS_NUM_SUITS; ++suit_idx)
         {
-            const unsigned long opt = RS_STATE(rank, suit_idx);
+            const unsigned long opt =
+                (unsigned long)RS_STATE((fcs_card)rank, (fcs_card)suit_idx);
             unsigned long base;
 
             if (IS_BAKERS_DOZEN())
             {
-                const_AUTO(card, fcs_card2char(fcs_make_card(rank, suit_idx)));
+                const_AUTO(card, fcs_card2char(fcs_make_card(
+                                     (fcs_card)rank, (fcs_card)suit_idx)));
 
                 if (self->bakers_dozen_topmost_cards_lookup[card >> 3] &
                     (1 << (card & (8 - 1))))
@@ -306,7 +306,8 @@ static inline void delta_stater__fill_column_with_descendent_cards(
                              : ((fcs_card_suit(parent_card) & (0x1)) ^ 0x1));
              suit < FCS_NUM_SUITS; suit += (IS_BAKERS_DOZEN() ? 1 : 2))
         {
-            const fcs_card candidate_card = fcs_make_card(candidate_rank, suit);
+            const fcs_card candidate_card =
+                fcs_make_card((fcs_card)candidate_rank, (fcs_card)suit);
 
             if (CARD_STATE(candidate_card) == wanted_opt)
             {
@@ -338,7 +339,7 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
 
         for (unsigned long rank = 1; rank <= foundation_rank; ++rank)
         {
-            RS_STATE(rank, suit_idx) = OPT_IN_FOUNDATION;
+            RS_STATE((fcs_card)rank, (fcs_card)suit_idx) = OPT_IN_FOUNDATION;
         }
 
         fcs_set_foundation(*ret, suit_idx, foundation_rank);
@@ -356,14 +357,14 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
     const_SLOT(num_freecells, self);
 #endif
 
-    bool orig_top_most_cards[CARD_ARRAY_LEN] = {FALSE};
+    bool orig_top_most_cards[CARD_ARRAY_LEN] = {false};
     for (size_t col_idx = 0; col_idx < self->num_columns; ++col_idx)
     {
         const_AUTO(col, fcs_state_get_col(*init_state, col_idx));
 
         if (fcs_col_len(col))
         {
-            orig_top_most_cards[CARD_POS(fcs_col_get_card(col, 0))] = TRUE;
+            orig_top_most_cards[CARD_POS(fcs_col_get_card(col, 0))] = true;
         }
     }
 
@@ -372,7 +373,7 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
     {
         for (int suit_idx = 0; suit_idx < FCS_NUM_SUITS; ++suit_idx)
         {
-            const fcs_card card = fcs_make_card(RANK_KING, suit_idx);
+            const fcs_card card = fcs_make_card(RANK_KING, (fcs_card)suit_idx);
 
             if (!IS_IN_FOUNDATIONS(card))
             {
@@ -390,7 +391,8 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
     {
         for (int suit_idx = 0; suit_idx < FCS_NUM_SUITS; ++suit_idx)
         {
-            const fcs_card card = fcs_make_card(rank, suit_idx);
+            const fcs_card card =
+                fcs_make_card((fcs_card)rank, (fcs_card)suit_idx);
             const_AUTO(card_char, fcs_card2char(card));
 
             if (IS_BAKERS_DOZEN())
@@ -406,13 +408,14 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
                 }
             }
 
-            const int existing_opt = RS_STATE(rank, suit_idx);
+            const int existing_opt =
+                RS_STATE((fcs_card)rank, (fcs_card)suit_idx);
 
             if (rank == 1)
             {
                 if (existing_opt < 0)
                 {
-                    RS_STATE(rank, suit_idx) = orig_pos_opt;
+                    RS_STATE((fcs_card)rank, (fcs_card)suit_idx) = orig_pos_opt;
                 }
             }
             else
@@ -426,7 +429,8 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
 
                 if (existing_opt < 0)
                 {
-                    RS_STATE(rank, suit_idx) = item_opt;
+                    RS_STATE((fcs_card)rank, (fcs_card)suit_idx) =
+                        (int)item_opt;
 
                     if (!IS_BAKERS_DOZEN())
                     {
@@ -524,7 +528,7 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
 
 static inline void fc_solve_delta_stater_decode_into_state_proto(
     const fcs_dbm_variant_type local_variant,
-    fcs_delta_stater *const delta_stater, const fcs_uchar *const enc_state,
+    fcs_delta_stater *const delta_stater, const rin_uchar *const enc_state,
     fcs_state_keyval_pair *const ret IND_BUF_T_PARAM(indirect_stacks_buffer))
 {
     fc_solve_var_base_reader_start(
