@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2011 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2011 Shlomi Fish
 // delta_states_impl.h - "delta states" are an encoding of states, where the
 // states are encoded and decoded based on a compact delta from the initial
 // state.
@@ -14,11 +12,11 @@
 #include "delta_states.h"
 
 #ifndef FCS_DEBONDT_DELTA_STATES
-static int fc_solve_get_column_orig_num_cards(
+static stack_i fc_solve_get_column_orig_num_cards(
     fcs_delta_stater *const self GCC_UNUSED, const fcs_const_cards_column col)
 {
     FCS_ON_NOT_FC_ONLY(const_SLOT(sequences_are_built_by, self));
-    for (int num_cards = fcs_col_len(col); num_cards >= 2; --num_cards)
+    for (stack_i num_cards = fcs_col_len(col); num_cards >= 2; --num_cards)
     {
         if (!fcs_is_parent_card(fcs_col_get_card(col, num_cards - 1),
                 fcs_col_get_card(col, num_cards - 2)))
@@ -32,7 +30,7 @@ static int fc_solve_get_column_orig_num_cards(
 static void fc_solve_delta_stater_init(fcs_delta_stater *const self,
     const fcs_dbm_variant_type local_variant GCC_UNUSED,
     fcs_state *const init_state, const size_t num_columns,
-    const int num_freecells PASS_ON_NOT_FC_ONLY(
+    const size_t num_freecells PASS_ON_NOT_FC_ONLY(
         const int sequences_are_built_by))
 {
     FCS_ON_NOT_FC_ONLY(self->sequences_are_built_by = sequences_are_built_by);
@@ -40,7 +38,7 @@ static void fc_solve_delta_stater_init(fcs_delta_stater *const self,
     self->num_freecells = num_freecells;
     self->init_state = init_state;
 
-    int max_num_cards = 0;
+    stack_i max_num_cards = 0;
     for (size_t col_idx = 0; col_idx < num_columns; ++col_idx)
     {
         const_AUTO(num_cards, fc_solve_get_column_orig_num_cards(self,
@@ -53,8 +51,8 @@ static void fc_solve_delta_stater_init(fcs_delta_stater *const self,
     }
 
     {
-        int bitmask = 1;
-        int num_bits = 0;
+        stack_i bitmask = 1;
+        stack_i num_bits = 0;
 
         while (bitmask <= max_num_cards)
         {
@@ -79,23 +77,23 @@ typedef struct
         COL_TYPE_ENTIRELY_NON_ORIG,
         COL_TYPE_HAS_ORIG
     } type;
-    fcs_uchar enc[4];
-    fcs_uchar *end;
-    int bit_in_char_idx;
+    rin_uchar enc[4];
+    rin_uchar *end;
+    size_t bit_in_char_idx;
 } fcs_column_encoding_composite;
 
 static inline void fc_solve_get_column_encoding_composite(
-    fcs_delta_stater *const self, const int col_idx,
+    fcs_delta_stater *const self, const stack_i col_idx,
     fcs_column_encoding_composite *const ret)
 {
     const fcs_state *const derived = self->derived_state;
     const_AUTO(col, fcs_state_get_col(*derived, col_idx));
 
     const_AUTO(num_orig_cards, fc_solve_get_column_orig_num_cards(self, col));
-    const int col_len = fcs_col_len(col);
-    const int num_derived_cards = col_len - num_orig_cards;
+    const stack_i col_len = fcs_col_len(col);
+    const stack_i num_derived_cards = col_len - num_orig_cards;
 
-    int_fast16_t num_cards_in_seq = num_derived_cards;
+    stack_i num_cards_in_seq = num_derived_cards;
     fcs_card init_card = fc_solve_empty_card;
 
     if ((num_orig_cards == 0) && num_derived_cards)
@@ -105,24 +103,23 @@ static inline void fc_solve_get_column_encoding_composite(
     }
 
     /* Prepare the encoding. */
-    fc_solve_bit_writer bit_w;
-    fc_solve_bit_writer_init(&bit_w, ret->enc);
+    rin_bit_writer bit_w;
+    rin_bit_writer_init_and_clear(&bit_w, ret->enc);
 
-    fc_solve_bit_writer_write(
+    rin_bit_writer_write(
         &bit_w, self->bits_per_orig_cards_in_column, num_orig_cards);
 
-    fc_solve_bit_writer_write(&bit_w, 4, num_derived_cards);
+    rin_bit_writer_write(&bit_w, 4, num_derived_cards);
 
     if (fcs_card_is_valid(init_card))
     {
-        fc_solve_bit_writer_write(&bit_w, 6, fcs_card2char(init_card));
+        rin_bit_writer_write(&bit_w, 6, fcs_card2char(init_card));
     }
 
-    for (int i = col_len - num_cards_in_seq; i < col_len; ++i)
+    for (stack_i i = col_len - num_cards_in_seq; i < col_len; ++i)
     {
 #define GET_SUIT_BIT(card) (((fcs_card_suit(card)) & 0x2) >> 1)
-        fc_solve_bit_writer_write(
-            &bit_w, 1, GET_SUIT_BIT(fcs_col_get_card(col, i)));
+        rin_bit_writer_write(&bit_w, 1, GET_SUIT_BIT(fcs_col_get_card(col, i)));
 #undef GET_SUIT_BIT
     }
 
@@ -137,7 +134,7 @@ static inline void fc_solve_get_column_encoding_composite(
 
 #if MAX_NUM_FREECELLS > 0
 static inline void fc_solve_get_freecells_encoding(
-    fcs_delta_stater *const self, fc_solve_bit_writer *const bit_w)
+    fcs_delta_stater *const self, rin_bit_writer *const bit_w)
 {
     const fcs_state *const derived = self->derived_state;
     const_SLOT(num_freecells, self);
@@ -160,7 +157,7 @@ static inline void fc_solve_get_freecells_encoding(
             }
         }
         const_AUTO(i_card, freecells[i]);
-        fc_solve_bit_writer_write(bit_w, 6,
+        rin_bit_writer_write(bit_w, 6,
             fcs_card2char((min_idx != i) ? ({
                 const_AUTO(min_card, freecells[min_idx]);
                 freecells[min_idx] = i_card;
@@ -175,7 +172,7 @@ static inline void fc_solve_delta__promote_empty_cols(const size_t num_columns,
     int *const cols_indexes, fcs_column_encoding_composite *const cols)
 {
     size_t non_orig_idx = 0;
-    ssize_t empty_col_idx = num_columns - 1;
+    ssize_t empty_col_idx = (ssize_t)num_columns - 1;
 
     while (1)
     {
@@ -215,7 +212,7 @@ static inline void fc_solve_delta__promote_empty_cols(const size_t num_columns,
 }
 
 static void fc_solve_delta_stater_encode_composite(
-    fcs_delta_stater *const self, fc_solve_bit_writer *const bit_w)
+    fcs_delta_stater *const self, rin_bit_writer *const bit_w)
 {
     int cols_indexes[MAX_NUM_STACKS];
     fcs_column_encoding_composite cols[MAX_NUM_STACKS];
@@ -224,7 +221,7 @@ static void fc_solve_delta_stater_encode_composite(
     const_SLOT(num_columns, self);
     for (size_t i = 0; i < num_columns; ++i)
     {
-        cols_indexes[i] = i;
+        cols_indexes[i] = (int)i;
         fc_solve_get_column_encoding_composite(self, i, &(cols[i]));
     }
 
@@ -282,19 +279,19 @@ static void fc_solve_delta_stater_encode_composite(
     {
         const fcs_column_encoding_composite *const col_enc =
             (cols + cols_indexes[i]);
-        const fcs_uchar *enc;
-        const fcs_uchar *const end = col_enc->end;
+        const rin_uchar *enc;
+        const rin_uchar *const end = col_enc->end;
         for (enc = col_enc->enc; enc < end; ++enc)
         {
-            fc_solve_bit_writer_write(bit_w, NUM_BITS_IN_BYTES, (*enc));
+            rin_bit_writer_write(bit_w, NUM_BITS_IN_BYTES, (*enc));
         }
-        fc_solve_bit_writer_write(bit_w, col_enc->bit_in_char_idx, (*enc));
+        rin_bit_writer_write(bit_w, col_enc->bit_in_char_idx, (*enc));
     }
 }
 
 /* ret must be an empty state. */
 static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
-    fcs_bit_reader *const bit_r, fcs_state *const ret)
+    rin_bit_reader *const bit_r, fcs_state *const ret)
 {
 #define PROCESS_CARD(card)                                                     \
     if (fcs_card_rank(card) < foundations[fcs_card_suit(card)])                \
@@ -311,7 +308,8 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
     const_SLOT(num_freecells, self);
     for (size_t i = 0; i < num_freecells; ++i)
     {
-        const fcs_card card = fcs_char2card(fc_solve_bit_reader_read(bit_r, 6));
+        const fcs_card card =
+            fcs_char2card((fcs_card)rin_bit_reader_read(bit_r, 6));
         if (fcs_card_is_valid(card))
         {
             PROCESS_CARD(card);
@@ -326,24 +324,24 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
     for (size_t col_idx = 0; col_idx < num_columns; ++col_idx)
     {
         const_AUTO(col, fcs_state_get_col(*ret, col_idx));
-        const int num_orig_cards =
-            fc_solve_bit_reader_read(bit_r, bits_per_orig_cards_in_column);
+        const stack_i num_orig_cards =
+            rin_bit_reader_read(bit_r, bits_per_orig_cards_in_column);
         const_AUTO(orig_col, fcs_state_get_col(*init_state, col_idx));
 
-        for (int i = 0; i < num_orig_cards; ++i)
+        for (stack_i i = 0; i < num_orig_cards; ++i)
         {
             const fcs_card card = fcs_col_get_card(orig_col, i);
             PROCESS_CARD(card);
             fcs_col_push_card(col, card);
         }
 
-        const int num_derived_cards = fc_solve_bit_reader_read(bit_r, 4);
-        int_fast16_t num_cards_in_seq = num_derived_cards;
+        const stack_i num_derived_cards = rin_bit_reader_read(bit_r, 4);
+        uint_fast16_t num_cards_in_seq = num_derived_cards;
 
         if ((num_orig_cards == 0) && num_derived_cards)
         {
             const fcs_card card =
-                fcs_char2card(fc_solve_bit_reader_read(bit_r, 6));
+                fcs_char2card((fcs_card)rin_bit_reader_read(bit_r, 6));
             PROCESS_CARD(card);
             fcs_col_push_card(col, card);
 
@@ -354,13 +352,13 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
         {
             fcs_card last_card = fcs_col_get_card(col, fcs_col_len(col) - 1);
 
-            for (int_fast16_t i = 0; i < num_cards_in_seq; ++i)
+            for (uint_fast16_t i = 0; i < num_cards_in_seq; ++i)
             {
-                const int suit_bit = fc_solve_bit_reader_read(bit_r, 1);
+                const stack_i suit_bit = rin_bit_reader_read(bit_r, 1);
                 const fcs_card new_card =
                     fcs_make_card(fcs_card_rank(last_card) - 1,
-                        ((suit_bit << 1) |
-                            ((fcs_card_suit(last_card) & 0x1) ^ 0x1)));
+                        (fcs_card)((((size_t)suit_bit) << 1U) |
+                                   ((fcs_card_suit(last_card) & 0x1U) ^ 0x1U)));
 
                 PROCESS_CARD(new_card);
                 fcs_col_push_card(col, new_card);
@@ -380,11 +378,11 @@ static void fc_solve_delta_stater_decode(fcs_delta_stater *const self,
 
 static inline void fc_solve_delta_stater_decode_into_state_proto(
     const fcs_dbm_variant_type local_variant GCC_UNUSED,
-    fcs_delta_stater *const delta_stater, const fcs_uchar *const enc_state,
+    fcs_delta_stater *const delta_stater, const rin_uchar *const enc_state,
     fcs_state_keyval_pair *const ret IND_BUF_T_PARAM(indirect_stacks_buffer))
 {
-    fcs_bit_reader bit_r;
-    fc_solve_bit_reader_init(&bit_r, enc_state + 1);
+    rin_bit_reader bit_r;
+    rin_bit_reader_init(&bit_r, enc_state + 1);
     fc_solve_state_init(ret, STACKS_NUM, indirect_stacks_buffer);
     fc_solve_delta_stater_decode(delta_stater, &bit_r, &(ret->s));
 }
@@ -394,11 +392,11 @@ static inline void fc_solve_delta_stater_encode_into_buffer(
     const fcs_dbm_variant_type local_variant GCC_UNUSED,
     fcs_state_keyval_pair *const state, unsigned char *const out_enc_state)
 {
-    fc_solve_bit_writer bit_w;
-    fc_solve_bit_writer_init(&bit_w, out_enc_state + 1);
+    rin_bit_writer bit_w;
+    rin_bit_writer_init_and_clear(&bit_w, out_enc_state + 1);
     fc_solve_delta_stater_set_derived(delta_stater, &(state->s));
     fc_solve_delta_stater_encode_composite(delta_stater, &bit_w);
-    out_enc_state[0] =
-        bit_w.current - bit_w.start + (bit_w.bit_in_char_idx > 0);
+    out_enc_state[0] = (unsigned char)(bit_w.current - bit_w.start +
+                                       (bit_w.bit_in_char_idx > 0));
 }
 #endif
