@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 #pragma once
 
 #include "dbm_procs_inner.h"
@@ -14,24 +12,32 @@
 static inline void dbm__spawn_threads(dbm_solver_instance *const instance,
     const size_t num_threads, main_thread_item *const threads)
 {
-#ifdef T
     FILE *const out_fh = instance->common.out_fh;
-#endif
-    TRACE("Running threads for curr_depth=%d\n", instance->curr_depth);
-    for (size_t i = 0; i < num_threads; i++)
+    TRACE("Running threads for curr_depth=%lu\n",
+        (unsigned long)instance->curr_depth);
+    if (num_threads == 1)
     {
-        if (pthread_create(&(threads[i].id), NULL, instance_run_solver_thread,
-                &(threads[i].arg)))
+        instance_run_solver_thread(&(threads[0].arg));
+    }
+    else
+    {
+        for (size_t i = 0; i < num_threads; i++)
         {
-            fc_solve_err("Worker Thread No. %zu Initialization failed!\n", i);
+            if (pthread_create(&(threads[i].id), NULL,
+                    instance_run_solver_thread, &(threads[i].arg)))
+            {
+                exit_error("Worker Thread No. %u Initialization failed!\n",
+                    (unsigned)i);
+            }
+        }
+
+        for (size_t i = 0; i < num_threads; i++)
+        {
+            pthread_join(threads[i].id, NULL);
         }
     }
-
-    for (size_t i = 0; i < num_threads; i++)
-    {
-        pthread_join(threads[i].id, NULL);
-    }
-    TRACE("Finished running threads for curr_depth=%d\n", instance->curr_depth);
+    TRACE("Finished running threads for curr_depth=%lu\n",
+        (unsigned long)instance->curr_depth);
 }
 
 static inline void init_thread(dbm_solver_thread *const thread)
@@ -49,13 +55,13 @@ static bool handle_and_destroy_instance_solution(
     dbm_solver_instance *const instance, fcs_delta_stater *const delta)
 {
     FILE *const out_fh = instance->common.out_fh;
-    bool ret = FALSE;
+    bool ret = false;
     TRACE("%s\n", "handle_and_destroy_instance_solution start");
     instance_print_stats(instance);
     if (instance->common.queue_solution_was_found)
     {
         trace_solution(instance, out_fh, delta);
-        ret = TRUE;
+        ret = true;
     }
     else if (instance->common.should_terminate != DONT_TERMINATE)
     {
@@ -63,7 +69,7 @@ static bool handle_and_destroy_instance_solution(
         fflush(out_fh);
         if (instance->common.should_terminate == MAX_ITERS_TERMINATE)
         {
-            fprintf(out_fh, "Reached Max-or-more iterations of %ld.\n",
+            fprintf(out_fh, "Reached Max-or-more iterations of %lu.\n",
                 instance->common.max_count_num_processed);
         }
     }
