@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2013 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2013 Shlomi Fish
 /*
  * depth_multi_queue.h - header file for the depth-based / depth-tracking
  * multi-queue which can handle more than one starting point.
@@ -18,6 +16,7 @@
 extern "C" {
 #endif
 
+#include <assert.h>
 #include "offloading_queue.h"
 
 typedef struct
@@ -63,13 +62,14 @@ static inline void fcs_depth_multi_queue__insert(
         if (queue->max_depth == queue->max_depth_margin)
         {
             queue->max_depth_margin += DEPTH_Q_GROW_BY;
-            queue->queues_by_depth =
-                SREALLOC(queue->queues_by_depth, queue->max_depth_margin);
+            queue->queues_by_depth = SREALLOC(
+                queue->queues_by_depth, (size_t)queue->max_depth_margin);
         }
         fcs_depth_multi_queue__new_queue(queue,
             &(queue->queues_by_depth[queue->max_depth - queue->min_depth]));
     }
 
+    assert(depth >= queue->min_depth);
     fcs_offloading_queue__insert(
         &(queue->queues_by_depth[depth - queue->min_depth]), item);
 
@@ -86,8 +86,8 @@ static inline void fcs_depth_multi_queue__init(
     queue->min_depth = first_depth;
     queue->max_depth_margin = first_depth + DEPTH_Q_GROW_BY;
 
-    queue->queues_by_depth = SMALLOC(
-        queue->queues_by_depth, queue->max_depth_margin - queue->min_depth + 1);
+    queue->queues_by_depth = SMALLOC(queue->queues_by_depth,
+        (size_t)(queue->max_depth_margin - queue->min_depth + 1));
     fcs_depth_multi_queue__new_queue(queue, &(queue->queues_by_depth[0]));
     queue->max_depth = first_depth;
 
@@ -97,7 +97,7 @@ static inline void fcs_depth_multi_queue__init(
 static inline void fcs_depth_multi_queue__destroy(
     fcs_depth_multi_queue *const queue)
 {
-    const int limit = queue->max_depth - queue->min_depth;
+    const long limit = queue->max_depth - queue->min_depth;
     if (queue->queues_by_depth == NULL)
     {
         return;
@@ -116,26 +116,20 @@ static inline bool fcs_depth_multi_queue__extract(
 {
     if (q_stats_is_empty(&queue->stats))
     {
-        return FALSE;
+        return false;
     }
 
-    while (q_stats_is_empty(&queue->queues_by_depth[0].stats))
+    int depth = 0;
+    while (q_stats_is_empty(&queue->queues_by_depth[depth].stats))
     {
-        var_AUTO(save_queue, queue->queues_by_depth[0]);
-        memmove(queue->queues_by_depth, queue->queues_by_depth + 1,
-            sizeof(queue->queues_by_depth[0]) *
-                (queue->max_depth - queue->min_depth));
-        queue->queues_by_depth[queue->max_depth - queue->min_depth] =
-            save_queue;
-        queue->max_depth++;
-        queue->min_depth++;
-        queue->max_depth_margin++;
+        ++depth;
     }
 
-    *return_depth = queue->min_depth;
-    fcs_offloading_queue__extract(&(queue->queues_by_depth[0]), return_item);
+    *return_depth = depth + (int)queue->min_depth;
+    fcs_offloading_queue__extract(
+        &(queue->queues_by_depth[depth]), return_item);
     q_stats_extract(&queue->stats);
-    return TRUE;
+    return true;
 }
 
 #ifdef __cplusplus
