@@ -1,15 +1,13 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 #include <assert.h>
 #include "fc_pro_iface_pos.h"
-#include "rinutils.h"
+#include "rinutils/rinutils.h"
 
 #define MOVES_PROCESSED_GROW_BY 32
 static inline void moves_processed_add_new_move(
@@ -34,9 +32,9 @@ static inline bool fc_solve_fc_pro__can_be_moved(
         (fcs_foundation_value(*s, suit) == rank - 1))
     {
         fcs_increment_foundation(*s, suit);
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 DLLEXPORT void fc_solve_moves_processed_gen(fcs_moves_processed *const ret,
@@ -53,13 +51,13 @@ DLLEXPORT void fc_solve_moves_processed_gen(fcs_moves_processed *const ret,
     }
 
 #define pos (pos_proto.s)
-    int virtual_stack_len[8];
+    stack_i virtual_stack_len[8];
     const int num_back_end_moves = moves_seq->num_moves;
     var_PTR(next_move_ptr, moves_seq->moves - 1);
     ret->num_moves = 0;
     ret->moves = SMALLOC(ret->moves, MOVES_PROCESSED_GROW_BY);
     ret->next_move_idx = 0;
-    for (int i = 0; i < 8; ++i)
+    for (stack_i i = 0; i < 8; ++i)
     {
         virtual_stack_len[i] = fcs_state_col_len(pos, i);
     }
@@ -106,7 +104,7 @@ DLLEXPORT void fc_solve_moves_processed_gen(fcs_moves_processed *const ret,
                 fcs_col_pop_card(col, card);
                 fcs_increment_foundation(pos, fcs_card_suit(card));
                 moves_processed_add_new_move(ret,
-                    (fcs_extended_move){.move = move, .to_empty_stack = FALSE});
+                    (fcs_extended_move){.move = move, .to_empty_stack = false});
             }
             --virtual_stack_len[src];
         }
@@ -118,7 +116,7 @@ DLLEXPORT void fc_solve_moves_processed_gen(fcs_moves_processed *const ret,
             const int src = fcs_move_get_src_freecell(move);
             if (!fcs_freecell_is_empty(pos, src))
                 moves_processed_add_new_move(ret,
-                    (fcs_extended_move){.move = move, .to_empty_stack = FALSE});
+                    (fcs_extended_move){.move = move, .to_empty_stack = false});
             fcs_increment_foundation(
                 pos, fcs_card_suit(fcs_freecell_card(pos, src)));
             fcs_empty_freecell(pos, src);
@@ -134,7 +132,7 @@ DLLEXPORT void fc_solve_moves_processed_gen(fcs_moves_processed *const ret,
             if (!fcs_freecell_is_empty(pos, src))
             {
                 moves_processed_add_new_move(ret,
-                    (fcs_extended_move){.move = move, .to_empty_stack = FALSE});
+                    (fcs_extended_move){.move = move, .to_empty_stack = false});
                 fcs_state_push(&pos, dest, fcs_freecell_card(pos, src));
                 fcs_empty_freecell(pos, src);
             }
@@ -154,7 +152,7 @@ DLLEXPORT void fc_solve_moves_processed_gen(fcs_moves_processed *const ret,
             if (fcs_col_len(col) >= virtual_stack_len[src])
             {
                 moves_processed_add_new_move(ret,
-                    (fcs_extended_move){.move = move, .to_empty_stack = FALSE});
+                    (fcs_extended_move){.move = move, .to_empty_stack = false});
                 fcs_card temp_card;
                 fcs_col_pop_card(col, temp_card);
                 fcs_put_card_in_freecell(pos, dest, temp_card);
@@ -168,14 +166,14 @@ DLLEXPORT void fc_solve_moves_processed_gen(fcs_moves_processed *const ret,
         {
             const_AUTO(src, fcs_move_get_src_freecell(move));
             const_AUTO(dest, fcs_move_get_dest_stack(move));
-            int num_cards = fcs_move_get_num_cards_in_seq(move);
+            stack_i num_cards = fcs_move_get_num_cards_in_seq(move);
             var_AUTO(src_col, fcs_state_get_col(pos, src));
             var_AUTO(dest_col, fcs_state_get_col(pos, dest));
-            const int src_len = fcs_col_len(src_col);
+            const stack_i src_len = fcs_col_len(src_col);
             assert(virtual_stack_len[src] >= src_len);
             if (virtual_stack_len[src] > src_len)
             {
-                const int virt_num_cards =
+                const stack_i virt_num_cards =
                     min((virtual_stack_len[src] - src_len), num_cards);
                 virtual_stack_len[src] -= virt_num_cards;
                 virtual_stack_len[dest] += virt_num_cards;
