@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 /*
  * fc_pro_iface_pos.h - generate solutions in standard notation, with
  * implicit (and not included) Horne/Raymond prune moves.
@@ -37,7 +35,7 @@ void fc_solve_moves_processed_gen(fcs_moves_processed *,
     fcs_state_keyval_pair *, int, const fcs_moves_sequence_t *);
 void fc_solve_moves_processed_render_move(fcs_extended_move, char *);
 
-static inline int fc_solve_moves_processed_get_moves_left(
+static inline size_t fc_solve_moves_processed_get_moves_left(
     const fcs_moves_processed *const moves)
 {
     return moves->num_moves - moves->next_move_idx;
@@ -48,10 +46,10 @@ static inline bool fc_solve_moves_processed_get_next_move(
 {
     if (moves->next_move_idx == moves->num_moves)
     {
-        return TRUE;
+        return true;
     }
     *move = moves->moves[moves->next_move_idx++];
-    return FALSE;
+    return false;
 }
 
 static inline void fc_solve_moves_processed_free(
