@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // fc_pro_range_solver.c - the FC-Pro range solver. Solves a range of
 // boards and displays the moves counts and the number of moves in their
 // solution.
@@ -15,12 +13,13 @@
 #include "range_solvers_binary_output.h"
 #include "fc_pro_iface_pos.h"
 #include "try_param.h"
+#include "print_time.h"
 
 static inline void fc_pro_get_board(const long long deal_idx,
     fcs_state_string state_string,
     fcs_state_keyval_pair *const pos IND_BUF_T_PARAM(indirect_stacks_buffer))
 {
-    get_board_l(deal_idx, state_string);
+    get_board_l((unsigned long long)deal_idx, state_string);
     fc_solve_initial_user_state_to_c(
         state_string, pos, 4, 8, 1, indirect_stacks_buffer);
 }
@@ -32,9 +31,9 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
     long long start_board, long long end_board, const long long stop_at)
 {
     const char *variant = "freecell";
-    long long total_num_iters = 0;
+    fcs_iters_int total_num_iters = 0;
 #ifndef FCS_WITHOUT_MAX_NUM_STATES
-    bool was_total_iterations_limit_per_board_set = FALSE;
+    bool was_total_iterations_limit_per_board_set = false;
 #endif
     fcs_int_limit_t total_iterations_limit_per_board = -1;
     fcs_binary_output binary_output = INIT_BINARY_OUTPUT;
@@ -60,7 +59,7 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
         else if ((param = TRY_P("--total-iterations-limit")))
         {
 #ifndef FCS_WITHOUT_MAX_NUM_STATES
-            was_total_iterations_limit_per_board_set = TRUE;
+            was_total_iterations_limit_per_board_set = true;
             total_iterations_limit_per_board = atol(param);
 #endif
         }
@@ -76,7 +75,7 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
     fc_solve_display_information_context display_context =
         INITIAL_DISPLAY_CONTEXT;
     void *const instance = alloc_instance_and_parse(argc, argv, &arg,
-        known_parameters, cmd_line_callback, &display_context, TRUE);
+        known_parameters, cmd_line_callback, &display_context, true);
 
     bin_init(&binary_output, &start_board, &end_board,
         &total_iterations_limit_per_board);
@@ -111,12 +110,15 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
             char command[1000];
 
             sprintf(command,
-                "make_pysol_freecell_board.py -F -t " FCS_LL_FMT "%s",
+                "make_pysol_freecell_board.py -F -t " RIN_LL_FMT "%s",
                 board_num, variant);
 
             FILE *const from_make_pysol = popen(command, "r");
-            fread(
-                buffer, sizeof(buffer[0]), COUNT(buffer) - 1, from_make_pysol);
+            if (fread(buffer, sizeof(buffer[0]), COUNT(buffer) - 1,
+                    from_make_pysol) == 0)
+            {
+                abort();
+            }
             pclose(from_make_pysol);
         }
 
@@ -153,7 +155,7 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
                     &fc_pro_moves, &pos, 4, &moves_seq);
 
                 num_fcpro_moves =
-                    fc_solve_moves_processed_get_moves_left(&fc_pro_moves);
+                    (int)fc_solve_moves_processed_get_moves_left(&fc_pro_moves);
 
                 if (moves_seq.moves)
                 {
