@@ -1,16 +1,11 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
-/*
- * fcs_hash.h - header file of Freecell Solver's internal hash implementation.
- */
-
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
+// fcs_hash.h - header file of Freecell Solver's internal hash implementation.
 #pragma once
 
 #ifdef __cplusplus
@@ -18,7 +13,7 @@ extern "C" {
 #endif
 
 #include "meta_alloc.h"
-#include "rinutils.h"
+#include "rinutils/rinutils.h"
 
 #ifdef FCS_INLINED_HASH_COMPARISON
 enum FCS_INLINED_HASH_DATA_TYPE
@@ -89,14 +84,14 @@ typedef struct
 #endif
 
     /* The size of the hash table */
-    int size;
+    size_t size;
 
     /* A bit mask that extract the lowest bits out of the hash value */
-    int size_bitmask;
+    size_t size_bitmask;
     /* The number of elements stored inside the hash */
-    fcs_int_limit_t num_elems;
+    size_t num_elems;
 
-    fcs_int_limit_t max_num_elems_before_resize;
+    size_t max_num_elems_before_resize;
 
     compact_allocator allocator;
 #ifdef FCS_RCS_STATES
@@ -105,7 +100,7 @@ typedef struct
 } hash_table;
 
 static inline void fcs_hash_set_max_num_elems(
-    hash_table *const hash, const fcs_int_limit_t new_size)
+    hash_table *const hash, const size_t new_size)
 {
     hash->max_num_elems_before_resize = (new_size << 1);
 }
@@ -154,6 +149,13 @@ static inline void fc_solve_hash_init(
     fc_solve_compact_allocator_init(&(hash->allocator), meta_alloc);
 }
 
+static inline void fc_solve_hash_recycle(hash_table *const hash)
+{
+    fc_solve_compact_allocator_recycle(&(hash->allocator));
+    memset(hash->entries, '\0', sizeof(hash->entries[0]) * hash->size);
+    hash->num_elems = 0;
+}
+
 static inline void fc_solve_hash_free(hash_table *const hash)
 {
     fc_solve_compact_allocator_finish(&(hash->allocator));
@@ -168,7 +170,7 @@ static inline void fc_solve_hash_foreach(hash_table *const hash,
 {
     const_SLOT(size, hash);
     var_AUTO(entries, hash->entries);
-    for (int i = 0; i < size; i++)
+    for (size_t i = 0; i < size; ++i)
     {
         hash_item **item = &(entries[i].first_item);
         while ((*item) != NULL)
