@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // handle_parsing.h - header file for convenient wrappers for handling
 // parsing the arguments.
 #pragma once
@@ -15,11 +13,11 @@
 extern "C" {
 #endif
 
-#include "rinutils.h"
+#include "rinutils/rinutils.h"
 #ifndef FCS_USE_PRECOMPILED_CMD_LINE_THEME
 #include "freecell-solver/fcs_cl.h"
 #else
-#include "fcs_user.h"
+#include "freecell-solver/fcs_user.h"
 #include "fc_solve__precompiled__theme.h"
 #endif
 enum
@@ -52,7 +50,7 @@ static inline void *alloc_instance_and_parse(const int argc GCC_UNUSED,
     case FCS_CMD_LINE_UNRECOGNIZED_OPTION:
         if (only_recognized)
         {
-            fc_solve_err("Unknown option: %s\n", argv[*arg_ptr]);
+            exit_error("Unknown option: %s\n", argv[*arg_ptr]);
         }
         break;
     case FCS_CMD_LINE_PARAM_WITH_NO_ARG:
@@ -82,7 +80,7 @@ static inline void *alloc_instance_and_parse(const int argc GCC_UNUSED,
 static inline void *simple_alloc_and_parse(
     const int argc, char **const argv, int arg)
 {
-    return alloc_instance_and_parse(argc, argv, &arg, NULL, NULL, NULL, TRUE);
+    return alloc_instance_and_parse(argc, argv, &arg, NULL, NULL, NULL, true);
 }
 
 static inline void print_flares_plan_error(void *const instance GCC_UNUSED)
