@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // instance.c - instance/hard_thread/soft_thread functions for Freecell Solver.
 #include "instance_for_lib.h"
 #include "instance.h"
@@ -145,9 +143,9 @@ void fc_solve_foreach_soft_thread(fcs_instance *const instance,
     const foreach_st_callback_choice callback_choice, void *const context)
 {
 #ifdef FCS_SINGLE_HARD_THREAD
-    const int_fast32_t num_soft_threads =
-        instance->hard_thread.num_soft_threads;
-    for (int_fast32_t st_idx = 0; st_idx <= num_soft_threads; ++st_idx)
+    const_AUTO(num_soft_threads, instance->hard_thread.num_soft_threads);
+    for (fastest_type_for_num_soft_threads__unsigned st_idx = 0;
+         st_idx <= num_soft_threads; ++st_idx)
     {
         fcs_soft_thread *soft_thread;
         if (st_idx < num_soft_threads)
@@ -244,18 +242,18 @@ static inline
                 .by_depth_moves =
                     SMALLOC1(soft_thread->by_depth_moves_order.by_depth_moves),
             },
-        .is_befs = FALSE,
+        .is_befs = false,
 #ifdef FCS_WITH_MOVES
-        .is_optimize_scan = FALSE,
+        .is_optimize_scan = false,
 #endif
         .super_method_type = FCS_SUPER_METHOD_DFS,
-        .master_to_randomize = FALSE,
+        .master_to_randomize = false,
         .checked_states_step = 50,
 #ifndef FCS_USE_PRECOMPILED_CMD_LINE_THEME
         .name = "",
 #endif
 #ifndef FCS_ENABLE_PRUNE__R_TF__UNCOND
-        .enable_pruning = FALSE,
+        .enable_pruning = false,
 #endif
 #ifndef FCS_DISABLE_PATSOLVE
         .pats_scan = NULL,
@@ -328,7 +326,7 @@ static inline int find_empty_col(
     {
         if (fcs_state_col_is_empty(*dynamic_state, i))
         {
-            return i;
+            return (int)i;
         }
     }
 
@@ -344,7 +342,7 @@ static inline int find_col_card(
         const int col_len = fcs_col_len(col);
         if (col_len > 0 && (fcs_col_get_card(col, col_len - 1) == needle))
         {
-            return i;
+            return (int)i;
         }
     }
 
@@ -359,7 +357,7 @@ static inline int find_fc_card(const fcs_state *const dynamic_state,
     {
         if (fcs_freecell_card(*dynamic_state, dest) == needle)
         {
-            return dest;
+            return (int)dest;
         }
     }
 
@@ -414,15 +412,15 @@ extern void fc_solve_trace_solution(fcs_instance *const instance)
         FCS_STATE__DUP_keyval_pair(s_and_info, (instance->state_copy));
 
 #ifndef HARD_CODED_NUM_STACKS
-        const int stacks_num = INSTANCE_STACKS_NUM;
+        const size_t stacks_num = INSTANCE_STACKS_NUM;
 #endif
 #ifndef HARD_CODED_NUM_FREECELLS
-        const int freecells_num = INSTANCE_FREECELLS_NUM;
+        const size_t freecells_num = INSTANCE_FREECELLS_NUM;
 #endif
 
         fcs_state *const s = &(s_and_info.s);
 #ifdef INDIRECT_STACK_STATES
-        for (int i = 0; i < STACKS_NUM__VAL; ++i)
+        for (stack_i i = 0; i < STACKS_NUM__VAL; ++i)
         {
             fcs_copy_stack(
                 s_and_info.s, s_and_info.info, i, indirect_stacks_buffer);
@@ -442,7 +440,7 @@ extern void fc_solve_trace_solution(fcs_instance *const instance)
 #if MAX_NUM_FREECELLS > 0
             case FCS_PATS__TYPE_FREECELL:
             {
-                int src_col_idx;
+                stack_i src_col_idx;
                 for (src_col_idx = 0; src_col_idx < STACKS_NUM__VAL;
                      ++src_col_idx)
                 {
@@ -459,7 +457,7 @@ extern void fc_solve_trace_solution(fcs_instance *const instance)
                     }
                 }
 
-                for (int dest = 0; dest < FREECELLS_NUM__VAL; ++dest)
+                for (stack_i dest = 0; dest < FREECELLS_NUM__VAL; ++dest)
                 {
                     if (fcs_freecell_is_empty(s_and_info.s, dest))
                     {
@@ -543,7 +541,8 @@ extern void fc_solve_trace_solution(fcs_instance *const instance)
             /* Merge the move stack */
             const fcs_move_stack *const stack = FCS_S_MOVES_TO_PARENT(s1);
             const fcs_internal_move *const moves = stack->moves;
-            for (int move_idx = stack->num_moves - 1; move_idx >= 0; --move_idx)
+            for (long move_idx = (long)stack->num_moves - 1; move_idx >= 0;
+                 --move_idx)
             {
                 fcs_move_stack_push(solution_moves_ptr, moves[move_idx]);
             }
@@ -574,11 +573,15 @@ void fc_solve_finish_instance(fcs_instance *const instance)
     g_tree_destroy(instance->tree);
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_JUDY)
     Word_t rc_word;
+#ifdef JERR
+#undef JERR
+#define JERR ((Word_t)(-1))
+#endif
     JHSFA(rc_word, instance->judy_array);
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_HASH)
     g_hash_table_destroy(instance->hash);
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_INTERNAL_HASH)
-    fc_solve_hash_free(&(instance->hash));
+    // fc_solve_hash_free(&(instance->hash));
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GOOGLE_DENSE_HASH)
     fc_solve_states_google_hash_free(instance->hash);
 #else
@@ -588,7 +591,7 @@ void fc_solve_finish_instance(fcs_instance *const instance)
 // De-allocate the stack collection while free()'ing the stacks in the process
 #ifdef INDIRECT_STACK_STATES
 #if (FCS_STACK_STORAGE == FCS_STACK_STORAGE_INTERNAL_HASH)
-    fc_solve_hash_free(&(instance->stacks_hash));
+    // fc_solve_hash_free(&(instance->stacks_hash));
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_LIBAVL2_TREE)
     fcs_libavl2_stacks_tree_destroy(instance->stacks_tree, NULL);
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_LIBREDBLACK_TREE)
@@ -607,10 +610,6 @@ void fc_solve_finish_instance(fcs_instance *const instance)
 #endif
 #endif
 
-#ifndef FCS_DISABLE_NUM_STORED_STATES
-    instance->num_states_in_collection = 0;
-#endif
-
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_DB_FILE)
     instance->db->close(instance->db, 0);
 #endif
