@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // instance.h - header file of fcs_instance / fcs_hard_thread /
 // fcs_soft_thread .
 #pragma once
@@ -92,9 +90,17 @@ extern "C" {
 #define FCS_POS_BY_RANK_LEN (FCS_RANK_KING * FCS_POS_BY_RANK_WIDTH)
 typedef struct
 {
-    char col, height;
+    int8_t col, height;
 } fcs_pos_by_rank;
 
+typedef struct
+{
+    fcs_iters_int num_checked_states;
+#ifndef FCS_DISABLE_NUM_STORED_STATES
+    fcs_int_limit_t num_states_in_collection;
+#endif
+} fcs_stats;
+
 #ifndef FCS_DISABLE_SIMPLE_SIMON
 #define FCS_SS_POS_BY_RANK_WIDTH (FCS_RANK_KING + 1)
 #define FCS_SS_POS_BY_RANK_LEN (FCS_SS_POS_BY_RANK_WIDTH * 4)
@@ -106,10 +112,8 @@ typedef struct
 
 typedef int8_t fcs__positions_by_rank[FCS_BOTH__POS_BY_RANK__SIZE];
 
-/*
- * This is a linked list item that is used to implement a queue for the BFS
- * scan.
- * */
+// This is a linked list item that is used to implement a queue for the BFS
+// scan.
 typedef struct fcs_states_linked_list_item_struct
 {
     fcs_collectible_state *s;
@@ -132,7 +136,8 @@ typedef void (*fc_solve_solve_for_state_move_func)(
 #define HT_FIELD(ht, field) (ht)->hard_thread.field
 #define HT_INSTANCE(hard_thread) (hard_thread)
 #define INST_HT0(instance) ((instance)->hard_thread)
-#define NUM_CHECKED_STATES (HT_INSTANCE(hard_thread)->i__num_checked_states)
+#define NUM_CHECKED_STATES                                                     \
+    (HT_INSTANCE(hard_thread)->i__stats.num_checked_states)
 typedef struct fc_solve_instance_struct fcs_hard_thread;
 extern void fc_solve_init_soft_thread(fcs_hard_thread *const hard_thread,
     struct fc_solve_soft_thread_struct *const soft_thread);
@@ -172,7 +177,7 @@ extern guint fc_solve_hash_function(gconstpointer key);
     fcs_soft_thread *const end_soft_thread =                                   \
         ht_soft_threads + HT_FIELD(hard_thread, num_soft_threads);             \
     for (; soft_thread < end_soft_thread; ++soft_thread)
-#define MOVES_GROW_BY 16
+#define MOVES_GROW_BY 16U
 
 typedef struct
 {
@@ -223,8 +228,8 @@ typedef struct
     fcs_moves_order moves_order;
 } fcs_by_depth_moves_order;
 
-#define STRUCT_CLEAR_FLAG(instance, flag) (instance)->flag = FALSE
-#define STRUCT_TURN_ON_FLAG(instance, flag) (instance)->flag = TRUE
+#define STRUCT_CLEAR_FLAG(instance, flag) (instance)->flag = false
+#define STRUCT_TURN_ON_FLAG(instance, flag) (instance)->flag = true
 #define STRUCT_QUERY_FLAG(instance, flag) ((instance)->flag)
 #define STRUCT_SET_FLAG_TO(instance, flag, value) (instance)->flag = (value)
 
@@ -233,10 +238,7 @@ struct fcs_cache_key_info_struct
 {
     const fcs_collectible_state *val_ptr;
     fcs_state key;
-    /* lower_pri and higher_pri form a doubly linked list.
-     *
-     * pri == priority.
-     * */
+    // lower_pri and higher_pri form a doubly linked list. pri == priority.
     struct fcs_cache_key_info_struct *lower_pri, *higher_pri;
 };
 
@@ -267,6 +269,7 @@ typedef void (*instance_debug_iter_output_func)(
 typedef struct fc_solve_soft_thread_struct fcs_soft_thread;
 typedef struct fc_solve_instance_struct fcs_instance;
 
+typedef uint_fast32_t fastest_type_for_num_soft_threads__unsigned;
 struct fc_solve_hard_thread_struct
 {
 #ifndef FCS_SINGLE_HARD_THREAD
@@ -283,29 +286,23 @@ struct fc_solve_hard_thread_struct
      *
      * Thus, the soft thread switching should be done based on this variable
      * */
-    fcs_int_limit_t ht__num_checked_states;
+    fcs_iters_int ht__num_checked_states;
 
 #endif
     /*
      * The maximal limit for num_checked_states.
      * */
-    fcs_int_limit_t ht__max_num_checked_states;
+    fcs_iters_int ht__max_num_checked_states;
 
-    /*
-     * The index for the soft-thread that is currently processed
-     * */
-    int_fast32_t st_idx;
-    /*
-     * This is the mechanism used to allocate memory for stacks, states
-     * and move stacks.
-     * */
+    // The index for the soft-thread that is currently processed
+    uint_fast32_t st_idx;
+    // This is the mechanism used to allocate memory for stacks, states
+    // and move stacks.
     compact_allocator allocator;
 
 #ifdef FCS_WITH_MOVES
-    /*
-     * This is a move stack that is used and re-used by the
-     * moves functions of this hard thread
-     * */
+    // This is a move stack that is used and re-used by the
+    // moves functions of this hard thread
     fcs_move_stack reusable_move_stack;
 #endif
 
@@ -324,14 +321,12 @@ struct fc_solve_hard_thread_struct
 #endif
 
     bool allocated_from_list;
-    int_fast32_t num_soft_threads;
+    fastest_type_for_num_soft_threads__unsigned num_soft_threads;
 
-    /*
-     * A counter that determines how many of the soft threads that belong
-     * to this hard thread have already finished. If it becomes
-     * num_soft_threads this thread is skipped.
-     * */
-    int num_soft_threads_finished;
+    // A counter that determines how many of the soft threads that belong
+    // to this hard thread have already finished. If it becomes
+    // num_soft_threads this thread is skipped.
+    fastest_type_for_num_soft_threads__unsigned num_soft_threads_finished;
 
 #ifndef FCS_USE_PRECOMPILED_CMD_LINE_THEME
     char *prelude_as_string;
@@ -342,7 +337,7 @@ struct fc_solve_hard_thread_struct
 
 typedef struct
 {
-    int idx;
+    int rating_with_index__idx;
     pq_rating rating;
 } rating_with_index;
 
@@ -356,8 +351,6 @@ typedef struct
     size_t derived_states_random_indexes_max_size;
     rating_with_index *derived_states_random_indexes;
     fcs__positions_by_rank positions_by_rank;
-    fcs_game_limit num_vacant_stacks;
-    fcs_game_limit num_vacant_freecells;
 } fcs_soft_dfs_stack_item;
 
 typedef struct
@@ -386,11 +379,9 @@ struct fc_solve_soft_thread_struct
 {
     fcs_hard_thread *hard_thread;
 
-    /*
-     * The ID of the soft thread inside the instance.
-     * Used for the state-specific flags.
-     * */
-    int id;
+    // The ID of the soft thread inside the instance. Used for the
+    // state-specific flags.
+    fastest_type_for_num_soft_threads__unsigned id;
 
     // The moves' order indicates which move funcs to run.
     struct
@@ -399,16 +390,13 @@ struct fc_solve_soft_thread_struct
         fcs_by_depth_moves_order *by_depth_moves;
     } by_depth_moves_order;
 
-    /* The super-method type - can be  */
     fcs_super_method_type super_method_type;
 
     struct
     {
         struct
         {
-            /*
-             * The (temporary) max depth of the Soft-DFS scans)
-             * */
+            // The (temporary) max depth of the Soft-DFS scans)
             ssize_t dfs_max_depth;
 
             /*
@@ -443,10 +431,8 @@ struct fc_solve_soft_thread_struct
              * */
             fcs_rand_gen rand_gen;
 
-            /*
-             * The initial seed of this random number generator
-             * */
-            int rand_seed;
+            // The initial seed of this random number generator
+            fcs_rand_gen rand_seed;
 
             /*
              * The moves to be performed in a preprocessed form.
@@ -503,10 +489,8 @@ struct fc_solve_soft_thread_struct
     // read by the move functions in freecell.c .
     fcs_game_limit num_vacant_stacks, num_vacant_freecells;
 
-    /*
-     * The number of iterations with which to process this scan
-     * */
-    fcs_int_limit_t checked_states_step;
+    // The number of iterations with which to process this scan
+    fcs_iters_int checked_states_step;
 
 #ifndef FCS_USE_PRECOMPILED_CMD_LINE_THEME
     // A string that serves as an identification for the user.
@@ -514,11 +498,9 @@ struct fc_solve_soft_thread_struct
 #endif
 
 #ifndef FCS_ENABLE_PRUNE__R_TF__UNCOND
-    /*
-     * Whether pruning should be done.
-     * This variable is temporary - there should be a better pruning
-     * abstraction with several optional prunes.
-     * */
+    // Whether pruning should be done.
+    // This variable is temporary - there should be a better pruning
+    // abstraction with several optional prunes.
     bool enable_pruning;
 #endif
 
@@ -532,12 +514,10 @@ struct fc_solve_soft_thread_struct
      * Differentiates between SOFT_DFS and RANDOM_DFS.
      * */
     bool master_to_randomize;
-    bool is_befs
+    bool is_befs;
 #ifdef FCS_WITH_MOVES
-        ,
-        is_optimize_scan
+    bool is_optimize_scan;
 #endif
-        ;
 };
 
 struct fc_solve_instance_struct
@@ -551,9 +531,7 @@ struct fc_solve_instance_struct
 #endif
 #endif
 
-    /* The number of states that were checked by the solving algorithm. */
-    fcs_int_limit_t i__num_checked_states;
-
+    fcs_stats i__stats;
 #ifndef FCS_WITHOUT_MAX_NUM_STATES
     /*
      * Limit for the maximal number of checked states.
@@ -565,7 +543,7 @@ struct fc_solve_instance_struct
      *
      * Normally should be used instead.
      * */
-    fcs_int_limit_t effective_max_num_checked_states;
+    fcs_iters_int effective_max_num_checked_states;
 #endif
 #ifndef FCS_DISABLE_NUM_STORED_STATES
     fcs_int_limit_t effective_max_num_states_in_collection;
@@ -574,11 +552,8 @@ struct fc_solve_instance_struct
 #endif
 #endif
     fcs_seq_cards_power_type initial_cards_under_sequences_value;
-/*
- * tree is the balanced binary tree that is used to store and index
- * the checked states.
- *
- * */
+// tree is the balanced binary tree that is used to store and index
+// the checked states.
 #if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_LIBREDBLACK_TREE)
     struct rbtree *tree;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_JUDY)
@@ -589,25 +564,18 @@ struct fc_solve_instance_struct
     GTree *tree;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_KAZ_TREE)
     dict_t *tree;
-#endif
-
-/*
- * hash is the hash table that is used to store the previous
- * states of the scan.
- * */
-#if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_HASH)
+#elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GLIB_HASH)
     GHashTable *hash;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_INTERNAL_HASH)
     hash_table hash;
 #elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_GOOGLE_DENSE_HASH)
     fcs_states_google_hash_handle hash;
+#elif (FCS_STATE_STORAGE == FCS_STATE_STORAGE_DB_FILE)
+    DB *db;
 #endif
 
 #if defined(INDIRECT_STACK_STATES)
-/*
- * The storage mechanism for the stacks assuming INDIRECT_STACK_STATES is
- * used.
- * */
+// The storage mechanism for the stacks
 #if (FCS_STACK_STORAGE == FCS_STACK_STORAGE_INTERNAL_HASH)
     hash_table stacks_hash;
 #elif (FCS_STACK_STORAGE == FCS_STACK_STORAGE_LIBAVL2_TREE)
@@ -628,13 +596,6 @@ struct fc_solve_instance_struct
 #endif
 
     fcs_collectible_state *list_of_vacant_states;
-/*
- * Storing using Berkeley DB is not operational for some reason so
- * pay no attention to it for the while
- * */
-#if (FCS_STATE_STORAGE == FCS_STATE_STORAGE_DB_FILE)
-    DB *db;
-#endif
 
 #ifndef FCS_HARD_CODE_CALC_REAL_DEPTH_AS_FALSE
     bool FCS_RUNTIME_CALC_REAL_DEPTH;
@@ -648,22 +609,17 @@ struct fc_solve_instance_struct
 #ifndef FCS_HARD_CODE_REPARENT_STATES_AS_FALSE
     bool FCS_RUNTIME_TO_REPARENT_STATES_PROTO;
 #endif
-    ;
 #ifdef FCS_WITH_MOVES
     bool FCS_RUNTIME_OPTIMIZE_SOLUTION_PATH, FCS_RUNTIME_IN_OPTIMIZATION_THREAD,
         FCS_RUNTIME_OPT_TESTS_ORDER_WAS_SET;
 #endif
 
-/*
- * This is the number of states in the state collection.
- *
- * It gives a rough estimate of the memory occupied by the instance.
- * */
+// This is the number of states in the state collection.
+// It gives a rough estimate of the memory occupied by the instance.
 #ifndef FCS_DISABLE_NUM_STORED_STATES
 #ifndef FCS_WITHOUT_TRIM_MAX_STORED_STATES
     fcs_int_limit_t active_num_states_in_collection;
 #endif
-    fcs_int_limit_t num_states_in_collection;
 #endif
 
 #ifdef FCS_SINGLE_HARD_THREAD
@@ -675,15 +631,11 @@ struct fc_solve_instance_struct
 #else
     uint_fast32_t num_hard_threads;
     struct fc_solve_hard_thread_struct *hard_threads;
-    /*
-     * An iterator over the hard threads.
-     * */
+    // An iterator over the hard threads.
     fcs_hard_thread *current_hard_thread;
 
 #ifdef FCS_WITH_MOVES
-    /*
-     * This is the hard-thread used for the optimization scan.
-     * */
+    // This is the hard-thread used for the optimization scan.
     struct fc_solve_hard_thread_struct *optimization_thread;
 #endif
 #endif
@@ -738,7 +690,7 @@ struct fc_solve_instance_struct
     /*
      * The next ID to allocate for a soft-thread.
      * */
-    int next_soft_thread_id;
+    fastest_type_for_num_soft_threads__unsigned next_soft_thread_id;
 
     /* This is the initial state */
     fcs_state_keyval_pair state_copy;
@@ -749,41 +701,31 @@ struct fc_solve_instance_struct
      * */
     fcs_collectible_state *final_state;
 
-    /*
-     * A move stack that contains the moves leading to the solution.
-     *
-     * It is created only after the solution was found by swallowing
-     * all the stacks of each depth.
-     * */
+    // A move stack that contains the moves leading to the solution.
+    //
+    // It is created only after the solution was found by swallowing
+    // all the stacks of each depth.
     fcs_move_stack solution_moves;
 #endif
 
-    /*
-     * The meta allocator - see meta_alloc.h.
-     * */
+    // The meta allocator - see meta_alloc.h.
     meta_allocator *meta_alloc;
 
 #if (defined(FCS_WITH_MOVES) && (!defined(FCS_DISABLE_PATSOLVE)))
-    /*
-     * The soft_thread that solved the state.
-     *
-     * Needed to trace the patsolve solutions.
-     * */
+    // The soft_thread that solved the state.
+    //
+    // Needed to trace the patsolve solutions.
     fcs_soft_thread *solving_soft_thread;
 #endif
 #ifndef FCS_DISABLE_PATSOLVE
-    /*
-     * This is intended to be used by the patsolve scan which is
-     * sensitive to the ordering of the columns/stacks. This is an ugly hack
-     * but hopefully it will work.
-     * */
+    // This is intended to be used by the patsolve scan which is
+    // sensitive to the ordering of the columns/stacks. This is an ugly hack
+    // but hopefully it will work.
     fcs_state_keyval_pair *initial_non_canonized_state;
 #endif
 
 #ifndef FCS_DISABLE_SIMPLE_SIMON
-    /*
-     * Whether or not this is a Simple Simon-like game.
-     * */
+    // Whether or not this is a Simple Simon-like game.
     bool is_simple_simon;
 #endif
 };
@@ -798,9 +740,7 @@ struct fc_solve_instance_struct
 #define BRFS_VAR(soft_thread, var)                                             \
     (soft_thread)->method_specific.befs.meth.brfs.var
 
-/*
- * An enum that specifies the meaning of each BeFS weight.
- * */
+// An enum that specifies the meaning of each BeFS weight.
 #define FCS_BEFS_WEIGHT_CARDS_OUT 0
 #define FCS_BEFS_WEIGHT_MAX_SEQUENCE_MOVE 1
 #define FCS_BEFS_WEIGHT_CARDS_UNDER_SEQUENCES 2
