@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2012 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2012 Shlomi Fish
 /*
  * lock.h - macros/functions for locking.
  */
@@ -28,15 +26,24 @@ extern "C" {
 #include <pthread/rwlock_fcfs.h>
 #endif
 
-#include "rinutils.h"
+#include "rinutils/rinutils.h"
 
 #ifdef FCS_DBM_SINGLE_THREAD
 
 typedef bool fcs_lock;
-static inline void fcs_lock_lock(fcs_lock *const lock) {}
-static inline void fcs_lock_unlock(fcs_lock *const lock) {}
-static inline void fcs_lock_init(fcs_lock *const lock) {}
-static inline void fcs_lock_destroy(fcs_lock *const lock) {}
+typedef bool fcs_condvar;
+static inline void fcs_lock_lock(GCC_UNUSED fcs_lock *const lock) {}
+static inline void fcs_lock_unlock(GCC_UNUSED fcs_lock *const lock) {}
+static inline void fcs_lock_init(GCC_UNUSED fcs_lock *const lock) {}
+static inline void fcs_lock_destroy(GCC_UNUSED fcs_lock *const lock) {}
+static inline void fcs_condvar_init(GCC_UNUSED fcs_condvar *const cond) {}
+static inline void fcs_condvar_destroy(GCC_UNUSED fcs_condvar *const cond) {}
+static inline void fcs_condvar__wait_on(
+    GCC_UNUSED fcs_condvar *const cond, GCC_UNUSED fcs_lock *const lock)
+{
+}
+static inline void fcs_condvar_signal(GCC_UNUSED fcs_condvar *const cond) {}
+static inline void fcs_condvar_broadcast(GCC_UNUSED fcs_condvar *const cond) {}
 #elif defined(FCS_DBM_USE_RWLOCK)
 
 typedef pthread_rwlock_fcfs_t *fcs_lock;
