@@ -1,15 +1,13 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // measure_depth_dep_tests_order_performance.c - measure the relative
 // depth-dependent performance of two scans.
-#include "rinutils.h"
+#include "rinutils/rinutils.h"
 #include "freecell-solver/fcs_cl.h"
 #include "range_solvers_gen_ms_boards.h"
 #include "try_param.h"
@@ -40,8 +38,8 @@ static void print_help(void)
 
 typedef struct
 {
-    fcs_portable_time start_time, end_time;
-    fcs_int_limit_t num_iters;
+    rinutils_portable_time start_time, end_time;
+    fcs_iters_int num_iters;
     int verdict;
 } result;
 
@@ -121,23 +119,23 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
         }
         else
         {
-            fc_solve_err("Unknown argument - '%s'!\n", argv[arg]);
+            exit_error("Unknown argument - '%s'!\n", argv[arg]);
         }
     }
 
     if (!scan1_to)
     {
-        fc_solve_err("--scan1-to not specified!\n");
+        exit_error("--scan1-to not specified!\n");
     }
 
     if (!scan2_to)
     {
-        fc_solve_err("--scan2-to not specified!\n");
+        exit_error("--scan2-to not specified!\n");
     }
 
     if (!output_filename)
     {
-        fc_solve_err("output filename not specified");
+        exit_error("output filename not specified");
     }
 
     fc_solve_print_started_at();
@@ -162,20 +160,20 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
         set_tests_order(instance, min_depth_for_scan2, scan2_to);
 
         result *curr_result;
-        int board_num;
+        long long board_num;
         for (board_num = start_board, curr_result = results;
              board_num <= end_board; board_num++, curr_result++)
         {
             fcs_state_string state_string;
-            get_board(board_num, state_string);
+            get_board((unsigned long long)board_num, state_string);
 
 #ifndef FCS_WITHOUT_MAX_NUM_STATES
             freecell_solver_user_limit_iterations_long(instance, iters_limit);
 #endif
-            curr_result->start_time = fcs_get_time();
+            curr_result->start_time = rinutils_get_time();
             curr_result->verdict =
                 freecell_solver_user_solve_board(instance, state_string);
-            curr_result->end_time = fcs_get_time();
+            curr_result->end_time = rinutils_get_time();
             curr_result->num_iters =
                 freecell_solver_user_get_num_times_long(instance);
 
@@ -190,15 +188,14 @@ static inline int range_solvers_main(int argc, char *argv[], int arg,
         for (board_num = start_board, curr_result = results;
              board_num <= end_board; board_num++, curr_result++)
         {
-            fprintf(output_fh, "board[%d].ret == %d\n", board_num,
+            fprintf(output_fh, "board[%ld].ret == %d\n", (long)board_num,
                 curr_result->verdict);
-            fprintf(output_fh, "board[%d].iters == %ld\n", board_num,
+            fprintf(output_fh, "board[%ld].iters == %ld\n", (long)board_num,
                 (long)curr_result->num_iters);
 
 #define FPRINTF_TIME(label, field)                                             \
-    fprintf(output_fh, "board[%d].%s = " FCS_T_FMT "\n", board_num, label,     \
-        FCS_TIME_GET_SEC(curr_result->field),                                  \
-        FCS_TIME_GET_USEC(curr_result->field));
+    fprintf(output_fh, "board[%ld].%s = " RIN_TIME_FMT "\n", (long)board_num,  \
+        label, RIN_TIME__GET_BOTH(curr_result->field));
 
             FPRINTF_TIME("start", start_time);
             FPRINTF_TIME("end", end_time);
