@@ -1,30 +1,31 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
-/*
- * meta_alloc.h - the Freecell Solver compact allocator based on the
- * meta-allocator concept that is used to collect the pages allocated by
- * the standard allocator after it is destroyed and to recycle them.
- *
- * Also see alloc.h.
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
+// meta_alloc.h - the Freecell Solver compact allocator based on the
+// meta-allocator concept that is used to collect the pages allocated by
+// the standard allocator after it is destroyed and to recycle them.
 #pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+#ifdef FCS_DBM_USE_APR
+#include <apr_hash.h>
+#endif
+
 #include "state.h"
 
 typedef struct
 {
     char *recycle_bin;
+#ifdef FCS_DBM_USE_APR
+    apr_pool_t *apr_pool;
+#endif
 } meta_allocator;
 
 typedef struct
@@ -36,7 +37,33 @@ typedef struct
     meta_allocator *meta;
 } compact_allocator;
 
-extern void fc_solve_compact_allocator_extend(compact_allocator *);
+#define OLD_LIST_NEXT(ptr) (*((char **)(ptr)))
+#define OLD_LIST_DATA(ptr) ((char *)(&(((char **)(ptr))[1])))
+#define FCS_METAALLOC_ALLOCED_SIZE (FCS_IA_PACK_SIZE * 1024 - (128))
+static inline char *meta_request_new_buffer(meta_allocator *const meta_alloc)
+{
+    char *const ret = meta_alloc->recycle_bin;
+    if (ret)
+    {
+        meta_alloc->recycle_bin = OLD_LIST_NEXT(ret);
+        return ret;
+    }
+    else
+    {
+        return malloc(FCS_METAALLOC_ALLOCED_SIZE);
+    }
+}
+static inline void fc_solve_compact_allocator_extend(
+    compact_allocator *const allocator)
+{
+    char *const new_data = meta_request_new_buffer(allocator->meta);
+
+    OLD_LIST_NEXT(new_data) = allocator->old_list;
+    allocator->old_list = new_data;
+
+    allocator->ptr = allocator->rollback_ptr = OLD_LIST_DATA(new_data);
+    allocator->max_ptr = new_data + FCS_METAALLOC_ALLOCED_SIZE;
+}
 
 /* To be called after the meta_alloc was set. */
 static inline void fc_solve_compact_allocator_init_helper(
@@ -50,6 +77,9 @@ static inline void fc_solve_meta_compact_allocator_init(
     meta_allocator *const meta)
 {
     meta->recycle_bin = NULL;
+#ifdef FCS_DBM_USE_APR
+    meta->apr_pool = NULL;
+#endif
 }
 
 extern void fc_solve_meta_compact_allocator_finish(meta_allocator *);
