@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 /*
  * meta_move_funcs_helpers.h - header file of the move functions of Freecell
  * Solver.
@@ -98,11 +96,9 @@ static inline void fc_solve_move_sequence_function(
     {                                                                          \
     }
 
-#define tests__is_filled_by_any_card() TRUE
-
-#define IS_FILLED_BY_KINGS_ONLY() FALSE
-
-#define IS_FILLED_BY_NONE() FALSE
+#define tests__is_filled_by_any_card() true
+#define IS_FILLED_BY_KINGS_ONLY() false
+#define IS_FILLED_BY_NONE() false
 
 #else
 
@@ -144,7 +140,7 @@ static inline void fc_solve_move_sequence_function(
 
 #ifdef INDIRECT_STACK_STATES
 #define tests_define_indirect_stack_states_accessors()                         \
-    char *indirect_stacks_buffer =                                             \
+    fcs_card *indirect_stacks_buffer =                                         \
         HT_FIELD(hard_thread, indirect_stacks_buffer);
 #else
 #define tests_define_indirect_stack_states_accessors()
