@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // move.c - move and move stacks routines for Freecell Solver
 #include "move.h"
 #include "state.h"
@@ -28,8 +26,8 @@ void fc_solve_apply_move(fcs_state *const ptr_state_key,
     const fcs_internal_move move FREECELLS_AND_STACKS_ARGS())
 {
     fcs_cards_column col;
-    const int src = fcs_int_move_get_src(move);
-    const int dest = fcs_int_move_get_dest(move);
+    const stack_i src = fcs_int_move_get_src(move);
+    const stack_i dest = fcs_int_move_get_dest(move);
 
 #define state_key (ptr_state_key)
     switch (fcs_int_move_get_type(move))
@@ -103,18 +101,3 @@ void fc_solve_apply_move(fcs_state *const ptr_state_key,
 #undef state_key
 }
 #endif
-
-#define DERIVED_STATES_LIST_GROW_BY 16
-void fc_solve_derived_states_list_add_state(fcs_derived_states_list *const list,
-    fcs_collectible_state *const state, const int context)
-{
-    if ((!((list->num_states + (list->states != NULL)) &
-            (DERIVED_STATES_LIST_GROW_BY - 1))))
-    {
-        list->states =
-            SREALLOC(list->states, list->num_states + (list->states != NULL) +
-                                       DERIVED_STATES_LIST_GROW_BY);
-    }
-    list->states[list->num_states++] = (fcs_derived_states_list_item){
-        .state_ptr = state, .context.i = context};
-}
