@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // move.h - header file for the move and move stacks functions.
 #pragma once
 
@@ -38,7 +36,8 @@ static inline void fcs_move_stack_push(
 }
 
 static inline void fcs_move_stack_params_push(fcs_move_stack *const stack,
-    const int type, const int src, const int dest, const int num_cards_in_seq)
+    const int type, const size_t src, const size_t dest,
+    const size_t num_cards_in_seq)
 {
     fcs_internal_move temp_move;
 
@@ -50,14 +49,14 @@ static inline void fcs_move_stack_params_push(fcs_move_stack *const stack,
     fcs_move_stack_push(stack, temp_move);
 }
 
-static inline void fcs_move_stack_non_seq_push(
-    fcs_move_stack *const stack, const int type, const int src, const int dest)
+static inline void fcs_move_stack_non_seq_push(fcs_move_stack *const stack,
+    const int type, const size_t src, const size_t dest)
 {
     fcs_move_stack_params_push(stack, type, src, dest, 1);
 }
 
 static inline void fcs_push_1card_seq(
-    fcs_move_stack *const stack, const int src, const int dest)
+    fcs_move_stack *const stack, const size_t src, const size_t dest)
 {
     fcs_move_stack_params_push(
         stack, FCS_MOVE_TYPE_STACK_TO_STACK, src, dest, 1);
@@ -69,11 +68,11 @@ static inline bool fc_solve_move_stack_pop(
     if (stack->num_moves > 0)
     {
         *move = stack->moves[--stack->num_moves];
-        return FALSE;
+        return false;
     }
     else
     {
-        return TRUE;
+        return true;
     }
 }
 
@@ -208,7 +207,7 @@ static inline int fc_solve_move__convert_freecell_num(const int fc_idx)
 
 static inline char fc_solve__freecell_to_char(const int fc_idx)
 {
-    return 'a' + fc_solve_move__convert_freecell_num(fc_idx);
+    return 'a' + (char)fc_solve_move__convert_freecell_num(fc_idx);
 }
 static inline void fc_solve_move_to_string_w_state(char *const string,
     fcs_state_keyval_pair *const state, const fcs_move_t move,
@@ -217,6 +216,8 @@ static inline void fc_solve_move_to_string_w_state(char *const string,
 #define state_key (&(state->s))
     switch (fcs_move_get_type(move))
     {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wnull-dereference"
     case FCS_MOVE_TYPE_STACK_TO_STACK:
         if ((standard_notation == FC_SOLVE__STANDARD_NOTATION_EXTENDED) &&
             /* More than one card was moved */
@@ -242,6 +243,7 @@ static inline void fc_solve_move_to_string_w_state(char *const string,
         }
         break;
 
+#pragma GCC diagnostic pop
     case FCS_MOVE_TYPE_FREECELL_TO_STACK:
         if (standard_notation)
         {
@@ -358,11 +360,22 @@ typedef struct
 {
     size_t num_states;
     fcs_derived_states_list_item *states;
+    size_t max_num_states;
 } fcs_derived_states_list;
 
-extern void fc_solve_derived_states_list_add_state(
-    fcs_derived_states_list *, fcs_collectible_state *, int);
-
+#define DERIVED_STATES_LIST_GROW_BY 16
+static inline void fc_solve_derived_states_list_add_state(
+    fcs_derived_states_list *const list, fcs_collectible_state *const state,
+    const int context)
+{
+    if (list->num_states == list->max_num_states)
+    {
+        list->states = SREALLOC(
+            list->states, list->max_num_states += DERIVED_STATES_LIST_GROW_BY);
+    }
+    list->states[list->num_states++] = (fcs_derived_states_list_item){
+        .state_ptr = state, .context.i = context};
+}
 #ifdef __cplusplus
 }
 #endif
