@@ -1,14 +1,11 @@
-/*
- * This file is part of patsolve. It is subject to the license terms in
- * the LICENSE file found in the top-level directory of this distribution
- * and at https://github.com/shlomif/patsolve/blob/master/LICENSE . No
- * part of patsolve, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2002 Tom Holroyd
- */
-#include "alloc_wrap.h"
-#include "count.h"
+// This file is part of patsolve. It is subject to the license terms in
+// the LICENSE file found in the top-level directory of this distribution
+// and at https://github.com/shlomif/patsolve/blob/master/LICENSE . No
+// part of patsolve, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2002 Tom Holroyd
+#include "rinutils/count.h"
 #include "instance.h"
 
 static inline int calc_empty_col_idx(
@@ -38,7 +35,7 @@ static inline bool good_automove(
 #endif
         r <= 2)
     {
-        return TRUE;
+        return true;
     }
 
     // Check the Out piles of opposite color.
@@ -58,18 +55,18 @@ static inline bool good_automove(
             {
                 if (fcs_foundation_value(soft_thread->current_pos.s, j) < r - 2)
                 {
-                    return FALSE;
+                    return false;
                 }
             }
             return (fcs_foundation_value(
                         soft_thread->current_pos.s, ((o + 2) & 3)) >= r - 3);
 #else /* Horne's Rule */
-            return FALSE;
+            return false;
 #endif
         }
     }
 
-    return TRUE;
+    return true;
 }
 /* Get the possible moves from a position, and store them in
  * soft_thread->possible_moves[]. */
@@ -100,9 +97,9 @@ static inline int get_possible_moves(
             fcs_foundation_value(soft_thread->current_pos.s, o) + 1)
         {
             *(move_ptr++) = (typeof(*move_ptr)){.card = card,
-                .from = w,
+                .from = (unsigned char)w,
                 .fromtype = FCS_PATS__TYPE_WASTE,
-                .to = o,
+                .to = (unsigned char)o,
                 .totype = FCS_PATS__TYPE_FOUNDATION,
                 .srccard = ((col_len > 1) ? fcs_col_get_card(col, col_len - 2)
                                           : fc_solve_empty_card),
@@ -111,7 +108,7 @@ static inline int get_possible_moves(
             // If it's an automove, just do it.
             if (good_automove(soft_thread, o, fcs_card_rank(card)))
             {
-                *a = TRUE;
+                *a = true;
                 if (NUM_MOVES != 1)
                 {
                     soft_thread->possible_moves[0] = move_ptr[-1];
@@ -137,9 +134,9 @@ static inline int get_possible_moves(
             fcs_foundation_value(soft_thread->current_pos.s, o) + 1)
         {
             *(move_ptr++) = (typeof(*move_ptr)){.card = card,
-                .from = t,
+                .from = (unsigned char)t,
                 .fromtype = FCS_PATS__TYPE_FREECELL,
-                .to = o,
+                .to = (unsigned char)o,
                 .totype = FCS_PATS__TYPE_FOUNDATION,
                 .srccard = fc_solve_empty_card,
                 .destcard = fc_solve_empty_card,
@@ -147,7 +144,7 @@ static inline int get_possible_moves(
             // If it's an automove, just do it.
             if (good_automove(soft_thread, o, fcs_card_rank(card)))
             {
-                *a = TRUE;
+                *a = true;
                 if (NUM_MOVES != 1)
                 {
                     soft_thread->possible_moves[0] = move_ptr[-1];
@@ -159,8 +156,8 @@ static inline int get_possible_moves(
 #endif
 
     // No more automoves, but remember if there were any moves out.
-    *a = FALSE;
-    *num_cards_out = NUM_MOVES;
+    *a = false;
+    *num_cards_out = (int)NUM_MOVES;
 
     /* Check for moves from non-singleton soft_thread->current_pos.stacks cells
     to one of any
@@ -170,7 +167,7 @@ static inline int get_possible_moves(
 #ifndef FCS_FREECELL_ONLY
         (!((INSTANCE_EMPTY_STACKS_FILL == FCS_ES_FILLED_BY_KINGS_ONLY)));
 #else
-        TRUE;
+        true;
 #endif
 
     const int empty_col_idx = calc_empty_col_idx(soft_thread, LOCAL_STACKS_NUM);
@@ -188,13 +185,13 @@ static inline int get_possible_moves(
                 {
                     *(move_ptr++) = (typeof(*move_ptr)){
                         .card = card,
-                        .from = i,
+                        .from = (unsigned char)i,
                         .fromtype = FCS_PATS__TYPE_WASTE,
-                        .to = empty_col_idx,
+                        .to = (unsigned char)empty_col_idx,
                         .totype = FCS_PATS__TYPE_WASTE,
                         .srccard = fcs_col_get_card(i_col, i_col_len - 2),
                         .destcard = fc_solve_empty_card,
-                        .pri = soft_thread->pats_solve_params.x[3],
+                        .pri = (signed char)soft_thread->pats_solve_params.x[3],
                     };
                 }
             }
@@ -237,16 +234,17 @@ static inline int get_possible_moves(
                             ))
                     {
                         *(move_ptr++) = (typeof(*move_ptr)){.card = card,
-                            .from = i,
+                            .from = (unsigned char)i,
                             .fromtype = FCS_PATS__TYPE_WASTE,
-                            .to = w,
+                            .to = (unsigned char)w,
                             .totype = FCS_PATS__TYPE_WASTE,
                             .srccard =
                                 ((i_col_len > 1)
                                         ? fcs_col_get_card(i_col, i_col_len - 2)
                                         : fc_solve_empty_card),
                             .destcard = w_card,
-                            .pri = soft_thread->pats_solve_params.x[4]};
+                            .pri = (signed char)
+                                       soft_thread->pats_solve_params.x[4]};
                     }
                 }
             }
@@ -281,13 +279,14 @@ static inline int get_possible_moves(
                             )))
                 {
                     *(move_ptr++) = (typeof(*move_ptr)){.card = card,
-                        .from = t,
+                        .from = (unsigned char)t,
                         .fromtype = FCS_PATS__TYPE_FREECELL,
-                        .to = w,
+                        .to = (unsigned char)w,
                         .totype = FCS_PATS__TYPE_WASTE,
                         .srccard = fc_solve_empty_card,
                         .destcard = w_card,
-                        .pri = soft_thread->pats_solve_params.x[5]};
+                        .pri =
+                            (signed char)soft_thread->pats_solve_params.x[5]};
                 }
             }
         }
@@ -307,13 +306,13 @@ static inline int get_possible_moves(
                 fcs_pats_is_king_only(not_King_only, card))
             {
                 *(move_ptr++) = (typeof(*move_ptr)){.card = card,
-                    .from = t,
+                    .from = (unsigned char)t,
                     .fromtype = FCS_PATS__TYPE_FREECELL,
-                    .to = empty_col_idx,
+                    .to = (unsigned char)empty_col_idx,
                     .totype = FCS_PATS__TYPE_WASTE,
                     .srccard = fc_solve_empty_card,
                     .destcard = fc_solve_empty_card,
-                    .pri = soft_thread->pats_solve_params.x[6]};
+                    .pri = (signed char)soft_thread->pats_solve_params.x[6]};
             }
         }
     }
@@ -334,22 +333,22 @@ static inline int get_possible_moves(
             {
                 *(move_ptr++) = (typeof(*move_ptr)){
                     .card = fcs_col_get_card(w_col, w_col_len - 1),
-                    .from = w,
+                    .from = (unsigned char)w,
                     .fromtype = FCS_PATS__TYPE_WASTE,
-                    .to = t,
+                    .to = (unsigned char)t,
                     .totype = FCS_PATS__TYPE_FREECELL,
                     .srccard = ((w_col_len > 1)
                                     ? fcs_col_get_card(w_col, w_col_len - 2)
                                     : fc_solve_empty_card),
                     .destcard = fc_solve_empty_card,
-                    .pri = soft_thread->pats_solve_params.x[7],
+                    .pri = (signed char)soft_thread->pats_solve_params.x[7],
                 };
             }
         }
         break;
     }
 #endif
-    return NUM_MOVES;
+    return (int)NUM_MOVES;
 }
 
 /* Moves that can't be undone get slightly higher priority, since it means
@@ -364,7 +363,7 @@ static inline bool is_irreversible_move(
 {
     if (move_ptr->totype == FCS_PATS__TYPE_FOUNDATION)
     {
-        return TRUE;
+        return true;
     }
     else if (move_ptr->fromtype == FCS_PATS__TYPE_WASTE)
     {
@@ -380,7 +379,7 @@ static inline bool is_irreversible_move(
 #endif
                     ))
             {
-                return TRUE;
+                return true;
             }
         }
         /* TODO : This is probably a bug because move_ptr->card probably cannot
@@ -391,11 +390,11 @@ static inline bool is_irreversible_move(
         else if (King_only &&
                  move_ptr->card != fcs_make_card(FCS_PATS__KING, 0))
         {
-            return TRUE;
+            return true;
         }
     }
 
-    return FALSE;
+    return false;
 }
 
 static inline void mark_irreversible(
@@ -412,7 +411,7 @@ static inline void mark_irreversible(
 #ifndef FCS_FREECELL_ONLY
         (INSTANCE_EMPTY_STACKS_FILL == FCS_ES_FILLED_BY_KINGS_ONLY);
 #else
-        FALSE;
+        false;
 #endif
     const_AUTO(x_param_8, soft_thread->pats_solve_params.x[8]);
 
@@ -449,7 +448,7 @@ static inline int get_pilenum(fcs_pats_thread *const soft_thread, const int w)
     fcs_pats__bucket_list *list_iter = soft_thread->buckets_list[bucket],
                           *last_item = NULL;
     const_AUTO(w_col, fcs_state_get_col(soft_thread->current_pos.s, w));
-    const int w_col_len = fcs_col_len(w_col);
+    const uint_fast16_t w_col_len = fcs_col_len(w_col);
     const char *w_col_data = (const char *)w_col + 1;
     for (; list_iter; list_iter = list_iter->next)
     {
@@ -558,12 +557,12 @@ static inline int prune_seahaven(
         !(INSTANCE_EMPTY_STACKS_FILL == FCS_ES_FILLED_BY_KINGS_ONLY) ||
         move_ptr->totype != FCS_PATS__TYPE_WASTE)
     {
-        return FALSE;
+        return false;
     }
 
     // Count the number of cards below this card.
-    const int r = fcs_card_rank(move_ptr->card) + 1;
-    const int s = fcs_card_suit(move_ptr->card);
+    const fcs_card r = fcs_card_rank(move_ptr->card) + 1;
+    const fcs_card s = fcs_card_suit(move_ptr->card);
     const_AUTO(
         col, fcs_state_get_col(soft_thread->current_pos.s, move_ptr->to));
     const int len = fcs_col_len(col);
@@ -580,7 +579,7 @@ static inline int prune_seahaven(
         }
         if (j < LOCAL_FREECELLS_NUM + 1)
         {
-            return FALSE;
+            return false;
         }
     }
 
@@ -592,11 +591,11 @@ static inline int prune_seahaven(
         const_AUTO(card, fcs_col_get_card(col, i));
         if ((fcs_card_suit(card) == s) && (fcs_card_rank(card) < r_minus))
         {
-            return TRUE;
+            return true;
         }
     }
 
-    return FALSE;
+    return false;
 }
 #endif
 
@@ -610,10 +609,10 @@ static inline int was_card_moved(
     {
         if (moves[i]->card == card)
         {
-            return TRUE;
+            return true;
         }
     }
-    return FALSE;
+    return false;
 }
 
 /* This utility routine is used to check if a card is ever used as a
@@ -625,10 +624,10 @@ static inline int is_card_dest(
     {
         if (moves[i]->destcard == card)
         {
-            return TRUE;
+            return true;
         }
     }
-    return FALSE;
+    return false;
 }
 
 static inline int was_card_moved_or_dest(
@@ -651,12 +650,12 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
     fcs_pats_position *pos = pos0;
     if (pos->depth == 0)
     {
-        return FALSE;
+        return false;
     }
     m = &pos->move;
     if (m->card == move_ptr->card)
     {
-        return TRUE;
+        return true;
     }
 
     /* The check above is the simplest case of the more general strategy
@@ -666,7 +665,7 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
     pos = pos->parent;
     if (pos->depth == 0)
     {
-        return FALSE;
+        return false;
     }
     prev[0] = m;
     j = -1;
@@ -687,7 +686,7 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
         pos = pos->parent;
         if (pos->depth == 0)
         {
-            return FALSE;
+            return false;
         }
     }
 
@@ -695,14 +694,14 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
     a redundant move. */
     if (j < 0)
     {
-        return FALSE;
+        return false;
     }
 
     /* If the number of empty soft_thread->current_pos.freecells cells
      * ever goes to zero, from prev[0] to
     prev[j-1], there may be a dependency.  We also want to know if there
     were any empty soft_thread->current_pos.freecells cells on move prev[j]. */
-    bool was_all_freecells_occupied = FALSE;
+    bool was_all_freecells_occupied = false;
     pos = pos0;
     for (int i = 0; i < j; i++)
     {
@@ -729,16 +728,16 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
         dependency, and we can't prune. */
         if (was_all_freecells_occupied)
         {
-            return FALSE;
+            return false;
         }
 
         /* If any intervening move used this card as a destination,
         we have a dependency and we can't prune. */
         if (is_card_dest(move_ptr->card, prev, j))
         {
-            return FALSE;
+            return false;
         }
-        return TRUE;
+        return true;
     }
 
     /* soft_thread->current_pos.stacks -> soft_thread->current_pos.freecells,
@@ -760,7 +759,7 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
         it's not an inverse. */
         if (m->srccard != move_ptr->destcard)
         {
-            return FALSE;
+            return false;
         }
 
         /* If any of the intervening moves either moves the card
@@ -768,10 +767,10 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
         fc_solve_empty_card), there is a dependency. */
         if (was_card_moved_or_dest(move_ptr->destcard, prev, j))
         {
-            return FALSE;
+            return false;
         }
 
-        return TRUE;
+        return true;
     }
 
     /* These are not inverse prunes, we're taking a shortcut. */
@@ -790,10 +789,10 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
         if (pos->num_cards_in_freecells != LOCAL_FREECELLS_NUM &&
             !was_all_freecells_occupied)
         {
-            return TRUE;
+            return true;
         }
 
-        return FALSE;
+        return false;
     }
 
     /* soft_thread->current_pos.freecells -> soft_thread->current_pos.stacks,
@@ -810,13 +809,13 @@ static inline int prune_redundant(fcs_pats_thread *const soft_thread GCC_UNUSED,
 
         if (was_card_moved_or_dest(move_ptr->destcard, prev, j))
         {
-            return FALSE;
+            return false;
         }
 
-        return TRUE;
+        return true;
     }
 
-    return FALSE;
+    return false;
 }
 
 // Next card in rank.
@@ -845,7 +844,7 @@ static inline void prioritize(fcs_pats_thread *const soft_thread,
     }
 
     fcs_card needed_cards[FCS_NUM_SUITS];
-    for (int suit = 0; suit < FCS_NUM_SUITS; suit++)
+    for (fcs_card suit = 0; suit < FCS_NUM_SUITS; suit++)
     {
         needed_cards[suit] = fc_solve_empty_card;
         const fcs_card rank =
@@ -940,10 +939,10 @@ static inline bool is_win(fcs_pats_thread *const soft_thread)
         if (fcs_foundation_value(soft_thread->current_pos.s, o) !=
             FCS_PATS__KING)
         {
-            return FALSE;
+            return false;
         }
     }
-    return TRUE;
+    return true;
 }
 
 // Generate an array of the moves we can make from this position.
@@ -1022,7 +1021,7 @@ fcs_pats__move *fc_solve_pats__get_moves(fcs_pats_thread *const soft_thread,
     moves. */
     fcs_pats__move *move_ptr, *moves_start;
     move_ptr = moves_start =
-        fc_solve_pats__new_array(soft_thread, fcs_pats__move, n);
+        fc_solve_pats__new_array(soft_thread, fcs_pats__move, (size_t)n);
     if (move_ptr == NULL)
     {
         return NULL;
