@@ -1,24 +1,23 @@
-/*
- * This file is part of patsolve. It is subject to the license terms in
- * the LICENSE file found in the top-level directory of this distribution
- * and at https://github.com/shlomif/patsolve/blob/master/LICENSE . No
- * part of patsolve, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2002 Tom Holroyd
- */
+// This file is part of patsolve. It is subject to the license terms in
+// the LICENSE file found in the top-level directory of this distribution
+// and at https://github.com/shlomif/patsolve/blob/master/LICENSE . No
+// part of patsolve, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2002 Tom Holroyd
 #pragma once
-#include "fcs_conf.h"
+#include "freecell-solver/fcs_conf.h"
 
 #include "game_type_params.h"
 #include "freecell-solver/fcs_enums.h"
 #include "tree.h"
 #include "param.h"
-#include "bool.h"
+#include <limits.h>
+#include <stdbool.h>
 #include "freecell-solver/fcs_dllexport.h"
 #include "state.h"
 #include "fnv.h"
-#include "alloc_wrap.h"
+#include "rinutils/alloc_wrap.h"
 #include "instance.h"
 
 #define FCS_PATS__COLOR 0x01 /* black if set */
@@ -106,7 +105,6 @@ typedef enum
 typedef enum
 {
     FCS_PATS__FAIL_CHECKED_STATES = 0,
-    FCS_PATS__FAIL_OTHER = 1,
 } fc_solve_pats__status_fail_reason;
 #endif
 
@@ -183,7 +181,7 @@ struct fc_solve__patsolve_thread_struct
     struct
     {
         fcs_state s;
-        DECLARE_IND_BUF_T(indirect_stacks_buffer);
+        DECLARE_IND_BUF_T(indirect_stacks_buffer)
         /* used to keep the piles sorted */
         int column_idxs[MAX_NUM_STACKS];
 /* column_inv_idxs are not needed or used. */
@@ -200,8 +198,8 @@ struct fc_solve__patsolve_thread_struct
     fcs_pats__move possible_moves[FCS_PATS__MAX_NUM_MOVES];
 
     /* Statistics. */
-    long num_checked_states, max_num_checked_states;
-    long num_states_in_collection;
+    unsigned long num_checked_states, max_num_checked_states;
+    unsigned long num_states_in_collection;
     fcs_pats_xy_params pats_solve_params;
     size_t position_size;
 
@@ -216,7 +214,7 @@ struct fc_solve__patsolve_thread_struct
     int num_solutions;     /* number of solutions found in -E mode */
     /* -S means stack, not queue, the moves to be done. This is a boolean
      * value.
-     * Default should be FALSE.
+     * Default should be false.
      * */
     bool to_stack;
     /* Switch between depth- and breadth-first. Default is "1".*/
@@ -444,12 +442,12 @@ static inline void fc_solve_pats__init_soft_thread(
     fcs_pats_thread *const soft_thread, fcs_instance *const instance)
 {
     soft_thread->instance = instance;
-    soft_thread->dont_exit_on_sol = FALSE;
-    soft_thread->to_stack = FALSE;
+    soft_thread->dont_exit_on_sol = false;
+    soft_thread->to_stack = false;
     soft_thread->num_moves_to_cut_off = 1;
     soft_thread->remaining_memory = (50 * 1000 * 1000);
     soft_thread->freed_positions = NULL;
-    soft_thread->max_num_checked_states = -1;
+    soft_thread->max_num_checked_states = ULONG_MAX;
 
     soft_thread->moves_to_win = NULL;
     soft_thread->num_moves_to_win = 0;
