@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // preset.c - game presets management
 #include "preset.h"
 #include "move_funcs_order.h"
@@ -44,9 +42,9 @@ typedef struct
 {
     const char name[32];
     int preset_id;
-} fcs_preset_name_t;
+} preset_name;
 
-static const fcs_preset_name_t fcs_preset_names[23] = {
+static const preset_name fcs_preset_names[23] = {
     {
         "bakers_dozen",
         FCS_PRESET_BAKERS_DOZEN,
@@ -173,7 +171,7 @@ static inline void apply_moves(fcs_moves_order *moves_order,
 }
 
 fc_solve_preset_ret_code_t fc_solve_apply_preset_by_ptr(
-    fc_solve_instance_t *const instance, const fcs_preset_t *const preset_ptr)
+    fcs_instance *const instance, const fcs_preset *const preset_ptr)
 {
     FCS__DECL_ERR_BUF(no_use);
 #define preset (*preset_ptr)
@@ -227,7 +225,7 @@ fc_solve_preset_ret_code_t fc_solve_apply_preset_by_ptr(
 }
 
 static inline fc_solve_preset_ret_code_t fcs_get_preset_by_id(
-    const int preset_id, const fcs_preset_t **const preset_ptr)
+    const int preset_id, const fcs_preset **const preset_ptr)
 {
     for (size_t preset_index = 0; preset_index < COUNT(fcs_presets);
          preset_index++)
@@ -243,7 +241,7 @@ static inline fc_solve_preset_ret_code_t fcs_get_preset_by_id(
 }
 
 fc_solve_preset_ret_code_t fc_solve_get_preset_by_name(
-    const char *const name, const fcs_preset_t **const preset_ptr)
+    const char *const name, const fcs_preset **const preset_ptr)
 {
     return fcs_get_preset_by_id(fcs_get_preset_id_by_name(name), preset_ptr);
 }
