@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 /*
  * pruner-main.c : pruning solver.
  */
@@ -28,8 +26,8 @@ static void my_iter_handler(void *const user_instance GCC_UNUSED,
     {
         char state_string[1000];
         freecell_solver_user_iter_state_stringify(user_instance, state_string,
-            ptr_state FC_SOLVE__PASS_PARSABLE(TRUE),
-            FALSE FC_SOLVE__PASS_T(TRUE));
+            ptr_state FC_SOLVE__PASS_PARSABLE(true),
+            false FC_SOLVE__PASS_T(true));
         printf("%s\n---------------\n\n\n", state_string);
         /* Now pass it to a secondary user_instance prune it. */
         void *const pruner = freecell_solver_user_alloc();
