@@ -1,19 +1,17 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2012 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2012 Shlomi Fish
 /*
  * pseudo_dfs_atomic_moves_solver.c - a specialised solver that runs a
  * pseudo-DFS scan. See ../docs/distributed-pseudo-dfs-solver-spec.txt
  */
 
 // #define FCS_LRU_KEY_IS_STATE
-
+#include <rinutils/longlong.h>
 #include "dbm_solver_head.h"
 #include "pseudo_dfs_cache.h"
 #include "render_state.h"
@@ -54,7 +52,7 @@ static inline bool lookup_state(store_type *const store,
 #else
     if (PValue != NULL)
     {
-        return TRUE;
+        return true;
     }
     else
     {
@@ -68,11 +66,12 @@ typedef struct
     store_type store;
     fcs_pseudo_dfs_lru_cache cache;
 
-    long pre_cache_max_count;
+    unsigned long pre_cache_max_count;
     /* The stack */
     ssize_t stack_depth, max_stack_depth;
     pseudo_dfs_stack_item *stack;
-    long count_num_processed, max_count_num_processed;
+    unsigned long count_num_processed;
+    unsigned long max_count_num_processed;
     bool solution_was_found;
     enum TERMINATE_REASON should_terminate;
     compact_allocator derived_list_allocator;
@@ -88,8 +87,8 @@ static inline void instance__inspect_new_state(
 {
     if (++instance->count_num_processed % 1000000 == 0)
     {
-        printf("Reached iteration %lld\n",
-            (long long)instance->count_num_processed);
+        printf("Reached iteration " RIN_ULL_FMT "\n",
+            (unsigned long long)instance->count_num_processed);
         fflush(stdout);
     }
 
@@ -104,8 +103,9 @@ static inline void instance__inspect_new_state(
     if (depth == max_depth)
     {
         instance->stack =
-            SREALLOC(instance->stack, ++(instance->max_stack_depth));
-        printf("Increasing to %lld\n", (long long)instance->max_stack_depth);
+            SREALLOC(instance->stack, (size_t)(++(instance->max_stack_depth)));
+        printf("Increasing to " RIN_LL_FMT "\n",
+            (long long)instance->max_stack_depth);
         fflush(stdout);
         instance->stack[max_depth] = (pseudo_dfs_stack_item){
             .next_states = NULL, .max_count_next_states = 0};
@@ -121,10 +121,10 @@ static inline void instance__inspect_new_state(
         delta_stater, state->s, &s, indirect_stacks_buffer);
     if (instance_solver_thread_calc_derived_states(instance->local_variant, &s,
             NULL, &derived_list, &(instance->derived_list_recycle_bin),
-            &(instance->derived_list_allocator), TRUE))
+            &(instance->derived_list_allocator), true))
     {
         instance->should_terminate = SOLUTION_FOUND_TERMINATE;
-        instance->solution_was_found = TRUE;
+        instance->solution_was_found = true;
         return;
     }
 
@@ -144,7 +144,7 @@ static inline void instance__inspect_new_state(
             if (i >= stack_item->max_count_next_states)
             {
                 stack_item->next_states = SREALLOC(stack_item->next_states,
-                    ++(stack_item->max_count_next_states));
+                    (size_t)(++(stack_item->max_count_next_states)));
             }
             stack_item->next_states[i] = derived_list->key;
             insert_state(&(instance->store), &(stack_item->next_states[i]));
@@ -159,7 +159,7 @@ static inline void instance__inspect_new_state(
 static inline void instance_init(dbm_solver_instance *const instance,
     const fcs_dbm_variant_type local_variant,
     fcs_state_keyval_pair *const init_state,
-    const long max_num_elements_in_cache)
+    const unsigned long max_num_elements_in_cache)
 {
     instance->local_variant = local_variant;
     fc_solve_delta_stater_init(&(instance->delta_stater), local_variant,
@@ -167,7 +167,7 @@ static inline void instance_init(dbm_solver_instance *const instance,
         FREECELLS_NUM PASS_ON_NOT_FC_ONLY(FCS_SEQ_BUILT_BY_ALTERNATE_COLOR));
     fcs_init_and_encode_state(&instance->delta_stater, local_variant,
         init_state, &instance->init_key);
-    instance->solution_was_found = FALSE;
+    instance->solution_was_found = false;
     instance->should_terminate = DONT_TERMINATE;
     instance->count_num_processed = 0;
     instance->max_count_num_processed = LONG_MAX;
@@ -196,6 +196,10 @@ static inline void instance_free(dbm_solver_instance *const instance)
     instance->stack = NULL;
 
     Word_t rc_word;
+#ifdef JERR
+#undef JERR
+#define JERR ((Word_t)(-1))
+#endif
     JHSFA(rc_word, instance->store);
 
     fcs_pdfs_cache_destroy(&(instance->cache));
@@ -246,7 +250,7 @@ static inline void instance__print_coords_to_log(
     const fcs_dbm_variant_type local_variant = instance->local_variant;
 #endif
     fprintf(
-        log_fh, "At %ld iterations Coords=[", instance->count_num_processed);
+        log_fh, "At %lu iterations Coords=[", instance->count_num_processed);
 
     const pseudo_dfs_stack_item *stack_item = instance->stack;
     const pseudo_dfs_stack_item *const end_stack_item =
@@ -301,7 +305,7 @@ int main(int argc GCC_UNUSED, char *argv[])
     FILE *const fh = fopen(filename, "r");
     if (!fh)
     {
-        fc_solve_err("Could not open file '%s' for input.\n", filename);
+        exit_error("Could not open file '%s' for input.\n", filename);
     }
     const fcs_user_state_str user_state = read_state(fh);
     fcs_state_keyval_pair init_state_pair;
@@ -316,8 +320,8 @@ int main(int argc GCC_UNUSED, char *argv[])
     FILE *const last_line_fh = popen(("tail -1 " LOG_FILENAME), "r");
     if (last_line_fh)
     {
-        long count_num_processed;
-        if (fscanf(last_line_fh, "At %ld iterations Coords=[",
+        unsigned long count_num_processed;
+        if (fscanf(last_line_fh, "At %lu iterations Coords=[",
                 &count_num_processed) == 1)
         {
             instance__load_coords_from_fh(&instance, last_line_fh);
