@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // range_solvers_gen_ms_boards.h - a header file that defines some
 // static (and preferably inline) routines for generating the Microsoft
 // boards.
@@ -44,15 +42,27 @@ static inline void card_to_string(char *const s, const CARD card)
  * routine.
  *
  * */
-void DLLEXPORT fc_solve_get_board_l(const long long deal_idx, char *const ret);
+void DLLEXPORT fc_solve_get_board_l(
+    const unsigned long long deal_idx, char *const ret);
 
 extern void DLLEXPORT fc_solve_get_board_l(
-    const long long deal_idx, char *const ret)
 #else
-static inline void get_board_l(const long long deal_idx, char *const ret)
+static inline void get_board_l(
 #endif
+#ifdef FCS_DEAL_ONLY_UP_TO_2G
+    const unsigned long long seedx
+#else
+    const unsigned long long deal_idx
+#endif
+    ,
+    char *const ret)
 {
-    long long seedx = microsoft_rand__calc_init_seedx(deal_idx);
+// #define FCS_DEAL_ONLY_UP_TO_2G
+#ifdef FCS_DEAL_ONLY_UP_TO_2G
+#else
+    microsoft_rand seedx =
+        microsoft_rand__calc_init_seedx((microsoft_rand)deal_idx);
+#endif
     strcpy(ret, "XX XX XX XX XX XX XX\n"
                 "XX XX XX XX XX XX XX\n"
                 "XX XX XX XX XX XX XX\n"
@@ -74,17 +84,25 @@ static inline void get_board_l(const long long deal_idx, char *const ret)
     microsoft_rand_uint num_cards_left = 52;
     for (size_t i = 0; i < 52; ++i)
     {
+#ifdef FCS_DEAL_ONLY_UP_TO_2G
+        const microsoft_rand_uint j =
+            microsoft_rand_rand(&seedx) % num_cards_left;
+#if 0
+        exit(-1);
+#endif
+#else
         const microsoft_rand_uint j =
             microsoft_rand__game_num_rand(&seedx, deal_idx) % num_cards_left;
+#endif
         card_to_string(&ret[offset_by_i[i]], deck[j]);
         deck[j] = deck[--num_cards_left];
     }
 }
 
 #ifndef FCS_GEN_BOARDS_WITH_EXTERNAL_API
-static inline void get_board(long deal_idx, char *ret)
+static inline void get_board(unsigned long deal_idx, char *ret)
 {
-    get_board_l((long long)deal_idx, ret);
+    get_board_l(deal_idx, ret);
 }
 #endif
 
