@@ -9,13 +9,27 @@ use Getopt::Long qw/ GetOptions /;
 use Env::Path ();
 use Path::Tiny qw/ path /;
 use File::Basename qw/ basename /;
+use CHI ();
 
-my $bindir     = path(__FILE__)->parent;
-my $abs_bindir = $bindir->absolute;
+my $glob_was_set = 0;
+my $rerun        = 0;
+my $bindir       = path(__FILE__)->parent;
+my $abs_bindir   = $bindir->absolute;
+my %progs;
 
 # Whether to use prove instead of runprove.
 my $use_prove = $ENV{FCS_USE_TEST_RUN} ? 0 : 1;
-my $num_jobs = $ENV{TEST_JOBS};
+my $num_jobs  = $ENV{TEST_JOBS};
+my $KEY       = 'FC_SOLVE__TESTS_RERUNS_CACHE_DATA_DIR';
+my $cache     = CHI->new(
+    driver => 'File',
+    root_dir =>
+        ( $ENV{$KEY} || ( ( $ENV{TMPDIR} || '/tmp' ) . '/fc-solve1temp' ) )
+);
+require lib;
+lib->import("$abs_bindir/t/lib");
+require FC_Solve::Test::Valgrind::Data;
+require FC_Solve::Paths::Base;
 
 sub _is_parallized
 {
@@ -35,6 +49,13 @@ sub run_tests
     my $tests = shift;
 
     my @cmd = ( ( $use_prove ? @{ _calc_prove() } : 'runprove' ), @$tests );
+    if (0)
+    {
+        @cmd = (
+            ( $use_prove ? @{ _calc_prove() } : 'runprove' ),
+            '-v', grep { /build-proc/ || /\.py\z/ } @$tests
+        );
+    }
     if ( $ENV{RUN_TESTS_VERBOSE} )
     {
         print "Running [@cmd]\n";
@@ -42,21 +63,66 @@ sub run_tests
 
     # Workaround for Windows spawning-SNAFU.
     my $exit_code = system(@cmd);
+    if ( !$exit_code and $rerun > 0 and ( !$glob_was_set ) )
+    {
+        foreach my $prog ( keys %progs )
+        {
+            $cache->set( $progs{$prog}, 1, '100 days' );
+        }
+    }
     exit( $exit_success ? 0 : $exit_code ? (-1) : 0 );
 }
 
 my $tests_glob = "*.{t.exe,py,t}";
 my $exclude_re_s;
+my $force_rebuild = delete( $ENV{REBUILD} );
 
 my @execute;
 GetOptions(
     '--exclude-re=s' => \$exclude_re_s,
     '--execute|e=s'  => \@execute,
     '--exit0!'       => \$exit_success,
-    '--glob=s'       => \$tests_glob,
+    '--glob=s'       => sub { $tests_glob = $_[1]; $glob_was_set = 1; },
     '--prove!'       => \$use_prove,
+    '--rebuild!'     => \$force_rebuild,
     '--jobs|j=n'     => \$num_jobs,
 ) or die "Wrong opts - $!";
+my %binaries;
+%progs =
+    map { $_ => +{ binaries => {}, } }
+    map {
+    FC_Solve::Paths::Base::exe_fn( $_->{args}->{prog} // die %{ $_->{args} } )
+    } values %{ FC_Solve::Test::Valgrind::Data->get_hash };
+
+use Digest::SHA ();
+if ( $FC_Solve::Paths::Base::IS_WIN || $force_rebuild )
+{
+    ++$rerun;
+}
+else
+{
+    foreach my $prog ( keys %progs )
+    {
+        say $prog;
+        die if !-e $prog;
+        foreach my $bin ( $prog, `ldd "$prog"` =~ m# => (\S+)#g )
+        {
+            say "bin $prog $bin";
+            $progs{$prog}{binaries}{$bin} //= (
+                $binaries{$bin} //= do
+                {
+                    Digest::SHA->new(256)->addfile($bin)->b64digest;
+                }
+            );
+        }
+        my $val = $cache->get( $progs{$prog} );
+        if ( !$val )
+        {
+            ++$rerun;
+        }
+    }
+}
+$glob_was_set ||= $exclude_re_s;
 
 sub myglob
 {
@@ -99,11 +165,10 @@ sub myglob
         $abs_bindir->child( "t", "scripts" ),
     );
 
-    my $IS_WIN = ( $^O eq "MSWin32" );
     Env::Path->CPATH->Prepend( $abs_bindir, );
 
     Env::Path->LD_LIBRARY_PATH->Prepend($fcs_path);
-    if ($IS_WIN)
+    if ($FC_Solve::Paths::Base::IS_WIN)
     {
         # For the shared objects.
         Env::Path->PATH->Append($fcs_path);
@@ -120,9 +185,10 @@ sub myglob
 
         return $bindir->child( "t", "config", $basename )->absolute;
     };
+    local $ENV{CMOCKA_MESSAGE_OUTPUT} = 'TAP';
 
     local $ENV{HARNESS_ALT_INTRP_FILE} = $get_config_fn->(
-        $IS_WIN
+        $FC_Solve::Paths::Base::IS_WIN
         ? "alternate-interpreters--mswin.yml"
         : "alternate-interpreters.yml"
     );
@@ -137,7 +203,7 @@ sub myglob
     );
 
     my $is_ninja = ( -e "build.ninja" );
-    my $MAKE = $IS_WIN ? 'gmake' : 'make';
+    my $MAKE     = $FC_Solve::Paths::Base::IS_WIN ? 'gmake' : 'make';
     if ($is_ninja)
     {
         system( "ninja", "boards" );
@@ -189,10 +255,14 @@ sub myglob
         @tests = grep { !/build-process/ } @tests;
     }
 
-    if ( $ENV{FCS_TEST_WITHOUT_VALGRIND} )
+    if ( $ENV{FCS_TEST_WITHOUT_VALGRIND} or ( $rerun == 0 ) )
     {
         @tests = grep { !/valgrind/ } @tests;
     }
+    if ( $rerun == 0 )
+    {
+        @tests = grep { !/(?:cmpdigest|verify)--/ } @tests;
+    }
 
     print STDERR <<"EOF";
 FCS_PATH = $ENV{FCS_PATH}
@@ -202,7 +272,7 @@ EOF
 
     if ( $ENV{FCS_TEST_SHELL} )
     {
-        system("bash");
+        system( $ENV{SHELL} );
     }
     elsif (@execute)
     {
