@@ -1,21 +1,16 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
-/*
- * scans.c - The code that relates to the various scans.
- * Currently Hard DFS, Soft-DFS, Random-DFS, BeFS and BFS are implemented.
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
+// scans.c - The code that relates to the various scans.
+// Currently Soft-DFS / Random-DFS, Best-FS and Breadth-FS are implemented.
 
 #include "scans.h"
 #include "meta_alloc.h"
 #include "move_stack_compact_alloc.h"
-#include "instance.h"
 
 #undef DEBUG
 
@@ -26,9 +21,8 @@
     calc_depth(FCS_STATE_kv_to_collectible(ptr_state))
 
 #ifdef FCS_RCS_STATES
-/* TODO : Unit-test this function as it had had a bug beforehand
- * because lru_side had been an unsigned long.
- * */
+// TODO : Unit-test this function as it had had a bug beforehand
+// because lru_side had been an unsigned long.
 typedef const char *lru_side;
 
 extern int __attribute__((pure))
@@ -59,7 +53,7 @@ fcs_state *fc_solve_lookup_state_key_from_val(fcs_instance *const instance,
     {
         fcs_cache_key_info *new_cache_state;
         const fcs_collectible_state *state_val;
-    } *parents_stack = SMALLOC(parents_stack, parents_stack_max_len);
+    } *parents_stack = SMALLOC(parents_stack, (size_t)parents_stack_max_len);
 
     parents_stack[0].state_val = orig_ptr_state_val;
 
@@ -143,7 +137,13 @@ fcs_state *fc_solve_lookup_state_key_from_val(fcs_instance *const instance,
             if (++parents_stack_len == parents_stack_max_len)
             {
                 parents_stack_max_len += 16;
-                parents_stack = SREALLOC(parents_stack, parents_stack_max_len);
+                const_AUTO(old_parents_stack, parents_stack);
+                parents_stack =
+                    SREALLOC(parents_stack, (size_t)parents_stack_max_len);
+                if (unlikely(!parents_stack))
+                {
+                    free(old_parents_stack);
+                }
             }
         }
     }
@@ -313,24 +313,67 @@ void fc_solve_soft_thread_init_befs_or_bfs(fcs_soft_thread *const soft_thread)
             &fcs_st_instance(soft_thread)->state_copy);
 }
 
-/*
- *  fc_solve_befs_or_bfs_do_solve() is the main event
- *  loop of the BeFS And BFS scans. It is quite simple as all it does is
- *  extract elements out of the queue or priority queue and run all the test
- *  of them.
- *
- *  It goes on in this fashion until the final state was reached or
- *  there are no more states in the queue.
- */
+static inline void befs__insert_derived_states(
+    fcs_soft_thread *const soft_thread, fcs_hard_thread *const hard_thread,
+    fcs_instance *instance GCC_UNUSED, const bool is_befs,
+    fcs_derived_states_list derived, pri_queue *const pqueue,
+    fcs_states_linked_list_item **queue_last_item)
+{
+    fcs_derived_states_list_item *derived_iter, *derived_end;
+    for (derived_end = (derived_iter = derived.states) + derived.num_states;
+         derived_iter < derived_end; derived_iter++)
+    {
+        const_AUTO(scans_ptr_new_state, derived_iter->state_ptr);
+        if (is_befs)
+        {
+#ifdef FCS_RCS_STATES
+            fcs_kv_state new_pass = {.key = fc_solve_lookup_state_key_from_val(
+                                         instance, scans_ptr_new_state),
+                .val = scans_ptr_new_state};
+#else
+            fcs_kv_state new_pass =
+                FCS_STATE_keyval_pair_to_kv(scans_ptr_new_state);
+#endif
+            fc_solve_pq_push(pqueue, scans_ptr_new_state,
+                befs_rate_state(soft_thread, WEIGHTING(soft_thread),
+                    new_pass.key, BEFS_MAX_DEPTH - kv_calc_depth(&(new_pass))));
+        }
+        else
+        {
+            /* Enqueue the new state. */
+            fcs_states_linked_list_item *last_item_next;
+
+            if (my_brfs_recycle_bin)
+            {
+                last_item_next = my_brfs_recycle_bin;
+                my_brfs_recycle_bin = my_brfs_recycle_bin->next;
+            }
+            else
+            {
+                last_item_next = NEW_BRFS_QUEUE_ITEM();
+            }
+
+            queue_last_item[0]->next = last_item_next;
+
+            queue_last_item[0]->s = scans_ptr_new_state;
+            last_item_next->next = NULL;
+            queue_last_item[0] = last_item_next;
+        }
+    }
+}
+
+// fc_solve_befs_or_bfs_do_solve() is the main event loop of the BeFS And
+// BFS scans. It is quite simple as all it does is extract elements out of
+// the queue or priority queue and run all the moves on them.
+//
+// It goes on in this fashion until the final state was reached or there are
+// no more states in the queue.
 fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
     fcs_soft_thread *const soft_thread)
 {
     fcs_hard_thread *const hard_thread = soft_thread->hard_thread;
     fcs_instance *const instance = HT_INSTANCE(hard_thread);
 
-#ifndef FCS_DISABLE_SIMPLE_SIMON
-    const bool is_simple_simon = instance->is_simple_simon;
-#endif
 #if !defined(FCS_WITHOUT_DEPTH_FIELD) &&                                       \
     !defined(FCS_HARD_CODE_CALC_REAL_DEPTH_AS_FALSE)
     const bool calc_real_depth = fcs_get_calc_real_depth(instance);
@@ -346,11 +389,9 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
     const_SLOT(effective_max_num_states_in_collection, instance);
 #endif
 
-    fcs_states_linked_list_item *queue = NULL;
-    fcs_states_linked_list_item *queue_last_item = NULL;
-    pri_queue *pqueue = NULL;
     fc_solve_solve_process_ret_t error_code;
-    fcs_derived_states_list derived = {.num_states = 0, .states = NULL};
+    fcs_derived_states_list derived = {
+        .num_states = 0, .max_num_states = 0, .states = NULL};
 
     const fcs_move_func *const moves_list = BEFS_M_VAR(soft_thread, moves_list);
     const fcs_move_func *const moves_list_end =
@@ -363,10 +404,10 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
     const bool enable_pruning = soft_thread->enable_pruning;
 #endif
 
-    fcs_int_limit_t *const instance_num_checked_states_ptr =
-        &(instance->i__num_checked_states);
+    fcs_iters_int *const instance_num_checked_states_ptr =
+        &(instance->i__stats.num_checked_states);
 #ifndef FCS_SINGLE_HARD_THREAD
-    fcs_int_limit_t *const hard_thread_num_checked_states_ptr =
+    fcs_iters_int *const hard_thread_num_checked_states_ptr =
         &(HT_FIELD(hard_thread, ht__num_checked_states));
 #endif
     const_SLOT(is_befs, soft_thread);
@@ -374,15 +415,9 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
     const_SLOT(is_optimize_scan, soft_thread);
 #endif
 
-    if (is_befs)
-    {
-        pqueue = &(BEFS_VAR(soft_thread, pqueue));
-    }
-    else
-    {
-        queue = my_brfs_queue;
-        queue_last_item = my_brfs_queue_last_item;
-    }
+    pri_queue *const pqueue = &(BEFS_VAR(soft_thread, pqueue));
+    fcs_states_linked_list_item *queue = my_brfs_queue;
+    fcs_states_linked_list_item *queue_last_item = my_brfs_queue_last_item;
     FC__STACKS__SET_PARAMS();
     const_AUTO(max_num_states, calc_ht_max_num_states(instance, hard_thread));
 #ifndef FCS_WITHOUT_ITER_HANDLER
@@ -390,23 +425,18 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
     const_SLOT(debug_iter_output_context, instance);
 #endif
 
-    /* Continue as long as there are states in the queue or
-       priority queue. */
     int8_t *const befs_positions_by_rank =
         (BEFS_M_VAR(soft_thread, befs_positions_by_rank));
 
     while (PTR_STATE != NULL)
     {
         TRACE0("Start of loop");
-        /*
-         * If we do the pruning after checking for being visited, then
-         * there's a risk of inconsistent result when being interrupted
-         * because we check once for the pruned state (after the scan
-         * was suspended) and another time for the uninterrupted state.
-         *
-         * Therefore, we prune before checking for the visited flags.
-         * */
-        TRACE0("Pruning");
+        // If we do the pruning after checking for being visited, then
+        // there's a risk of inconsistent result when being interrupted
+        // because we check once for the pruned state (after the scan
+        // was suspended) and another time for the uninterrupted state.
+        //
+        // Therefore, we prune before checking for the visited flags.
         if (fcs__should_state_be_pruned(enable_pruning, PTR_STATE))
         {
             fcs_collectible_state *const after_pruning_state =
@@ -417,33 +447,26 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
             }
         }
 
-        {
-            register const int temp_visited = FCS_S_VISITED(PTR_STATE);
+        register const int temp_visited = FCS_S_VISITED(PTR_STATE);
 
-            /*
-             * If this is an optimization scan and the state being checked is
-             * not in the original solution path - move on to the next state
-             * */
-            /*
-             * It the state has already been visited - move on to the next
-             * state.
-             * */
-            if (
+        // If this is an optimization scan and the state being checked is
+        // not in the original solution path - move on to the next state
+        // If the state has already been visited - move on to the next
+        // state.
+        if (
 #ifdef FCS_WITH_MOVES
-                is_optimize_scan
-                    ? ((!(temp_visited & FCS_VISITED_IN_SOLUTION_PATH)) ||
-                          (temp_visited & FCS_VISITED_IN_OPTIMIZED_PATH))
-                    :
+            is_optimize_scan
+                ? ((!(temp_visited & FCS_VISITED_IN_SOLUTION_PATH)) ||
+                      (temp_visited & FCS_VISITED_IN_OPTIMIZED_PATH))
+                :
 #endif
-                    ((temp_visited & FCS_VISITED_DEAD_END) ||
-                        (is_scan_visited(PTR_STATE, soft_thread_id))))
-            {
-                goto next_state;
-            }
+                ((temp_visited & FCS_VISITED_DEAD_END) ||
+                    (is_scan_visited(PTR_STATE, soft_thread_id))))
+        {
+            goto next_state;
         }
 
         TRACE0("Counting cells");
-
         if (check_if_limits_exceeded())
         {
             BEFS_M_VAR(soft_thread, first_state_to_check) = PTR_STATE;
@@ -456,15 +479,16 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
         TRACE0("debug_iter_output");
         if (debug_iter_output_func)
         {
-            debug_iter_output_func(
-                debug_iter_output_context, *(instance_num_checked_states_ptr),
+            debug_iter_output_func(debug_iter_output_context,
+                (fcs_int_limit_t) * (instance_num_checked_states_ptr),
                 calc_depth(PTR_STATE), (void *)instance, &pass,
 #ifdef FCS_WITHOUT_VISITED_ITER
                 0
 #else
                 ((FCS_S_PARENT(PTR_STATE) == NULL)
                         ? 0
-                        : FCS_S_VISITED_ITER(FCS_S_PARENT(PTR_STATE)))
+                        : (fcs_int_limit_t)FCS_S_VISITED_ITER(
+                              FCS_S_PARENT(PTR_STATE)))
 #endif
             );
         }
@@ -487,18 +511,11 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
         soft_thread->num_vacant_freecells = num_vacant_freecells;
         soft_thread->num_vacant_stacks = num_vacant_stacks;
         fc_solve__calc_positions_by_rank_data(
-            soft_thread, &FCS_SCANS_the_state, befs_positions_by_rank
-#ifndef FCS_DISABLE_SIMPLE_SIMON
-            ,
-            is_simple_simon
-#endif
-        );
+            soft_thread, &FCS_SCANS_the_state, befs_positions_by_rank);
 
-        TRACE0("perform_tests");
-        /*
-         * Do all the tests at one go, because that is the way it should be
-         * done for BFS and BeFS.
-         */
+        TRACE0("perform_moves");
+        // Do all the tests at one go, because that is the way it should be
+        // done for BFS and BeFS.
         derived.num_states = 0;
         for (const fcs_move_func *move_func_ptr = moves_list;
              move_func_ptr < moves_list_end; move_func_ptr++)
@@ -511,55 +528,10 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
             FCS_S_VISITED(PTR_STATE) |= FCS_VISITED_ALL_TESTS_DONE;
         }
 
-        /* Increase the number of iterations by one .
-         * */
         BUMP_NUM_CHECKED_STATES();
         TRACE0("Insert all states");
-        /* Insert all the derived states into the PQ or Queue */
-        fcs_derived_states_list_item *derived_iter, *derived_end;
-        for (derived_end = (derived_iter = derived.states) + derived.num_states;
-             derived_iter < derived_end; derived_iter++)
-        {
-            const_AUTO(scans_ptr_new_state, derived_iter->state_ptr);
-            if (is_befs)
-            {
-#ifdef FCS_RCS_STATES
-                fcs_kv_state new_pass = {
-                    .key = fc_solve_lookup_state_key_from_val(
-                        instance, scans_ptr_new_state),
-                    .val = scans_ptr_new_state};
-#else
-                fcs_kv_state new_pass =
-                    FCS_STATE_keyval_pair_to_kv(scans_ptr_new_state);
-#endif
-                fc_solve_pq_push(pqueue, scans_ptr_new_state,
-                    befs_rate_state(soft_thread, WEIGHTING(soft_thread),
-                        new_pass.key,
-                        BEFS_MAX_DEPTH - kv_calc_depth(&(new_pass))));
-            }
-            else
-            {
-                /* Enqueue the new state. */
-                fcs_states_linked_list_item *last_item_next;
-
-                if (my_brfs_recycle_bin)
-                {
-                    last_item_next = my_brfs_recycle_bin;
-                    my_brfs_recycle_bin = my_brfs_recycle_bin->next;
-                }
-                else
-                {
-                    last_item_next = NEW_BRFS_QUEUE_ITEM();
-                }
-
-                queue_last_item->next = last_item_next;
-
-                queue_last_item->s = scans_ptr_new_state;
-                last_item_next->next = NULL;
-                queue_last_item = last_item_next;
-            }
-        }
-
+        befs__insert_derived_states(soft_thread, hard_thread, instance, is_befs,
+            derived, pqueue, &queue_last_item);
 #ifdef FCS_WITH_MOVES
         if (is_optimize_scan)
         {
@@ -585,51 +557,38 @@ fc_solve_solve_process_ret_t fc_solve_befs_or_bfs_do_solve(
 
     next_state:
         TRACE0("Label next state");
-        /*
-            Extract the next item in the queue/priority queue.
-        */
+        fcs_collectible_state *new_ptr_state;
+        if (is_befs)
         {
-            fcs_collectible_state *new_ptr_state;
-            if (is_befs)
+            /* It is an BeFS scan */
+            fc_solve_pq_pop(pqueue, &(new_ptr_state));
+        }
+        else
+        {
+            const_AUTO(save_item, queue->next);
+            if (save_item != queue_last_item)
             {
-                /* It is an BeFS scan */
-                fc_solve_pq_pop(pqueue, &(new_ptr_state));
+                new_ptr_state = save_item->s;
+                queue->next = save_item->next;
+                save_item->next = my_brfs_recycle_bin;
+                my_brfs_recycle_bin = save_item;
             }
             else
             {
-                const_AUTO(save_item, queue->next);
-                if (save_item != queue_last_item)
-                {
-                    new_ptr_state = save_item->s;
-                    queue->next = save_item->next;
-                    save_item->next = my_brfs_recycle_bin;
-                    my_brfs_recycle_bin = save_item;
-                }
-                else
-                {
-                    new_ptr_state = NULL;
-                }
+                new_ptr_state = NULL;
             }
-            ASSIGN_ptr_state(new_ptr_state);
         }
+        ASSIGN_ptr_state(new_ptr_state);
     }
 
     error_code = FCS_STATE_IS_NOT_SOLVEABLE;
 my_return_label:
-#ifdef FCS_WITH_MOVES
-    instance->final_state = PTR_STATE;
-#endif
-    /* Free the memory that was allocated by the
-     * derived states list */
+    FCS_SET_final_state();
     if (derived.states != NULL)
     {
         free(derived.states);
     }
-
-    if (!is_befs)
-    {
-        my_brfs_queue_last_item = queue_last_item;
-    }
+    my_brfs_queue_last_item = queue_last_item;
 
     return error_code;
 }
