@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2009 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2009 Shlomi Fish
 /*
  * scans.h - header file for the scans.c - Best-First-Search and Soft-DFS
  * scans.
@@ -44,12 +42,7 @@ static inline void fc_solve__assign_dest_stack_and_col_ptr(
 static inline void fc_solve__calc_positions_by_rank_data(
     fcs_soft_thread *const soft_thread GCC_UNUSED,
     const fcs_state *const ptr_state_key,
-    fcs__positions_by_rank positions_by_rank
-#ifndef FCS_DISABLE_SIMPLE_SIMON
-    ,
-    const bool is_simple_simon
-#endif
-)
+    fcs__positions_by_rank positions_by_rank)
 {
 #ifndef HARD_CODED_ALL
     var_AUTO(instance, fcs_st_instance(soft_thread));
@@ -59,7 +52,7 @@ static inline void fc_solve__calc_positions_by_rank_data(
     memset(positions_by_rank, -1, sizeof(fcs__positions_by_rank));
 
 #ifndef FCS_DISABLE_SIMPLE_SIMON
-    if (is_simple_simon)
+    if (instance->is_simple_simon)
     {
 #define FCS_POS_IDX(rank, suit) ((suit)*FCS_SS_POS_BY_RANK_WIDTH + (rank))
         fcs_pos_by_rank *const p_by_r = (fcs_pos_by_rank *)positions_by_rank;
@@ -75,7 +68,7 @@ static inline void fc_solve__calc_positions_by_rank_data(
                 const int rank = fcs_card_rank(card);
 
                 p_by_r[FCS_POS_IDX(rank, suit)] =
-                    (fcs_pos_by_rank){.col = ds, .height = dc};
+                    (fcs_pos_by_rank){.col = (int8_t)ds, .height = (int8_t)dc};
             }
         }
     }
@@ -118,12 +111,13 @@ static inline void fc_solve__calc_positions_by_rank_data(
                     if (!fcs_is_parent_card(dest_below_card, dest_card))
                     {
                         fc_solve__assign_dest_stack_and_col_ptr(
-                            positions_by_rank, ds, dc, dest_card);
+                            positions_by_rank, (int8_t)ds, (int8_t)dc,
+                            dest_card);
                     }
                 }
             }
             fc_solve__assign_dest_stack_and_col_ptr(
-                positions_by_rank, ds, top_card_idx, dest_card);
+                positions_by_rank, (int8_t)ds, (int8_t)top_card_idx, dest_card);
         }
     }
 #undef state_key
@@ -170,6 +164,12 @@ extern fcs_collectible_state *fc_solve_sfs_check_state_end(fcs_soft_thread *,
 #endif
     fcs_kv_state *FCS__pass_moves(fcs_move_stack *));
 
+#ifdef FCS_WITH_MOVES
+#define FCS_SET_final_state() instance->final_state = PTR_STATE
+#else
+#define FCS_SET_final_state()
+#endif
+
 #ifdef __cplusplus
 }
 #endif
