@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // scans_impl.h - code implementing the various scans as inline functions.
 #pragma once
 
@@ -20,17 +18,17 @@ extern "C" {
 
 #ifdef FCS_SINGLE_HARD_THREAD
 #define check_if_limits_exceeded__num()                                        \
-    ((*instance_num_checked_states_ptr) == max_num_states)
+    ((*instance_num_checked_states_ptr) >= max_num_states)
 #else
 #define check_if_limits_exceeded__num()                                        \
-    ((*hard_thread_num_checked_states_ptr) == max_num_states)
+    ((*hard_thread_num_checked_states_ptr) >= max_num_states)
 #endif
 
 #ifdef FCS_DISABLE_NUM_STORED_STATES
 #define check_if_limits_exceeded__num_states()
 #else
 #define check_if_limits_exceeded__num_states()                                 \
-    || (instance->num_states_in_collection >=                                  \
+    || (instance->i__stats.num_states_in_collection >=                         \
            effective_max_num_states_in_collection)
 #endif
 
@@ -45,7 +43,7 @@ extern "C" {
 #define BEFS_MAX_DEPTH 20000
 
 #ifdef FCS_FREECELL_ONLY
-#define is_filled_by_any_card() TRUE
+#define is_filled_by_any_card() true
 #else
 #define is_filled_by_any_card()                                                \
     (INSTANCE_EMPTY_STACKS_FILL == FCS_ES_FILLED_BY_ANY_CARD)
@@ -75,7 +73,7 @@ static inline void fc_solve_initialize_befs_rater(
     const bool unlimited_sequence_move_var = INSTANCE_UNLIMITED_SEQUENCE_MOVE;
 #define unlimited_sequence_move unlimited_sequence_move_var
 #else
-#define unlimited_sequence_move FALSE
+#define unlimited_sequence_move false
 #endif
 
     const fc_solve_weighting_float num_cards_out_factor =
@@ -112,9 +110,9 @@ static inline void fc_solve_initialize_befs_rater(
         W(FCS_BEFS_WEIGHT_NUM_CARDS_NOT_ON_PARENTS) / (LOCAL_DECKS_NUM * 52);
 
     weighting->should_go_over_stacks =
-        (weighting->max_sequence_move_factor ||
-            weighting->cards_under_sequences_factor ||
-            weighting->seqs_over_renegade_cards_factor);
+        ((bool)weighting->max_sequence_move_factor ||
+            (bool)weighting->cards_under_sequences_factor ||
+            (bool)weighting->seqs_over_renegade_cards_factor);
 }
 #undef unlimited_sequence_move
 #undef W
@@ -185,7 +183,7 @@ static inline pq_rating befs_rate_state(
     const bool unlimited_sequence_move_var = INSTANCE_UNLIMITED_SEQUENCE_MOVE;
 #define unlimited_sequence_move unlimited_sequence_move_var
 #else
-#define unlimited_sequence_move FALSE
+#define unlimited_sequence_move false
 #endif
 
     fcs_seq_cards_power_type cards_under_sequences = 0;
@@ -195,7 +193,7 @@ static inline pq_rating befs_rate_state(
         (max(0, negated_depth) * weighting->depth_factor);
     const_PTR(
         num_cards_out_lookup_table, weighting->num_cards_out_lookup_table);
-    if (num_cards_out_lookup_table[1])
+    if ((bool)num_cards_out_lookup_table[1])
     {
         const int num_foundations = (LOCAL_DECKS_NUM << 2);
         for (int found_idx = 0; found_idx < num_foundations; ++found_idx)
@@ -256,7 +254,7 @@ static inline pq_rating befs_rate_state(
 
     const fc_solve_weighting_float num_cards_not_on_parents_weight =
         weighting->num_cards_not_on_parents_factor;
-    if (num_cards_not_on_parents_weight)
+    if ((bool)num_cards_not_on_parents_weight)
     {
         int num_cards_not_on_parents = (LOCAL_DECKS_NUM * 52);
         for (int stack_idx = 0; stack_idx < LOCAL_STACKS_NUM; stack_idx++)
@@ -342,7 +340,7 @@ static inline void calculate_real_depth(
         /* Assign the new depth throughout the path */
         while (FCS_S_DEPTH(temp_state) != this_real_depth)
         {
-            FCS_S_DEPTH(temp_state) = this_real_depth;
+            FCS_S_DEPTH(temp_state) = (int)this_real_depth;
             --this_real_depth;
             temp_state = FCS_S_PARENT(temp_state);
         }
@@ -453,9 +451,9 @@ static inline bool fcs__should_state_be_pruned(
 #define CALC_HARD_THREAD_MAX_NUM_CHECKED_STATES__HELPER()                      \
     (HT_FIELD(hard_thread, ht__num_checked_states) +                           \
         (instance->effective_max_num_checked_states -                          \
-            (instance->i__num_checked_states)))
+            (instance->i__stats.num_checked_states)))
 #endif
-static inline fcs_int_limit_t calc_ht_max_num_states(
+static inline fcs_iters_int calc_ht_max_num_states(
     const fcs_instance *const instance GCC_UNUSED,
     const fcs_hard_thread *const hard_thread)
 {
