@@ -1,16 +1,15 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // split_cmd_line.c: split command line arguments from a big string according
 // to a subset of Bourne shell's semantics. Useful for reading command
 // line arguments from files.
 #include "split_cmd_line.h"
+#include "freecell-solver/config.h"
 
 typedef struct
 {
@@ -41,26 +40,37 @@ static inline void add_to_last_arg(
     if (manager->last_arg_ptr == manager->last_arg_end)
     {
         char *const new_last_arg = SREALLOC(manager->last_arg,
-            manager->last_arg_end - manager->last_arg + 1024);
+            (size_t)(manager->last_arg_end - manager->last_arg + 1024));
         manager->last_arg_ptr += new_last_arg - manager->last_arg;
         manager->last_arg_end += new_last_arg - manager->last_arg + 1024;
         manager->last_arg = new_last_arg;
     }
 }
 
+// Windows...
+#ifndef HAVE_STRNDUP
+static inline char *strndup(const char *s, const size_t n)
+{
+    char *ret = malloc(n + 1);
+    if (ret)
+    {
+        strncpy(ret, s, n + 1);
+        ret[n] = '\0';
+    }
+    return ret;
+}
+#endif
 static inline void push_args_last_arg(args_man_wrapper *const manager)
 {
-    const int len = manager->last_arg_ptr - manager->last_arg;
-    char *const new_arg = SMALLOC(new_arg, len + 1);
-    strncpy(new_arg, manager->last_arg, len);
-    new_arg[len] = '\0';
+    const size_t len = (size_t)(manager->last_arg_ptr - manager->last_arg);
+    char *const new_arg = strndup(manager->last_arg, len);
 
     manager->args_man.argv[(manager->args_man.argc)++] = new_arg;
 
     if (!(manager->args_man.argc & (FC_SOLVE__ARGS_MAN_GROW_BY - 1)))
     {
         manager->args_man.argv = SREALLOC(manager->args_man.argv,
-            manager->args_man.argc + FC_SOLVE__ARGS_MAN_GROW_BY);
+            (size_t)(manager->args_man.argc + FC_SOLVE__ARGS_MAN_GROW_BY));
     }
 
     /* Reset last_arg_ptr so we will have an entirely new argument */
@@ -89,7 +99,7 @@ fcs_args_man fc_solve_args_man_chop(const char *const string)
 
     while (*s != '\0')
     {
-        bool push_next_arg_flag = FALSE;
+        bool push_next_arg_flag = false;
 
         while (is_whitespace(*s))
         {
@@ -109,8 +119,8 @@ fcs_args_man fc_solve_args_man_chop(const char *const string)
             continue;
         }
 
-        bool should_still_loop = TRUE;
-        bool in_arg = FALSE;
+        bool should_still_loop = true;
+        bool in_arg = false;
         while (should_still_loop)
         {
             switch (*s)
@@ -121,8 +131,8 @@ fcs_args_man fc_solve_args_man_chop(const char *const string)
             case '\0':
             case '\r':
 
-                push_next_arg_flag = TRUE;
-                should_still_loop = FALSE;
+                push_next_arg_flag = true;
+                should_still_loop = false;
 
                 break;
 
@@ -134,15 +144,15 @@ fcs_args_man fc_solve_args_man_chop(const char *const string)
                 {
                 case '\0':
                     s--;
-                    push_next_arg_flag = TRUE;
-                    should_still_loop = FALSE;
+                    push_next_arg_flag = true;
+                    should_still_loop = false;
                     break;
                 case '\r':
                 case '\n':
                     /* Skip to the next line. */
                     if (!in_arg)
                     {
-                        should_still_loop = FALSE;
+                        should_still_loop = false;
                     }
                     break;
                 default:
@@ -154,8 +164,8 @@ fcs_args_man fc_solve_args_man_chop(const char *const string)
 
             case '\"':
 
-                in_arg = TRUE;
-                while (TRUE)
+                in_arg = true;
+                while (true)
                 {
                     const_AUTO(c, *(++s));
                     switch (c)
@@ -204,18 +214,18 @@ fcs_args_man fc_solve_args_man_chop(const char *const string)
 
             case '#':
 
-                in_arg = FALSE;
+                in_arg = false;
                 /* Skip to the next line */
                 while ((*s != '\0') && (*s != '\n'))
                 {
                     s++;
                 }
-                push_next_arg_flag = TRUE;
-                should_still_loop = FALSE;
+                push_next_arg_flag = true;
+                should_still_loop = false;
                 break;
 
             default:
-                in_arg = TRUE;
+                in_arg = true;
                 add_to_last_arg(&manager, *s);
                 s++;
                 break;
