@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2012 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2012 Shlomi Fish
 // split_fcc_solver.c - a specialised solver that solves one FCC (=
 // fully connected component) at a time - meant to try to
 // reduce the memory consumption. See
@@ -14,8 +12,8 @@
 // in the Freecell Solver git repository.
 #include "dbm_solver_head.h"
 #include <sys/tree.h>
-#include <assert.h>
 #include "depth_multi_queue.h"
+#include "rinutils/portable_time.h"
 
 typedef struct
 {
@@ -63,7 +61,7 @@ typedef struct
     fcs_dbm_collection_by_depth coll;
     fcs_lock global_lock;
     const char *offload_dir_path;
-    int curr_depth;
+    size_t curr_depth;
     dbm_instance_common_elems common;
     meta_allocator fcc_meta_alloc;
     FccEntryPointList fcc_entry_points;
@@ -98,7 +96,7 @@ typedef struct
 #include "dbm_procs.h"
 #include "fcs_base64.h"
 RB_GENERATE_STATIC(
-    FccEntryPointList, FccEntryPointNode, entry_, FccEntryPointNode_compare);
+    FccEntryPointList, FccEntryPointNode, entry_, FccEntryPointNode_compare)
 
 static inline void instance_init(dbm_solver_instance *const instance,
     const fcs_dbm_common_input *const inp,
@@ -119,7 +117,7 @@ static inline void instance_init(dbm_solver_instance *const instance,
     instance->moves_base64_encoding_buffer = NULL;
     instance->moves_base64_encoding_buffer_max_len = 0;
     {
-        int curr_depth = 0;
+        size_t curr_depth = 0;
         {
             for (size_t i = 0;
                  i < COUNT(fingerprint_which_irreversible_moves_bitmask->s);
@@ -140,7 +138,7 @@ static inline void instance_init(dbm_solver_instance *const instance,
     fcs_lock_init(&instance->global_lock);
     instance->offload_dir_path = inp->offload_dir_path;
     fcs_dbm__common_init(&(instance->common), inp->iters_delta_limit,
-        inp->local_variant, out_fh);
+        inp->max_num_states_in_collection, inp->local_variant, out_fh);
 
     fcs_lock_init(&instance->output_lock);
     fcs_lock_init(&instance->fcc_entry_points_lock);
@@ -186,8 +184,8 @@ static void *instance_run_solver_thread(void *const void_arg)
     fcs_derived_state *derived_list = NULL, *derived_list_recycle_bin = NULL;
     compact_allocator derived_list_allocator;
     fcs_state_keyval_pair state;
+#ifdef WITH__base64_encoding_buffer
     char *base64_encoding_buffer = NULL;
-#if 0
     size_t base64_encoding_buffer_max_len = 0;
 #endif
 
@@ -202,7 +200,7 @@ static void *instance_run_solver_thread(void *const void_arg)
     const_AUTO(local_variant, instance->common.variant);
 
     fcs_dbm_queue_item *item = NULL, *prev_item = NULL;
-    long queue_num_extracted_and_processed = 0;
+    unsigned long queue_num_extracted_and_processed = 0;
     fc_solve_compact_allocator_init(
         &(derived_list_allocator), &(thread->thread_meta_alloc));
     FILE *const out_fh = instance->common.out_fh;
@@ -226,7 +224,10 @@ static void *instance_run_solver_thread(void *const void_arg)
             if (fcs_depth_multi_queue__extract(&(coll->depth_queue),
                     &(thread->state_depth), (offloading_queue_item *)(&token)))
             {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wnull-dereference"
                 physical_item.key = token->key;
+#pragma GCC diagnostic pop
                 item = &physical_item;
                 instance_increment(instance);
             }
@@ -273,11 +274,11 @@ static void *instance_run_solver_thread(void *const void_arg)
                 &(key)
             );
 
-            bool to_prune = FALSE;
-            bool to_output = FALSE;
+            bool to_prune = false;
+            bool to_output = false;
             if (val_proto)
             {
-                val_proto->kv.val.is_reachable = TRUE;
+                val_proto->kv.val.is_reachable = true;
                 const int moves_count = instance->start_key_moves_count
                     + item->moves_seq.count;
 
@@ -286,7 +287,7 @@ static void *instance_run_solver_thread(void *const void_arg)
                     if (val_proto->kv.val.depth <= moves_count)
                     {
                         /* We can prune based on here. */
-                        to_prune = TRUE;
+                        to_prune = true;
                     }
                     else
                     {
@@ -294,18 +295,18 @@ static void *instance_run_solver_thread(void *const void_arg)
                          * for future trimming. */
                         to_output = !(val_proto->kv.val.was_consumed);
                         val_proto->kv.val.depth = moves_count;
-                        val_proto->kv.val.was_consumed = TRUE;
+                        val_proto->kv.val.was_consumed = true;
                     }
                 }
                 else
                 {
                     if (! val_proto->kv.val.was_consumed)
                     {
-                        to_output = TRUE;
+                        to_output = true;
                         if (val_proto->kv.val.depth >= moves_count)
                         {
                             val_proto->kv.val.depth = moves_count;
-                            val_proto->kv.val.was_consumed = TRUE;
+                            val_proto->kv.val.was_consumed = true;
                         }
                     }
                 }
@@ -348,7 +349,7 @@ static void *instance_run_solver_thread(void *const void_arg)
 
             if (instance_solver_thread_calc_derived_states(local_variant,
                     &state, token, &derived_list, &derived_list_recycle_bin,
-                    &derived_list_allocator, TRUE))
+                    &derived_list_allocator, true))
             {
                 fcs_lock_lock(&instance->global_lock);
                 fcs_dbm__found_solution(&(instance->common), token, item);
@@ -380,7 +381,9 @@ static void *instance_run_solver_thread(void *const void_arg)
         prev_item = item;
     }
 
+#ifdef WITH__base64_encoding_buffer
     free(base64_encoding_buffer);
+#endif
     fc_solve_compact_allocator_finish(&(derived_list_allocator));
     TRACE("%s\n", "instance_run_solver_thread end");
     return NULL;
@@ -401,7 +404,7 @@ static inline void instance_alloc_num_moves(
 
 static inline void instance_check_key(
     dbm_solver_thread *const thread, dbm_solver_instance *const instance,
-    const int key_depth, fcs_encoded_state_buffer *const key,
+    const size_t key_depth, fcs_encoded_state_buffer *const key,
     fcs_dbm_record *const parent, const unsigned char move GCC_UNUSED,
     const fcs_which_moves_bitmask *const which_irreversible_moves_bitmask
 #ifndef FCS_DBM_WITHOUT_CACHES
@@ -453,7 +456,7 @@ static inline void instance_check_key(
                     which_irreversible_moves_bitmask->s[i] +
                     instance->fingerprint_which_irreversible_moves_bitmask.s[i];
             }
-            int trace_num;
+            size_t trace_num;
             fcs_encoded_state_buffer *trace;
             fcs_lock_lock(&instance->fcc_exit_points_output_lock);
             /* instance->storage_lock is already locked
@@ -467,19 +470,23 @@ static inline void instance_check_key(
                     &(instance->fcc_entry_points), &fcc_entry_key);
                 if (!val_proto)
                 {
-                    return;
+                    goto cleanup;
                 }
                 const long location_in_file =
                     val_proto->kv.val.location_in_file;
                 fseek(instance->fingerprint_fh, location_in_file, SEEK_SET);
 
 #ifdef HAVE_GETLINE
-                getline(&(instance->fingerprint_line),
-                    &(instance->fingerprint_line_size),
-                    instance->fingerprint_fh);
+                if (getline(&(instance->fingerprint_line),
+                        &(instance->fingerprint_line_size),
+                        instance->fingerprint_fh) <= 0)
+                {
+                    abort();
+                }
 #else
                 fgets(instance->fingerprint_line,
-                    instance->fingerprint_line_size, instance->fingerprint_fh);
+                    (int)instance->fingerprint_line_size,
+                    instance->fingerprint_fh);
 #endif
                 char *const moves_to_state_enc =
                     strchr(strchr(instance->fingerprint_line, ' ') + 1, ' ') +
@@ -502,9 +509,10 @@ static inline void instance_check_key(
                 moves_to_state_len + trace_num - 1;
             instance_alloc_num_moves(instance, added_moves_to_output);
             unsigned char *const moves_to_state = instance->moves_to_state;
-            for (int i = trace_num - 1; i > 0; i--)
+            ssize_t s_trace_num = (ssize_t)trace_num - 1;
+            for (ssize_t i = s_trace_num; i > 0; --i)
             {
-                moves_to_state[moves_to_state_len + trace_num - 1 - i] =
+                moves_to_state[(ssize_t)moves_to_state_len + s_trace_num - i] =
                     get_move_from_parent_to_child(instance,
                         &(thread->delta_stater), trace[i], trace[i - 1]);
             }
@@ -532,7 +540,7 @@ static inline void instance_check_key(
                 &unused_output_len);
             /* Output the exit point. */
             fprintf(instance->fcc_exit_points_out_fh,
-                "%s %s " FCS_LL_FMT " %s\n", fingerprint_base64, state_base64,
+                "%s %s " RIN_LL_FMT " %s\n", fingerprint_base64, state_base64,
                 (long long)added_moves_to_output,
                 instance->moves_base64_encoding_buffer);
 #ifdef DEBUG_OUT
@@ -550,6 +558,7 @@ static inline void instance_check_key(
             }
 #endif
             fflush(instance->fcc_exit_points_out_fh);
+        cleanup:
             fcs_lock_unlock(&instance->fcc_exit_points_output_lock);
             free(trace);
         }
@@ -571,17 +580,20 @@ static void instance_run_all_threads(dbm_solver_instance *const instance,
 #endif
 
     dbm__spawn_threads(instance, num_threads, threads);
+#if 0
     if (!instance->common.queue_solution_was_found)
     {
         mark_and_sweep_old_states(instance,
             fc_solve_dbm_store_get_dict(instance->coll.cache_store.store),
             instance->curr_depth);
     }
+#endif
     dbm__free_threads(instance, num_threads, threads, free_thread);
 }
 
 int main(int argc, char *argv[])
 {
+    apr_initialize();
     build_decoding_table();
 #ifdef DEBUG_OUT
     fcs_state_locs_struct locs;
@@ -625,14 +637,14 @@ int main(int argc, char *argv[])
 
     if (arg != argc)
     {
-        fc_solve_err("%s\n", "Junk at the end of the parameters");
+        exit_error("%s\n", "Junk at the end of the parameters");
     }
 
     if (!(filename && fingerprint_input_location_path &&
             mod_base64_fcc_fingerprint && path_to_output_dir &&
             inp.offload_dir_path))
     {
-        fc_solve_err("One or more of these parameters was not specified: %s\n",
+        exit_error("One or more of these parameters was not specified: %s\n",
             "--board, --fingerprint, --input, --output, --offload-dir-path");
     }
     fcs_state_keyval_pair init_state;
@@ -651,16 +663,15 @@ int main(int argc, char *argv[])
         if (fingerprint_data_len !=
             sizeof(fingerprint_which_irreversible_moves_bitmask))
         {
-            fc_solve_err("%s\n", "--fingerprint is invalid length.");
+            exit_error("%s\n", "--fingerprint is invalid length.");
         }
     }
 
     const_AUTO(local_variant, inp.local_variant);
+#ifndef FCS_DBM_SINGLE_THREAD
     const_AUTO(num_threads, inp.num_threads);
-
-    /* Calculate the fingerprint_which_irreversible_moves_bitmask's curr_depth.
-     */
-
+#endif
+    // Calculate the fingerprint_which_irreversible_moves_bitmask's curr_depth.
     fcs_delta_stater delta;
     fc_solve_delta_stater_init(&delta, local_variant, &init_state.s, STACKS_NUM,
         FREECELLS_NUM PASS_ON_NOT_FC_ONLY(CALC_SEQUENCES_ARE_BUILT_BY()));
@@ -675,7 +686,7 @@ int main(int argc, char *argv[])
     FILE *fingerprint_fh = fopen(fingerprint_input_location_path, "rt");
     if (!fingerprint_fh)
     {
-        fc_solve_err("Cannot open '%s' for reading. Exiting.",
+        exit_error("Cannot open '%s' for reading. Exiting.",
             fingerprint_input_location_path);
     }
 
@@ -689,13 +700,13 @@ int main(int argc, char *argv[])
 #endif
 
     long location_in_file = 0;
-    bool was_init = FALSE;
+    bool was_init = false;
 #ifdef HAVE_GETLINE
     while (getline(&instance.fingerprint_line, &instance.fingerprint_line_size,
                fingerprint_fh) != -1)
 #else
-    while (fgets(instance.fingerprint_line, instance.fingerprint_line_size - 1,
-        fingerprint_fh))
+    while (fgets(instance.fingerprint_line,
+        (int)instance.fingerprint_line_size - 1, fingerprint_fh))
 #endif
     {
         FccEntryPointNode *const entry_point = fcs_compact_alloc_ptr(
@@ -725,13 +736,13 @@ int main(int argc, char *argv[])
 #ifndef FCS_DBM_WITHOUT_CACHES
         cache_store__insert_key(&(instance.cache_store), &(key_ptr->kv.key.key), &parent_state_enc, NULL, '\0');
 #else
-        token = fc_solve_dbm_store_insert_key_value(instance.coll.store, &(key_ptr->kv.key.key), NULL, TRUE);
+        token = fc_solve_dbm_store_insert_key_value(instance.coll.store, &(key_ptr->kv.key.key), NULL, true);
 #endif
 
 #if 0
         entry_point->kv.val.was_consumed =
             entry_point->kv.val.is_reachable =
-            FALSE;
+            false;
 #endif
 #endif
         entry_point->kv.val.location_in_file = location_in_file;
@@ -750,7 +761,7 @@ int main(int argc, char *argv[])
             {
                 fcs_depth_multi_queue__init(&(instance.coll.depth_queue),
                     instance.offload_dir_path, state_depth, &(token));
-                was_init = TRUE;
+                was_init = true;
             }
         }
         ++instance.common.num_states_in_collection;
@@ -785,7 +796,7 @@ int main(int argc, char *argv[])
     free(instance.moves_base64_encoding_buffer);
     free(instance.fingerprint_line);
     fc_solve_delta_stater_release(&delta);
-
+    apr_terminate();
     return 0;
 }
 #ifdef FCS_KAZ_TREE_USE_RECORD_DICT_KEY
