@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // state.c - state functions module for Freecell Solver
 #include "state.h"
 #include "freecell-solver/fcs_enums.h"
@@ -30,7 +28,7 @@ static inline int fcs_stack_compare(const void *s1, const void *s2)
 #elif defined(INDIRECT_STACK_STATES)
 
 #define DECLARE_TEMP_STACK() fcs_card *temp_stack
-#define STACK_COMPARE(a, b) (fc_solve_stack_compare_for_comparison(a, b))
+#define STACK_COMPARE(a, b) (fc_solve_stack_compare_for_canonize(a, b))
 #define GET_STACK(c) (state_key->columns[c])
 #define COPY_STACK(d, s) (d = s)
 
@@ -317,7 +315,7 @@ void fc_solve_state_as_string(char *output_s, const fcs_state *const state,
 #if MAX_NUM_FREECELLS > 0
 #ifdef FC_SOLVE__REMOVE_TRAILING_WHITESPACE_IN_OUTPUT
         int max_freecell_idx = -1;
-        for (int i = FREECELLS_NUM__VAL - 1; i >= 0; i--)
+        for (int i = (int)FREECELLS_NUM__VAL - 1; i >= 0; i--)
         {
             if (fcs_card_is_valid(fcs_freecell_card(*state, freecell_locs[i])))
             {
@@ -326,7 +324,7 @@ void fc_solve_state_as_string(char *output_s, const fcs_state *const state,
             }
         }
 #else
-        const int max_freecell_idx = FREECELLS_NUM__VAL - 1;
+        const int max_freecell_idx = (int)FREECELLS_NUM__VAL - 1;
 #endif
 
         if (max_freecell_idx >= 0)
