@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // state.h - header file for state functions and macros for Freecell Solver
 #pragma once
 
@@ -15,7 +13,8 @@ extern "C" {
 #endif
 
 #include <ctype.h>
-#include "fcs_conf.h"
+#include "freecell-solver/fcs_conf.h"
+#include "freecell-solver/fcs_limit.h"
 
 #ifdef FCS_WITH_MOVES
 #include "freecell-solver/fcs_move.h"
@@ -23,7 +22,7 @@ extern "C" {
 
 #include "freecell-solver/fcs_enums.h"
 
-#include "rinutils.h"
+#include "rinutils/rinutils.h"
 #include "game_type_limit.h"
 
 #include "internal_move_struct.h"
@@ -48,7 +47,8 @@ extern "C" {
     ((FCS_S_SCAN_VISITED(ptr_state))[(scan_id) >> FCS_CHAR_BIT_SIZE_LOG2] &    \
         (1 << ((scan_id) & ((1 << (FCS_CHAR_BIT_SIZE_LOG2)) - 1))))
 
-typedef char fcs_card;
+typedef uint_fast16_t stack_i;
+typedef uint8_t fcs_card;
 typedef fcs_card *fcs_cards_column;
 typedef const fcs_card *fcs_const_cards_column;
 typedef fcs_card fcs_state_foundation;
@@ -113,9 +113,9 @@ typedef struct
         {                                                                      \
             (state_val).stacks_copy_on_write_flags |= (1 << idx);              \
             const_AUTO(copy_stack_col, fcs_state_get_col((state_key), idx));   \
-            memcpy(&buffer[idx << 7], copy_stack_col,                          \
+            memcpy(&buffer[idx << 6], copy_stack_col,                          \
                 fcs_col_len(copy_stack_col) + 1);                              \
-            fcs_state_get_col((state_key), idx) = &buffer[idx << 7];           \
+            fcs_state_get_col((state_key), idx) = &buffer[idx << 6];           \
         }                                                                      \
     }
 
@@ -166,7 +166,7 @@ typedef uint8_t fcs_locs_type;
 #define fcs_card_is_empty(card) ((card) == 0)
 #define fcs_card_is_valid(card) ((card) != 0)
 
-static inline fcs_card fcs_make_card(const int rank, const int suit)
+static inline fcs_card fcs_make_card(const fcs_card rank, const fcs_card suit)
 {
     return (fcs_card)((((fcs_card)rank) << 2) | ((fcs_card)suit));
 }
@@ -179,8 +179,8 @@ static inline fcs_card fcs_make_card(const int rank, const int suit)
 #define fcs_state_col_len(s, i) fcs_col_len(fcs_state_get_col((s), (i)))
 #define fcs_state_col_is_empty(s, i) (fcs_state_col_len((s), (i)) == 0)
 
-#define fcs_card_rank(card) ((card) >> 2)
-#define fcs_card_suit(card) ((card)&0x03)
+#define fcs_card_rank(card) ((card) >> 2U)
+#define fcs_card_suit(card) ((card)&0x03U)
 
 static inline fcs_card fcs_col_get_rank(
     const fcs_const_cards_column col, const int card_idx)
@@ -195,7 +195,7 @@ static inline bool fcs_card_is_king(const fcs_card card)
 }
 
 static inline bool fcs_col_is_king(
-    const fcs_const_cards_column col, const int card_idx)
+    const fcs_const_cards_column col, const stack_i card_idx)
 {
     return fcs_card_is_king(fcs_col_get_card(col, card_idx));
 }
@@ -232,7 +232,7 @@ struct fcs_state_extra_info_struct
     /*
      * The iteration in which this state was marked as visited
      * */
-    fcs_int_limit_t visited_iter;
+    fcs_iters_int visited_iter;
 #endif
 
     /*
@@ -485,9 +485,9 @@ extern void fc_solve_card_stringify(
  * The suit letter may come somewhat after the beginning of the string.
  *
  * */
-static inline __attribute__((pure)) int fcs_str2suit(const char *suit)
+static inline __attribute__((pure)) fcs_card fcs_str2suit(const char *suit)
 {
-    while (TRUE)
+    while (true)
     {
         switch (FC_SOLVE_MAP_CHAR(*suit))
         {
@@ -513,7 +513,7 @@ static inline __attribute__((pure)) int fcs_str2suit(const char *suit)
  * the program.
  * */
 
-static inline __attribute__((pure)) int fcs_str2rank(const char *string)
+static inline __attribute__((pure)) fcs_card fcs_str2rank(const char *string)
 {
     while (1)
     {
@@ -590,8 +590,8 @@ static inline void fc_solve_state_init_proto(fcs_state_keyval_pair *const state
     size_t i;
     for (i = 0; i < STACKS_NUM__VAL; ++i)
     {
-        memset(state->s.columns[i] = &indirect_stacks_buffer[i << 7], '\0',
-            MAX_NUM_DECKS * 52 + 1);
+        memset(state->s.columns[i] = &indirect_stacks_buffer[i << 6], '\0',
+            1 * 52 + 1);
     }
     for (; i < MAX_NUM_STACKS; ++i)
     {
@@ -661,19 +661,30 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
     fc_solve_state_init(out_state, STACKS_NUM__VAL, indirect_stacks_buffer);
     const char *str = string;
 
-    bool first_line = TRUE;
+    bool first_line = true;
 
 #define out (out_state->s)
 /* Handle the end of string - shouldn't happen */
+#ifdef FCS_BREAK_BACKWARD_COMPAT_2
 #define HANDLE_EOS()                                                           \
     {                                                                          \
         if ((*str) == '\0')                                                    \
         {                                                                      \
-            return FALSE;                                                      \
+            return false;                                                      \
         }                                                                      \
     }
+#else
+#define HANDLE_EOS()                                                           \
+    {                                                                          \
+        if ((*str) == '\0')                                                    \
+        {                                                                      \
+            goto end_of_loop;                                                  \
+        }                                                                      \
+    }
+#endif
 
-    for (size_t s = 0; s < STACKS_NUM__VAL; s++)
+    size_t s;
+    for (s = 0; s < STACKS_NUM__VAL; ++s)
     {
         /* Move to the next stack */
         if (!first_line)
@@ -686,7 +697,7 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
             ++str;
         }
 
-        first_line = FALSE;
+        first_line = false;
 
 #if MAX_NUM_FREECELLS > 0
         const_AUTO(new_str, FCS_PARSE_try_prefix(str,
@@ -724,10 +735,10 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
 
                 fcs_put_card_in_freecell(out, c,
                     ((*str == '*') || (*str == '-')) ? fc_solve_empty_card : ({
-                        const char rank = fcs_str2rank(str);
+                        const fcs_card rank = fcs_str2rank(str);
                         if (!rank)
                         {
-                            return FALSE;
+                            return false;
                         }
                         fcs_make_card(rank, fcs_str2suit(str));
                     }));
@@ -748,7 +759,7 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
         if (new_str2)
         {
             str = new_str2;
-            for (size_t f_idx = 0; f_idx < (DECKS_NUM__VAL << 2); f_idx++)
+            for (size_t f_idx = 0; f_idx < (DECKS_NUM__VAL << 2); ++f_idx)
             {
                 fcs_set_foundation(out, f_idx, 0);
             }
@@ -760,7 +771,7 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
                     ++str;
                 if ((*str == '\n') || (*str == '\r'))
                     break;
-                const int f_idx = fcs_str2suit(str);
+                const size_t f_idx = fcs_str2suit(str);
                 ++str;
                 while (*str == '-')
                     ++str;
@@ -821,13 +832,20 @@ static inline bool fc_solve_initial_user_state_to_c_proto(
             const_AUTO(my_card, fc_solve_card_parse_str(str));
             if (!fcs_card_rank(my_card))
             {
-                return FALSE;
+                return false;
             }
             fcs_col_push_card(col, my_card);
         }
+#ifndef FCS_BREAK_BACKWARD_COMPAT_2
+    end_of_loop:;
+#endif
     }
 
-    return TRUE;
+#ifdef FCS_BREAK_BACKWARD_COMPAT_2
+    return true;
+#else
+    return s == STACKS_NUM__VAL;
+#endif
 }
 
 #undef out
@@ -913,7 +931,8 @@ static inline state_validity_ret fc_solve_check_state_validity(
         {
             if (card_counts[suit_idx][rank] != DECKS_NUM__VAL)
             {
-                *misplaced_card = fcs_make_card(rank, suit_idx);
+                *misplaced_card =
+                    fcs_make_card((fcs_card)rank, (fcs_card)suit_idx);
                 return ((card_counts[suit_idx][rank] < DECKS_NUM__VAL)
                             ? FCS_STATE_VALIDITY__MISSING_CARD
                             : FCS_STATE_VALIDITY__EXTRA_CARD);
@@ -953,7 +972,16 @@ static inline int fc_solve_stack_compare_for_comparison(
     const fcs_card *const s2 = (const fcs_card *const)v_s2;
 
     {
+#ifdef __cplusplus
+        using std::min;
+#endif
         const int min_len = min(s1[0], s2[0]);
+#ifdef DO_NOT_ENABLE__FALSE_RESULTS
+        if (min_len)
+        {
+            return fc_solve_card_compare(s1[1], s2[1]);
+        }
+#else
         for (int a = 1; a <= min_len; a++)
         {
             const int ret = fc_solve_card_compare(s1[a], s2[a]);
@@ -962,6 +990,44 @@ static inline int fc_solve_stack_compare_for_comparison(
                 return ret;
             }
         }
+#endif
+    }
+    /*
+     * The reason I do the stack length comparisons after the card-by-card
+     * comparison is to maintain correspondence with
+     * fcs_stack_compare_for_stack_sort, and with the one card comparison
+     * of the other state representation mechanisms.
+     * */
+    /* For some reason this code is faster than s1[0]-s2[0] */
+    if (s1[0] < s2[0])
+    {
+        return -1;
+    }
+    else if (s1[0] > s2[0])
+    {
+        return 1;
+    }
+    else
+    {
+        return 0;
+    }
+}
+
+static inline int fc_solve_stack_compare_for_canonize(
+    const void *const v_s1, const void *const v_s2)
+{
+    const fcs_card *const s1 = (const fcs_card *const)v_s1;
+    const fcs_card *const s2 = (const fcs_card *const)v_s2;
+
+    {
+#ifdef __cplusplus
+        using std::min;
+#endif
+        const int min_len = min(s1[0], s2[0]);
+        if (min_len)
+        {
+            return fc_solve_card_compare(s1[1], s2[1]);
+        }
     }
     /*
      * The reason I do the stack length comparisons after the card-by-card
@@ -986,7 +1052,7 @@ static inline int fc_solve_stack_compare_for_comparison(
 #endif
 
 static inline void set_scan_visited(
-    fcs_collectible_state *const ptr_state, const int scan_id)
+    fcs_collectible_state *const ptr_state, const size_t scan_id)
 {
     (FCS_S_SCAN_VISITED(ptr_state))[scan_id >> FCS_CHAR_BIT_SIZE_LOG2] |=
         (1 << ((scan_id) & ((1 << (FCS_CHAR_BIT_SIZE_LOG2)) - 1)));
@@ -1016,7 +1082,7 @@ static inline bool fcs_is_parent_card__helper(const fcs_card child,
 {
     return ((fcs_card_rank(child) + 1 == fcs_card_rank(parent)) &&
             ((sequences_are_built_by == FCS_SEQ_BUILT_BY_RANK)
-                    ? TRUE
+                    ? true
                     : ((sequences_are_built_by == FCS_SEQ_BUILT_BY_SUIT)
                               ? (fcs_card_suit(child) == fcs_card_suit(parent))
                               : ((fcs_card_suit(child) & 0x1) !=
@@ -1034,7 +1100,7 @@ static inline bool fcs_is_parent_card__helper(const fcs_card child,
     }
 
 static inline void fcs_col_transfer_cards(
-    fcs_cards_column dest_col, fcs_cards_column src_col, const int cards_num)
+    fcs_cards_column dest_col, fcs_cards_column src_col, const size_t cards_num)
 {
     fcs_card *const src_cards_ptr =
         &fcs_col_get_card(src_col, (fcs_col_len(src_col) -= cards_num));
@@ -1046,7 +1112,7 @@ static inline void fcs_col_transfer_cards(
 }
 
 static inline fcs_card fcs_state_pop_col_card(
-    fcs_state *const state, const int col_idx)
+    fcs_state *const state, const stack_i col_idx)
 {
     var_AUTO(col, fcs_state_get_col(*state, col_idx));
     fcs_card ret;
@@ -1055,21 +1121,21 @@ static inline fcs_card fcs_state_pop_col_card(
 }
 
 static inline void fcs_state_pop_col_top(
-    fcs_state *const state, const int col_idx)
+    fcs_state *const state, const size_t col_idx)
 {
     var_AUTO(col, fcs_state_get_col(*state, col_idx));
     fcs_col_pop_top(col);
 }
 
 static inline void fcs_state_push(
-    fcs_state *const state, const int col_idx, const fcs_card card)
+    fcs_state *const state, const size_t col_idx, const fcs_card card)
 {
     var_AUTO(col, fcs_state_get_col(*state, col_idx));
     fcs_col_push_card(col, card);
 }
 
 #ifdef FCS_FREECELL_ONLY
-#define FCS__SEQS_ARE_BUILT_BY_RANK() FALSE
+#define FCS__SEQS_ARE_BUILT_BY_RANK() false
 #else
 #define FCS__SEQS_ARE_BUILT_BY_RANK()                                          \
     (sequences_are_built_by == FCS_SEQ_BUILT_BY_RANK)
