@@ -37,7 +37,7 @@ sub validate_and_transform
 my $arr = [
     'dbm_fc_solver_1' => {
         dbm  => 1,
-        prog => "dbm_fc_solver",
+        prog => "dbm-fc-solver",
         argv => [
             '--offload-dir-path',
             { type => 'tempdir', },
@@ -46,7 +46,7 @@ my $arr = [
                 arg  => '2freecells-24-mid-with-colons.board'
             }
         ],
-        msg => qq{dbm_fc_solver from 24-mid-with-colons.},
+        msg => qq{dbm-fc-solver from 24-mid-with-colons.},
     },
     'empty_board' => {
         prog => "fc-solve",
@@ -113,6 +113,14 @@ my $arr = [
         argv => [ { type => 'sample_board', arg => '24-with-7-cols.board' } ],
         msg  => "Check the sanity of not enough input.",
     },
+    'fc-solve-simple-simon-15508' => {
+        prog => "fc-solve",
+        argv => [
+            '-g', 'simple_simon',
+            { type => 'sample_board', arg => '15508.simpsim.board' }
+        ],
+        msg => "Check the sanity of not enough input.",
+    },
     'fc-solve-trim-max-stored-states' => {
         prog => "fc-solve",
         argv => [
