@@ -1,7 +1,9 @@
 #!/usr/bin/env python3
 
-from FC_Solve import FC_Solve_Suite
 import unittest
+
+from FC_Solve import FreecellSolverTestSuite
+
 # TEST:source "$^CURRENT_DIRNAME/../lib/FC_Solve/__init__.py"
 
 
@@ -9,10 +11,10 @@ class MyTests(unittest.TestCase):
     def test_1(self):
         testname = "test_1"
 
-        fcs = FC_Solve_Suite(self)
+        fcs = FreecellSolverTestSuite(self)
 
         # TEST*$input_cmd_line
-        fcs.input_cmd_line(
+        fcs.input_cmd_line__test(
             "dto 1",
             ["-to", "0123456789", "-dto", "1,0132456789"]
         )
@@ -26,10 +28,10 @@ class MyTests(unittest.TestCase):
     def test_2(self):
         testname = "test_1"
 
-        fcs = FC_Solve_Suite(self)
+        fcs = FreecellSolverTestSuite(self)
 
         # TEST*$input_cmd_line
-        fcs.input_cmd_line(
+        fcs.input_cmd_line__test(
             "dto 1",
             ["-to", "0123456789", "-dto", "1,0132456789", "-dto", "50,056234"]
         )
