@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 // threaded_range_solver.c - a range solver that solves different boards in
 // several POSIX threads.
 //
@@ -17,6 +15,7 @@
 #include <pthread.h>
 #include "range_solvers.h"
 #include "try_param.h"
+#include "print_time.h"
 
 #ifndef FCS_WITHOUT_CMD_LINE_HELP
 static void print_help(void)
@@ -36,12 +35,11 @@ static void print_help(void)
 static const pthread_mutex_t initial_mutex_constant = PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t next_board_num_lock;
 static long long next_board_num, stop_at, past_end_board, board_num_step = 1;
-#define UPDATE_TOTAL_NUM_ITERS_THRESHOLD 1000000
 #ifndef FCS_USE_PRECOMPILED_CMD_LINE_THEME
 static char **context_argv;
 static int arg = 1, context_argc;
 #endif
-static long long total_num_iters = 0;
+static fcs_iters_int total_num_iters = 0;
 
 static void *worker_thread(void *const void_arg)
 {
@@ -129,7 +127,7 @@ static inline int range_solvers_main(int argc, char *argv[], const int par__arg,
             pthread_create(&workers[idx], NULL, worker_thread, &num_iters[idx]);
         if (check)
         {
-            fc_solve_err(
+            exit_error(
                 "Worker Thread No. %lu Initialization failed with error %d!\n",
                 (unsigned long)idx, check);
         }
